#### Libraries needed to run the current R code ####
library(languageR)#version 1.4.1
library(lme4)     #version 1.1-12
library(lattice)  #version 0.20-34
library(lmerTest) #if you want p values for your lmer model #version 2.0-33
library(MASS)     #version 7.3-45
library(plyr)     #version 1.8.4

#### Clean up####
rm(list=ls())
#### Part1-TARGET WORDS ANALYSES-Load data and set up variables####
# 1.Load data
# Open your datafile in a raw editor to see how the columns are separated and what character is used for decimal points.
# open the csv.file according to data name.
datafile = read.csv(file.choose(), sep = ",", dec = ".")
head(datafile) #generally check the file you have imported
# choose dependent variable - here I have several measures - first analyze FFD on the first constituent
measure = "FFD"
# add to dataframe
datafile$depvar = datafile[,measure]
# 2.Set up variables 
colnames(datafile) #checked the column names
col.pp = 1    #specify which column your participant number is in,participant
col.stim =2    #specify which column your stim number is in,trial
col.phrase_type =3 #specify which column phrase_type number is
col.preview_type =4 #specify which column  preview_type_type number is
col.condition =5 #specify which column conditon number is
head(datafile)

#### Part1-TARGET WORDS ANALYSES-Work out the fixed and random factors are in
datafile$phrase_type = datafile[,col.phrase_type]
datafile$stim = datafile[,col.stim]
datafile$pp = datafile[,col.pp]
#### Part1-TARGET WORDS ANALYSES-Make sure all variables are correct class ####
str(datafile)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$ preview_type = as.factor(datafile$ preview_type)
datafile$phrase_type = as.factor(datafile$phrase_type)
datafile$condition = as.factor(datafile$condition)
datafile$depvar = as.numeric(datafile$depvar)


#### Part1-TARGET WORDS ANALYSES-Remove outlier ####
# Remove data outside 3 standard deviations
head(datafile) #let's first have a look
nrcolumns = ncol(datafile)   
# make a new datafile with eye movement measures > 0
between1 = datafile[datafile$depvar > 0, ]
head(between1)
between1 = datafile
#make a matrix with the means per subject 
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp ), sd, na.rm = T)
sd.matrix
# add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
# make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]
# you might want to clean up this data file by removing the added columns
result = result[,1:nrcolumns]
tussen1 = result# insert the name from the datafile coming from the clean up on the right
nrow(datafile)-nrow(tussen1) # calculate how many row you removed
# calculate the rate
rate=(nrow(datafile)-nrow(tussen1))/nrow(datafile) 
rate 
datafile = tussen1 
nrow(datafile)# checked the observations after remove outliers

#### Part1-TARGET WORD ANALYSES-Means,Standard Deviations and Standard Errors####
##Code for calculating means per pp and per condition
mean.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.tt
sd.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.tt
## then calculate the grand mean by condition
grand.mean=apply(mean.tt, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(sd.tt,2,mean, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(138)  ## this number is the total number of participants from your data, so it is changable.
grand.se
# Paste the results into .txt file

#### Part1-TARGET WORD ANALYSES-Datavisualization ####
# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # log transform data
# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar) 
# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)

####Part1-TARGET ANALYSES-Linear Mixed Models (LMM)####
# 1.Check the levels of  preview_type and phrase_type
levels(datafile$ preview_type)
levels(datafile$phrase_type)
# 2.Do the contrast.
#contrasts(datafile$phrase_type)#
contrasts(datafile$phrase_type) <- contr.sdif(3)
contrasts(datafile$ preview_type) <- contr.sdif(2)

# 3.Run linear mixed-effects models (LMM)
# 1.Full model

depvar.lmer1 = lmer(depvar ~ phrase_type *  preview_type + (1 + phrase_type *  preview_type|pp) + (1 + phrase_type *  preview_type|stim), datafile)
summary(depvar.lmer1, corr = FALSE)

# 2.Remove correlations of item

depvar.lmer2 = lmer(depvar ~ phrase_type *  preview_type  + (1 + phrase_type *  preview_type|pp) + (0 + phrase_type *  preview_type|stim), datafile)
summary(depvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item

depvar.lmer3 = lmer(depvar ~ phrase_type *  preview_type   + (1 + phrase_type *  preview_type|pp) + (1 + phrase_type +  preview_type|stim), datafile)
summary(depvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

depvar.lmer4 = lmer(depvar ~ phrase_type *  preview_type  + (1 + phrase_type *  preview_type|pp) + (0 + phrase_type +  preview_type|stim), datafile)
summary(depvar.lmer4, corr = FALSE)

# 5a. Remove one of the slopes

depvar.lmer5a = lmer(depvar ~ phrase_type *  preview_type  + (1 + phrase_type *  preview_type|pp) + (1 + phrase_type|stim), datafile)
summary(depvar.lmer5a, corr = FALSE)

### 5b.
depvar.lmer5b = lmer(depvar ~ phrase_type *  preview_type+ (1 + phrase_type *  preview_type|pp) + (1 +  preview_type|stim), datafile)
summary(depvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

depvar.lmer6a = lmer(depvar ~ phrase_type *  preview_type+ (1 + phrase_type *  preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile)
summary(depvar.lmer6a, corr = FALSE)

### 6b.
depvar.lmer6b = lmer(depvar ~ phrase_type *  preview_type  + (1 + phrase_type *  preview_type|pp) + (1|stim) + (0 +  preview_type|stim), datafile)
summary(depvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

depvar.lmer7 = lmer(depvar ~ phrase_type *  preview_type  + (1 + phrase_type *  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

depvar.lmer8 = lmer(depvar ~ phrase_type *  preview_type  + (0 + phrase_type *  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

depvar.lmer9 = lmer(depvar ~ phrase_type *  preview_type  + (1 + phrase_type +  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

depvar.lmer10 = lmer(depvar ~ phrase_type *  preview_type  + (0 + phrase_type +  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
depvar.lmer11a = lmer(depvar ~ phrase_type *  preview_type  + (1 +  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer11a, corr = FALSE)

#### 11b.
depvar.lmer11b = lmer(depvar ~ phrase_type *  preview_type  + (1 + phrase_type|pp) + (1|stim), datafile)
summary(depvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

depvar.lmer12a = lmer(depvar ~ phrase_type *  preview_type  + (1|pp) + (0 + phrase_type|pp) + (1|stim), datafile)
summary(depvar.lmer12a, corr = FALSE)

#### 12b.

depvar.lmer12b = lmer(depvar ~ phrase_type *  preview_type  + (1|pp) + (0 +  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer12b, corr = FALSE)

# 13. Intercepts only 

depvar.lmer13 = lmer(depvar ~ phrase_type *  preview_type  + (1|pp) + (1|stim), datafile)
summary(depvar.lmer13, corr = FALSE)

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(depvar.lmer3, method="Wald") # calculate CI of the model you run.
# Paste the results into .txt file

########################################################################
####Simple analyse###########
levels(datafile$condition)

#Preview effect for different target word
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,0,0,# ID vs Pseudocharacter for word
                                                    0,0,-0.5,+0.5,0,0,# ID vs Pseudocharacter for MCUs
                                                    0,0,0,0,-0.5,+0.5)  # ID vs Pseudocharacter for phrase
                                                  ,6,3),3)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(contrast1.lmer, method="Wald") # calculate CI of the model you run.

###############################################################################

#### Clean up and notice####
rm(list=ls())
#NOTICE: The code for FFD,SFD, GD,TFD,Go-past are identical
#After clean up, please run the code above for FFD,SFD, GD,TFD,and Go-past.

######## Part1-TARGET WORDS ANALYSES-load some packages that needed.

library(languageR)#version 1.4.1
library(lme4) #version 1.1-17
library(lattice) #version 0.20-35
library(MASS) #version 7.3-49
library(plyr) #version 1.8.4
library(lmerTest) #version3.0-1

rm(list=ls()) # Remove any variables

# Part1-TARGET WORDS ANALYSES-Open a csv.file of skipping 

datafile = read.csv(file.choose(), sep = ",", dec = ".")

head(datafile) # generally check the file you have imported

nrow(datafile) # check the number of observations

colnames(datafile)   #Display the column names 
col.subject = 1      # specify which column your participant number is in
col.condition = 5    # specify which column contains your condition number
col.stim = 2         # specify which column your item number is in

# Part1-TARGET WORDS ANALYSES-choose dependent variable
measure = "IA_SKIP"

# add to dataframe
datafile$depvar = datafile[,measure]

# Work out which colums the fixed and random factors are in

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# Let's make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)


################################################################

####Part1-TARGET WORDS ANALYSES-Calculate Means, Standard Deviations and Standard Errors####

#Make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix

#Make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

## Calculate the grand mean, grand SD, and grand SE by condition
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(138)  ##The number of the participants is 138. 
grand.se

###############################################################################
#Part1-TARGET WORDS ANALYSES- Add contrasts
contrasts(datafile$phrase_type) <- contr.sdif(3)  
contrasts(datafile$preview_type) <- contr.sdif(2)


##When we run the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.
# Part1-TARGET WORDS ANALYSES-GLME
# 1.Full model
depvar.lmer1 = glmer(depvar ~ phrase_type *preview_type   + (1 + phrase_type *preview_type|pp) + (1 + phrase_type *preview_type|stim), datafile, family = binomial)
summary(depvar.lmer1, corr = FALSE)

# 2.remove correlations of item

depvar.lmer2 = glmer(depvar ~ phrase_type *preview_type + (1 + phrase_type *preview_type|pp) + (0 + phrase_type *preview_type|stim), datafile, family = binomial)
summary(depvar.lmer2, corr = FALSE)

# 3. remove interactions (with correlation back in) of item

depvar.lmer3 = glmer(depvar ~ phrase_type *preview_type  + (1 + phrase_type *preview_type|pp) + (1 + phrase_type +preview_type|stim), datafile, family = binomial)
summary(depvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

depvar.lmer4 = glmer(depvar ~ phrase_type *preview_type + (1 + phrase_type *preview_type|pp) + (0 + phrase_type +preview_type|stim), datafile, family = binomial)
summary(depvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes 

depvar.lmer5a = glmer(depvar ~ phrase_type *preview_type  + (1 + phrase_type *preview_type|pp) + (1 + phrase_type|stim), datafile, family = binomial)
summary(depvar.lmer5a, corr = FALSE)

### 5b. 

depvar.lmer5b = glmer(depvar ~ phrase_type *preview_type  + (1 + phrase_type *preview_type|pp) + (1 +preview_type|stim), datafile, family = binomial)
summary(depvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

depvar.lmer6a = glmer(depvar ~ phrase_type *preview_type + (1 + phrase_type *preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile, family = binomial)
summary(depvar.lmer6a, corr = FALSE)

### 6b.

depvar.lmer6b = glmer(depvar ~ phrase_type *preview_type  + (1 + phrase_type *preview_type|pp) + (1|stim) + (0 +preview_type|stim), datafile, family = binomial)
summary(depvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

depvar.lmer7 = glmer(depvar ~ phrase_type *preview_type  + (1 + phrase_type *preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

depvar.lmer8 = glmer(depvar ~ phrase_type *preview_type   + (0 + phrase_type *preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

depvar.lmer9 = glmer(depvar ~ phrase_type *preview_type + (1 + phrase_type +preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

depvar.lmer10 = glmer(depvar ~ phrase_type *preview_type + (0 + phrase_type +preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
depvar.lmer11a = glmer(depvar ~ phrase_type *preview_type  + (1 +preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11a, corr = FALSE)

##### 11b.
depvar.lmer11b = glmer(depvar ~ phrase_type *preview_type + (1 + phrase_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

depvar.lmer12a = glmer(depvar ~ phrase_type *preview_type  + (1|pp) + (0 + phrase_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12a, corr = FALSE)

#### 12b.

depvar.lmer12b = glmer(depvar ~ phrase_type *preview_type  + (1|pp) + (0 +preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12b, corr = FALSE)

# 13. Intercepts only

depvar.lmer13 = glmer(depvar ~ phrase_type *preview_type + (1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer13, corr = FALSE)

depvar.lmer13 = glmer(depvar ~ phrase_type *preview_type + (1|pp) , datafile, family = binomial)
summary(depvar.lmer13, corr = FALSE)

######################################################################

###CI confidence Interation
confint(depvar.lmer13, method="Wald")
################Simple effect######################################################
#Preview effect for different target word
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,0,0,# ID vs Pseudocharacter for word
                                                    0,0,-0.5,+0.5,0,0,# ID vs Pseudocharacter for MCUs
                                                    0,0,0,0,-0.5,+0.5)  # ID vs Pseudocharacter for phrase
                                                  ,6,3),3)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.glmer <- glmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), datafile, family = binomial)
summary(contrast1.glmer, corr = FALSE)

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(contrast4.glmer, method="Wald") # calculate CI of the model you run.

#################################THE END##############################
#### Additional analyses
#### Below are codes when predictability or transitional probability was included as a covariable in the LMM analyses

#### Libraries needed to run the current R code ####
library(languageR)#version 1.4.1
library(lme4)     #version 1.1-12
library(lattice)  #version 0.20-34
library(lmerTest) #if you want p values for your lmer model #version 2.0-33
library(MASS)     #version 7.3-45
library(plyr)     #version 1.8.4

#### Clean up####
rm(list=ls())


#### Part2-TARGET WORDS ANALYSES  when predictability was included as  a covariate-Load data and set up variables####
# 1.Load data
# Open your datafile in a raw editor to see how the columns are separated and what character is used for decimal points.
# open the csv.file according to data name.
datafile = read.csv(file.choose(), sep = ",", dec = ".")
head(datafile) #generally check the file you have imported
# choose dependent variable - here I have several measures
measure = "FFD"
# add to dataframe
datafile$depvar = datafile[,measure]
# 2.Set up variables 
colnames(datafile) #checked the column names
col.pp = 1    #specify which column your participant number is in,participant
col.stim =2    #specify which column your stim number is in,trial
col.phrase_type =3 #specify which column phrase_type number is
col.preview_type =4 #specify which column  preview_type_type number is
col.condition =5 #specify which column conditon number is
col.prediction =6 #specify which column conditon number is
head(datafile)

#### Part2-TARGET WORDS ANALYSES  when predictability was included as a covariate-Work out the fixed and random factors are in
datafile$phrase_type = datafile[,col.phrase_type]
datafile$stim = datafile[,col.stim]
datafile$pp = datafile[,col.pp]
#### Make sure all variables are correct class ####
str(datafile)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$ preview_type = as.factor(datafile$ preview_type)
datafile$phrase_type = as.factor(datafile$phrase_type)
datafile$condition = as.factor(datafile$condition)
datafile$prediction  = as.numeric(datafile$prediction)
datafile$depvar = as.numeric(datafile$depvar)


#### Part2-TARGET WORDS ANALYSES  when predictability was included as a covariate-Remove outlier ####
# Remove data outside 3 standard deviations
head(datafile) #let's first have a look
nrcolumns = ncol(datafile)   
# make a new datafile with eye movement measures > 0
between1 = datafile[datafile$depvar > 0, ]
head(between1)
between1 = datafile
#make a matrix with the means per subject 
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp ), sd, na.rm = T)
sd.matrix
# add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
# make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]
# you might want to clean up this data file by removing the added columns
result = result[,1:nrcolumns]
tussen1 = result# insert the name from the datafile coming from the clean up on the right
nrow(datafile)-nrow(tussen1) # calculate how many row you removed
# calculate the rate
rate=(nrow(datafile)-nrow(tussen1))/nrow(datafile) 
rate 
datafile = tussen1 
nrow(datafile)# checked the observations after remove outlier
#centering  predicition
datafile$prediction = datafile$prediction -mean(datafile$prediction)
head(datafile)

####Part2-TARGET WORDS ANALYSES  when predictability was included asa covariate-Means,Standard Deviations and Standard Errors####
##Code for calculating means between per pp and per condition
mean.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.tt
sd.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.tt
## then calculate the grand mean by condition
grand.mean=apply(mean.tt, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(sd.tt,2,mean, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(138)  ## this number is the total number of participants from your data, so it is changable.
grand.se
# Paste the results into .txt file

#### Part2-TARGET WORDS ANALYSES when predictability was included as a covariate-Datavisualization ####
# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # log transform data
# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar) 
# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)

####Part2-TARGET WORDS ANALYSES when predictability was included as a covariate-Linear Mixed Models (LMM)####
# 1.Check the levels of  preview_type_type and phrase_type
levels(datafile$ preview_type)
levels(datafile$phrase_type)
# 2.Do the contrast.
#contrasts(datafile$phrase_type)#
contrasts(datafile$phrase_type) <- contr.sdif(3)
contrasts(datafile$ preview_type) <- contr.sdif(2)

# 3.Run linear mixed-effects models (LMM)
# 1.Full model

depvar.lmer1 = lmer(depvar ~ phrase_type *  preview_type +prediction+ (1 + phrase_type *  preview_type|pp) + (1 + phrase_type *  preview_type|stim), datafile)
summary(depvar.lmer1, corr = FALSE)

# 2.Remove correlations of item

depvar.lmer2 = lmer(depvar ~ phrase_type *  preview_type +prediction+  (1 + phrase_type *  preview_type|pp) + (0 + phrase_type *  preview_type|stim), datafile)
summary(depvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item

depvar.lmer3 = lmer(depvar ~ phrase_type *  preview_type  +prediction+  (1 + phrase_type *  preview_type|pp) + (1 + phrase_type +  preview_type|stim), datafile)
summary(depvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

depvar.lmer4 = lmer(depvar ~ phrase_type *  preview_type +prediction+  (1 + phrase_type *  preview_type|pp) + (0 + phrase_type +  preview_type|stim), datafile)
summary(depvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes

depvar.lmer5a = lmer(depvar ~ phrase_type *  preview_type  +prediction+ (1 + phrase_type *  preview_type|pp) + (1 + phrase_type|stim), datafile)
summary(depvar.lmer5a, corr = FALSE)

### 5b.
depvar.lmer5b = lmer(depvar ~ phrase_type *  preview_type +prediction+ (1 + phrase_type *  preview_type|pp) + (1 +  preview_type|stim), datafile)
summary(depvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

depvar.lmer6a = lmer(depvar ~ phrase_type *  preview_type +prediction+ (1 + phrase_type *  preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile)
summary(depvar.lmer6a, corr = FALSE)

### 6b.
depvar.lmer6b = lmer(depvar ~ phrase_type *  preview_type +prediction  + (1 + phrase_type *  preview_type|pp) + (1|stim) + (0 +  preview_type|stim), datafile)
summary(depvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

depvar.lmer7 = lmer(depvar ~ phrase_type *  preview_type  +prediction + (1 + phrase_type *  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

depvar.lmer8 = lmer(depvar ~ phrase_type *  preview_type  +prediction + (0 + phrase_type *  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

depvar.lmer9 = lmer(depvar ~ phrase_type *  preview_type  +prediction + (1 + phrase_type +  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

depvar.lmer10 = lmer(depvar ~ phrase_type *  preview_type +prediction  + (0 + phrase_type +  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
depvar.lmer11a = lmer(depvar ~ phrase_type *  preview_type +prediction  + (1 +  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer11a, corr = FALSE)

#### 11b.
depvar.lmer11b = lmer(depvar ~ phrase_type *  preview_type +prediction  + (1 + phrase_type|pp) + (1|stim), datafile)
summary(depvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

depvar.lmer12a = lmer(depvar ~ phrase_type *  preview_type  +prediction + (1|pp) + (0 + phrase_type|pp) + (1|stim), datafile)
summary(depvar.lmer12a, corr = FALSE)

#### 12b.

depvar.lmer12b = lmer(depvar ~ phrase_type *  preview_type +prediction  + (1|pp) + (0 +  preview_type|pp) + (1|stim), datafile)
summary(depvar.lmer12b, corr = FALSE)

# 13. Intercepts only 

depvar.lmer13 = lmer(depvar ~ phrase_type *  preview_type  +prediction + (1|pp) + (1|stim), datafile)
summary(depvar.lmer13, corr = FALSE)

#### Part2-TARGET WORDS ANALYSES  when predictability was included as a covariate-Confidence interval ####
confint(depvar.lmer5a, method="Wald") # calculate CI of the model you run.
# Paste the results into .txt file

########################################################################
####Simple analyse###########
levels(datafile$condition)

#Preview effect for different target word
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,0,0,# ID vs Pseudocharacter for word
                                                    0,0,-0.5,+0.5,0,0,# ID vs Pseudocharacter for MCUs
                                                    0,0,0,0,-0.5,+0.5)  # ID vs Pseudocharacter for phrase
                                                  ,6,3),3)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lmer
contrast1.lmer <- lmer(depvar ~ condition  +prediction + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

####Part2-TARGET WORDS ANALYSES  when predictability was included asa covariate-Confidence interval ####
confint(contrast1.lmer, method="Wald") # calculate CI of the model you run.

###############################################################################

#### Clean up and notice####
rm(list=ls())
#NOTICE: The code for FFD,SFD,GD,TFD,Go-past are identical
#After clean up, please run the code above for FFD,SFD,GD,TFD,Go-past.

########Part2-TARGET WORDS ANALYSES when predictability was included as a covariate-load some packages that needed.

library(languageR)#version 1.4.1
library(lme4) #version 1.1-17
library(lattice) #version 0.20-35
library(MASS) #version 7.3-49
library(plyr) #version 1.8.4
library(lmerTest) #version3.0-1

rm(list=ls()) # Remove any variables

#  Part2-TARGET WORDS ANALYSES when predictability was included as a covariate-Open a csv.file of skipping 

datafile = read.csv(file.choose(), sep = ",", dec = ".")

head(datafile) # generally check the file you have imported

nrow(datafile) # check the number of observations

colnames(datafile)   #Display the column names 
col.subject = 1      # specify which column your participant number is in
col.condition = 5    # specify which column contains your condition number
col.stim = 2         # specify which column your item number is in

#  Part2-TARGET WORDS ANALYSES  when predictability was included as a covariate-choose dependent variable
measure = "IA_SKIP"

# add to dataframe
datafile$depvar = datafile[,measure]

# Work out which colums the fixed and random factors are in

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# Let's make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
################################################################
#centering  predicition
datafile$prediction = datafile$prediction -mean(datafile$prediction)
head(datafile)

####Part2-TARGET WORDS ANALYSES  when predictability was included as  a covariate-Calculate Means, Standard Deviations and Standard Errors####

#Make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix

#Make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

## Calculate the grand mean, grand SD, and grand SE by condition
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(138)  ##The number of the participants is 138. 
grand.se

###############################################################################
##Part2-TARGET WORDS ANALYSES  when predictability was included as  a covariate- Add contrasts
contrasts(datafile$phrase_type) <- contr.sdif(3)  
contrasts(datafile$preview_type) <- contr.sdif(2)


##When we run the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.
#  Part2-TARGET WORDS ANALYSES  when predictability was included as  a covariate-GLME

# 1.Full model
depvar.lmer1 = glmer(depvar ~ phrase_type *preview_type  +prediction   + (1 + phrase_type *preview_type|pp) + (1 + phrase_type *preview_type|stim), datafile, family = binomial)
summary(depvar.lmer1, corr = FALSE)

# 2.remove correlations of item

depvar.lmer2 = glmer(depvar ~ phrase_type *preview_type  +prediction + (1 + phrase_type *preview_type|pp) + (0 + phrase_type *preview_type|stim), datafile, family = binomial)
summary(depvar.lmer2, corr = FALSE)

# 3. remove interactions (with correlation back in) of item

depvar.lmer3 = glmer(depvar ~ phrase_type *preview_type   +prediction + (1 + phrase_type *preview_type|pp) + (1 + phrase_type +preview_type|stim), datafile, family = binomial)
summary(depvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

depvar.lmer4 = glmer(depvar ~ phrase_type *preview_type +prediction  + (1 + phrase_type *preview_type|pp) + (0 + phrase_type +preview_type|stim), datafile, family = binomial)
summary(depvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes 

depvar.lmer5a = glmer(depvar ~ phrase_type *preview_type  +prediction  + (1 + phrase_type *preview_type|pp) + (1 + phrase_type|stim), datafile, family = binomial)
summary(depvar.lmer5a, corr = FALSE)

### 5b. 

depvar.lmer5b = glmer(depvar ~ phrase_type *preview_type  +prediction  + (1 + phrase_type *preview_type|pp) + (1 +preview_type|stim), datafile, family = binomial)
summary(depvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

depvar.lmer6a = glmer(depvar ~ phrase_type *preview_type +prediction  + (1 + phrase_type *preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile, family = binomial)
summary(depvar.lmer6a, corr = FALSE)

### 6b.

depvar.lmer6b = glmer(depvar ~ phrase_type *preview_type  +prediction  + (1 + phrase_type *preview_type|pp) + (1|stim) + (0 +preview_type|stim), datafile, family = binomial)
summary(depvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

depvar.lmer7 = glmer(depvar ~ phrase_type *preview_type  +prediction  + (1 + phrase_type *preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

depvar.lmer8 = glmer(depvar ~ phrase_type *preview_type   +prediction  + (0 + phrase_type *preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

depvar.lmer9 = glmer(depvar ~ phrase_type *preview_type  +prediction + (1 + phrase_type +preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

depvar.lmer10 = glmer(depvar ~ phrase_type *preview_type  +prediction + (0 + phrase_type +preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
####Run successfully without any warning messages or errors.
depvar.lmer11a = glmer(depvar ~ phrase_type *preview_type  +prediction  + (1 +preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11a, corr = FALSE)

##### 11b.
depvar.lmer11b = glmer(depvar ~ phrase_type *preview_type +prediction  + (1 + phrase_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

depvar.lmer12a = glmer(depvar ~ phrase_type *preview_type  +prediction  + (1|pp) + (0 + phrase_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12a, corr = FALSE)

#### 12b.

depvar.lmer12b = glmer(depvar ~ phrase_type *preview_type   +prediction + (1|pp) + (0 +preview_type|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12b, corr = FALSE)

# 13. Intercepts only

depvar.lmer13 = glmer(depvar ~ phrase_type *preview_type  +prediction + (1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer13, corr = FALSE)

depvar.lmer13 = glmer(depvar ~ phrase_type *preview_type +prediction  + (1|pp) , datafile, family = binomial)
summary(depvar.lmer13, corr = FALSE)

######################################################################

###CI confidence Interation
confint(depvar.lmer13, method="Wald")
######################################################################
################Simple effect######################################################
#Preview effect for different target word
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,0,0,# ID vs Pseudocharacter for word
                                                    0,0,-0.5,+0.5,0,0,# ID vs Pseudocharacter for MCUs
                                                    0,0,0,0,-0.5,+0.5)  # ID vs Pseudocharacter for phrase
                                                  ,6,3),3)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.glmer <- glmer(depvar ~ condition  +prediction + (1+condition|pp) + (1+condition|stim), datafile, family = binomial)
summary(contrast1.glmer, corr = FALSE)

#### #Part2-TARGET WORDS ANALYSES  when predictability was included as  a covariate-Confidence interval ####
confint(contrast1.glmer, method="Wald") # calculate CI of the model you run.


#################################THE END##############################