# This code for processing of popular internet phrases experiment.
## This R script was originally run using R version 4.2.2 and Rstudio version 2023.03.1+446

# There are mainly two parts of analyses.
# Part1 The code for continuous variables (FFD,SFD,GD,TFD,Go-past) for the first constituent (n+1), the second constituent (n+2) and the the whole region.
# Part2 The code for  binomial variable (skipping) for the first constituent (n+1), the second constituent (n+2) and the the whole region.

# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.

##Note: in this code
#Identity was labelled as ID
#Pseudocharacter was labelled as IN
#high familiarity was labelled as NH
#low familiarity was labelled as NL

#### Libraries needed to run the current R code ####
library(languageR)#version 1.5.0
library(lme4)     #version 1.1-33
library(lattice)  #version 0.21-8
library(lmerTest) #if you want p values for your lmer model #version 3.1-3 
library(MASS)     #version 7.3-60 
library(plyr)     #version 1.8.8 
sessionInfo()
#### Clean up####
rm(list=ls())

#### Part1-TARGET WORDS ANALYSES-Continuous dependent variables####
# 1.Load data
# Open your datafile in a raw editor to see how the columns are separated and what character is used for decimal points.
# open the csv.file according to data name.
datafile = read.csv(file.choose(), sep = ",", dec = ".")

head(datafile) #generally check the file you have imported

measure = "IA_FIRST_FIXATION_DURATION"
# add to dataframe
datafile$depvar = datafile[,measure]
# 2.Set up variables 
colnames(datafile) #checked the column names
col.pp = 1    #specify which column your participant number is in,participant
col.stim =2    #specify which column your stim number is in,trial
col.n1 =3 #specify which column phrase_type number is
col.n2 =4 #specify which column  preview_type_type number is
col.condition =5
#specify which column conditon number is
##col.prediction = 9
head(datafile)

#### Part1-Work out which colums the fixed and random factors are in####

datafile$stim = datafile[,col.stim]
datafile$pp = datafile[,col.pp]
#### Part1-TARGET WORDS ANALYSES-Making sure all variables are correct class ####
str(datafile)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$n2 = as.factor(datafile$n2)
datafile$n1 = as.factor(datafile$n1)
datafile$condition = as.factor(datafile$condition)
#datafile$prediction = as.numeric(datafile$prediction)
datafile$depvar = as.numeric(datafile$depvar)



#### Part1-TARGET WORDS ANALYSES-Remove outlier ####
# Remove data outside 3 standard deviations
head(datafile) #let's first have a look
nrcolumns = ncol(datafile)   
# make a new datafile with eye movement measures > 0
between1 = datafile[datafile$depvar > 0, ]
head(between1)
between1 = datafile
#make a matrix with the means per subject 
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp ), sd, na.rm = T)
sd.matrix
# add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
# make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]
# you might want to clean up this data file by removing the added columns
result = result[,1:nrcolumns]
tussen1 = result# insert the name from the datafile coming from the clean up on the right
nrow(datafile)-nrow(tussen1) # calculate how many row you removed
# calculate how many row rate
rate=(nrow(datafile)-nrow(tussen1))/nrow(datafile) 
rate 
datafile = tussen1 
nrow(datafile)# checked the observations after remove outlier

#### Part1-TARGET WORD ANALYSES-Means,Standard Deviations and Standard Errors####
##Code for calculating means between per pp and per condition
mean.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.tt
sd.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.tt
## then calculate the grand mean by condition
grand.mean=apply(mean.tt, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.tt, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(94)  ## this number is the total number of participants from your data, so it is changable.
grand.se
# Paste the results into .txt file

#### Part1-TARGET WORD ANALYSES-Datavisualization ####
# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # log transform data
# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar) 
# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)

####Part1-TARGET ANALYSES-Linear Mixed Models (LMM)####
# 1.Check the levels of  preview_type_type and phrase_type
levels(datafile$ n2)
levels(datafile$ n1)
# 2.Do the contrast.
#contrasts(datafile$phrase_type)#
contrasts(datafile$n1) <- contr.sdif(2)
contrasts(datafile$n2) <- contr.sdif(2)


# 3.Run linear mixed-effects models (LMM)
# 1.Full model

depvar.lmer1 = lmer(depvar ~ n1 *  n2 + (1 + n1 *  n2|pp) + (1 + n1 *  n2|stim), datafile)
summary(depvar.lmer1, corr = FALSE)

# 2.Remove correlations of item

depvar.lmer2 = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (0 + n1 *  n2|stim), datafile)
summary(depvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item

depvar.lmer3 = lmer(depvar ~ n1 *  n2   + (1 + n1 *  n2|pp) + (1 + n1 +  n2|stim), datafile)
summary(depvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

depvar.lmer4 = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (0 + n1 +  n2|stim), datafile)
summary(depvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes

depvar.lmer5a = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (1 + n1|stim), datafile)
summary(depvar.lmer5a, corr = FALSE)

### 5b.
depvar.lmer5b = lmer(depvar ~ n1 *  n2+ (1 + n1 *  n2|pp) + (1 +  n2|stim), datafile)
summary(depvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

depvar.lmer6a = lmer(depvar ~ n1 *  n2+ (1 + n1 *  n2|pp) + (1|stim) + (0 + n1|stim), datafile)
summary(depvar.lmer6a, corr = FALSE)

### 6b.
depvar.lmer6b = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (1|stim) + (0 +  n2|stim), datafile)
summary(depvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

depvar.lmer7 = lmer(depvar ~ n1 *  n2  + (1 + n1 *  n2|pp) + (1|stim), datafile)
summary(depvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

depvar.lmer8 = lmer(depvar ~ n1 *  n2  + (0 + n1 *  n2|pp) + (1|stim), datafile)
summary(depvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

depvar.lmer9 = lmer(depvar ~ n1 * n2  + (1 + n1 +  n2|pp) + (1|stim), datafile)
summary(depvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

depvar.lmer10 = lmer(depvar ~ n1 *  n2  + (0 + n1 +  n2|pp) + (1|stim), datafile)
summary(depvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
depvar.lmer11a = lmer(depvar ~ n1 *  n2  + (1 +  n2|pp) + (1|stim), datafile)
summary(depvar.lmer11a, corr = FALSE)

#### 11b.
depvar.lmer11b = lmer(depvar ~ n1 *  n2  + (1 + n1|pp) + (1|stim), datafile)
summary(depvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

depvar.lmer12a = lmer(depvar ~ n1 *  n2  + (1|pp) + (0 + n1|pp) + (1|stim), datafile)
summary(depvar.lmer12a, corr = FALSE)

#### 12b.

depvar.lmer12b = lmer(depvar ~ n1 *  n2  + (1|pp) + (0 +  n2|pp) + (1|stim), datafile)
summary(depvar.lmer12b, corr = FALSE)

# 13. Intercepts only 

depvar.lmer13 = lmer(depvar ~ n1 *  n2  + (1|pp) + (1|stim), datafile)
summary(depvar.lmer13, corr = FALSE)

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(depvar.lmer11a, method="Wald") # calculate CI of the model you run.

########################################################################

####Simple effect###########
### if interaction of n+1preview and n+2preview is significant, then run the code below
#1. n+2preview effect for different n+1preview
levels(datafile$condition)

datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,# 
                                                    0,0,-0.5,+0.5)  # o
                                                  ,4,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

#
#2.n+1preview effect for different n+2preview
datafile$condition <- C(datafile$condition,matrix(c(-0.5,0,+0.5,0,# 
                                                    0,-0.5,0,+0.5)  # 
                                                  ,4,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$condition)
contrast1.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

contrast2.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

#contrast4.lmer <- lmer(depvar ~ condition  +(1|pp), data = datafile)
#summary(contrast1.lmer, corr = FALSE)

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(contrast3.lmer, method="Wald") # calculate CI of the model you run.


##############################################################################
###############################################################################


#### Clean up and notice####
#####part 2###

rm(list=ls())
#NOTICE: The code for SKIP . REGRESSION_OUT.
#After clean up, please run the code above for SKIP. REGRESSION_OUT.

#######load some packages that needed.

library(languageR)#version 1.5.0
library(lme4) #version 1.1-33  
library(lattice) #version 0.21-8 
library(MASS) #version 7.3-60 
library(plyr) #version 1.8.8 
library(lmerTest) #version  3.1-3                            

rm(list=ls()) # Remove any variables

# Open a csv.file of skipping 

datafile = read.csv(file.choose(), sep = ",", dec = ".")

head(datafile) # generally check the file you have imported

nrow(datafile) # check the number of observations

colnames(datafile)   #Display the column names 
col.subject = 2      # specify which column your participant number is in
col.condition = 5    # specify which column contains your condition number
col.stim = 1         # specify which column your item number is in
col.n1 =3 #specify which column phrase_type number is
col.n2 =4 
# choose dependent variable
measure = "IA_REGRESSION_OUT"

# add to dataframe
datafile$depvar = datafile[,measure]

# Work out which colums the fixed and random factors are in

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# Let's make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$n1 = as.factor(datafile$n1)
datafile$n2 = as.factor(datafile$n2)
datafile$prediction = as.numeric(datafile$prediction)
# Set up the baseline of each factor


################################################################

####Calculate Means, Standard Deviations and Standard Errors####

#Make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix

#Make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

## Calculate the grand mean, grand SD, and grand SE by condition
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(80)  ##The number of the participants is 120. 
grand.se

###############################################################################
#center
datafile$prediction = datafile$prediction -mean(datafile$prediction)
# Add contrasts
contrasts(datafile$n1) <- contr.sdif(2)  
contrasts(datafile$n2) <- contr.sdif(2)


##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.
##Testing times were treated as covariate to see whether or not our experimental effects were influenced by testing times.
####For the pre-target, lmer11b run successfully; and for the target, lmer11a run successfully.

# GLME
# 1.Full model
depvar.lmer1 = glmer(depvar ~ n1 *n2   + (1 + n1 *n2|pp) + (1 + n1 *n2|stim), datafile, family = binomial)
summary(depvar.lmer1, corr = FALSE)

# 2.remove correlations of item

depvar.lmer2 = glmer(depvar ~ n1 *n2 + (1 + n1 *n2|pp) + (0 + n1 *n2|stim), datafile, family = binomial)
summary(depvar.lmer2, corr = FALSE)

# 3. remove interactions (with correlation back in) of item

depvar.lmer3 = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1 + n1 +n2|stim), datafile, family = binomial)
summary(depvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

depvar.lmer4 = glmer(depvar ~ n1 *n2 + (1 + n1 *n2|pp) + (0 + n1 +n2|stim), datafile, family = binomial)
summary(depvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes 

depvar.lmer5a = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1 + n1|stim), datafile, family = binomial)
summary(depvar.lmer5a, corr = FALSE)

### 5b. 

depvar.lmer5b = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1 +n2|stim), datafile, family = binomial)
summary(depvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

depvar.lmer6a = glmer(depvar ~ n1 * n2+ (1 + n1 *n2|pp) + (1|stim) + (0 + n1|stim), datafile, family = binomial)
summary(depvar.lmer6a, corr = FALSE)

### 6b.

depvar.lmer6b = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1|stim) + (0 +n2|stim), datafile, family = binomial)
summary(depvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

depvar.lmer7 = glmer(depvar ~ n1 *n2  + (1 + n1 *n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

depvar.lmer8 = glmer(depvar ~ n1 *n2   + (0 + n1 *n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

depvar.lmer9 = glmer(depvar ~ n1 *n2 + (1 + n1 +n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

depvar.lmer10 = glmer(depvar ~ n1 *n2 + (0 + n1 +n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
####Run successfully without any warning messages or errors.
depvar.lmer11a = glmer(depvar ~ n1 *n2  + (1 +n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11a, corr = FALSE)

##### 11b.
depvar.lmer11b = glmer(depvar ~ n1 *n2 + (1 + n1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

depvar.lmer12a = glmer(depvar ~ n1 *n2  + (1|pp) + (0 + n1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12a, corr = FALSE)

#### 12b.

depvar.lmer12b = glmer(depvar ~ n1 *n2  + (1|pp) + (0 +n2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12b, corr = FALSE)

# 13. Intercepts only

depvar.lmer13 = glmer(depvar ~ n1 *n2 + (1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer13, corr = FALSE)

depvar.lmer13 = glmer(depvar ~ n1 *n2 + (1|pp) , datafile, family = binomial)
summary(depvar.lmer13, corr = FALSE)

######################################################################

###CI confidence Interation
confint(depvar.lmer11b, method="Wald")##for pre-target, replace the name of the model with depvar.lmer11b which run successfully

######################################################################

# if interaction of n+1preview and n+2preview is significant, then run the code below
#1. n+2preview effect for different n+1preview
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,# one vs twoT for HF word
                                                    0,0,-0.5,+0.5)  # one vs twoT for LF word

                                                                                                    ,4,2),2)             # ,number of condition, number of contrasts), number of contrasts)

###2. n+1preview effect for different n+2preview
# Let's see how this contrast matrix looks:
datafile$condition <- C(datafile$condition,matrix(c(-0.5,0,+0.5,0,# one vs twoT for HF word
                                                    0,-0.5,0,+0.5)  # one vs twoT for LF word
                                                  ,4,2),2)   

contrasts(datafile$condition)
# Then run the lme
contrast1.glmer <- glmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), datafile, family = binomial)
summary(contrast1.glmer, corr = FALSE)

contrast2.glmer <- glmer(depvar ~ condition  + (1+condition|pp) + (1|stim), datafile, family = binomial)
summary(contrast2.glmer, corr = FALSE)

contrast3.glmer <- glmer(depvar ~ condition  + (1|pp) + (1|stim), datafile, family = binomial)
summary(contrast3.glmer, corr = FALSE)


contrast4.glmer <- glmer(depvar ~ condition  + (1|pp) , datafile, family = binomial)
summary(contrast4.glmer, corr = FALSE)

contrast5.glmer <- glmer(depvar ~ condition + (1|stim), datafile, family = binomial)
summary(contrast5.glmer, corr = FALSE)

#### Part2-TARGET WORD ANALYSES-Confidence interval ####
confint(contrast3.glmer, method="Wald") # calculate CI of the model you run.

###CI confidence Interation
confint(depvar.lmer11b, method="Wald")
