################2X2X2##########
# This code for the procossing popular internet phrases and familarity experiment.
## This R script was originally run using R version 4.2.2 and Rstudio version 2023.03.1+446
# There are mainly two parts of analyses.
# Part1 The code for continuous variables (FFD,SFD,GD,TFD,Go-past) for the first constituent (n+1), the second constituent (n+2) and the the whole region.
# Part2 The code for  binomial variable (skipping) for the first constituent (n+1), the second constituent (n+2) and the the whole region.

# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.

##Note: in this code
#Identity was labelled as ID
#Pseudocharacter was labelled as IN
#high familiarity was labelled as NH
#low familiarity was labelled as NL

# Here we will look at two ways of analysing a 2 x 2 x 2 design which has:
#############################################################################

#### Libraries needed to run the current R code ####
library(languageR)#version 1.5.0 
library(lme4)     #version 1.1-33 
library(lattice)  #version 0.21-8  
library(lmerTest) # version 3.1-3  #if you want p values for your lmer model 
library(MASS)     #version 7.3-60 
library(plyr)     #version 1.8.8   
library(yarrr) #version 0.1.5  
library(ggplot2)#version 3.4.2 

sessionInfo()

#### Part1- Continuous dependent variables of target word analyse####
rm(list=ls()) # Remove any variables
# 1.Load data
# open the csv.file according to data name.

#datafile = read.csv(file.choose(),header=TRUE,sep = ",",dec=".") 
datafile = read.csv(file.choose(), sep = ",", dec = ".") 

head(datafile) # generally check the file you have imported
# 2.Set up variables 
colnames(datafile)#checked the column names
col.pp =1   # specify which column your participant number is in
col.condition =5 # specify which column contains your condition number 
col.stim =6 # specify which column your item number is in??sentence??
col.n1_preview=2
col.n2_preview= 3
col.familiarity = 4

measure =  "IA_FIRST_RUN_DWELL_TIME"  # choose dependent variable
# add to dataframe
datafile$depvar = datafile[,measure]

####Part1-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.pp]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]
#datafile$tp = datafile[,col.tp]

#### Part1-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)

datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$n1_preview = as.factor(datafile$n1preview)
datafile$n2_preview_type = as.factor(datafile$n2preview)
datafile$familiarity = as.factor(datafile$familiarity)
str(datafile)

#### Part1-Remove outlier ####
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
head(datafile) #let's first have a look
# make a new datafile with fixation durations > 0 ms
between1 = datafile[datafile$depvar > 0, ]
head(between1)
#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp), sd, na.rm = T)
sd.matrix
#add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
nrow(datafile)
nrow(datafile)-nrow(result) # calculate how many row you removed
# calculate delete rate
rate=(nrow(datafile)-nrow(result))/nrow(datafile)
rate
datafile <-result
nrow(datafile)# checked the observations after remove outlier

#### Part1-Means,Standard Deviations and Standard Errors####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(104) ##The number of the participants is 104. 
grand.se


#### Part1-Data visualization ####

# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # raw data

# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar)
head(datafile) 
#### Part1-Means,Standard Deviations and Standard Errors####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(104) ##The number of the participants is . 
grand.se
# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)



####Part1-Linear Mixed Models (LMM)####
# 1.Check the levels of wordlength and word frequency
levels(datafile$n1_preview) # Phrase,Idioms
levels(datafile$n2_preview)# identity,Pseudo
levels(datafile$familiarity)


# 2. Add contrasts
contrasts(datafile$n1_preview) <- contr.sdif(2)
contrasts(datafile$n2_preview) <- contr.sdif(2)
contrasts(datafile$familiarity) <- contr.sdif(2)
####################################################################################
# 3.Run linear mixed-effects models (LMM)
##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.

# 1.Full model

Adepvar.lmer1 = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview * n2_preview* familiarity|stim), datafile)
summary(Adepvar.lmer1, corr = FALSE)

# 2.Remove correlations of item

Adepvar.lmer2 = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview * n2_preview* familiarity|stim), datafile)
summary(Adepvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item

Adepvar.lmer3 = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview + n2_preview + familiarity|stim), datafile)
summary(Adepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

Adepvar.lmer4 = lmer(depvar ~ n1_preview * n2_preview* familiarity  + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview + n2_preview + familiarity|stim), datafile)
summary(Adepvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes

Adepvar.lmer5a = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n2_preview* familiarity|stim), datafile)
summary(Adepvar.lmer5a, corr = FALSE)

# 5b. remove one of the slopes
Adepvar.lmer5b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview* familiarity|stim), datafile)
summary(Adepvar.lmer5b, corr = FALSE)

# 5c. remove one of the slopes
Adepvar.lmer5c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview * n2_preview|stim), datafile)
summary(Adepvar.lmer5c, corr = FALSE)


# 6a. remove one of the slopes, without correlation
Adepvar.lmer6a = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n2_preview* familiarity|stim), datafile)
summary(Adepvar.lmer6a, corr = FALSE)

# 6b.remove one of the slopes, without correlation
Adepvar.lmer6b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview * familiarity|stim), datafile)
summary(Adepvar.lmer6b, corr = FALSE)

# 6c remove one of the slopes, without correlation
Adepvar.lmer6c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview * n2_preview|stim), datafile)
summary(Adepvar.lmer6c, corr = FALSE)

# 7a. remove one of the slopes, Remove interactions (with correlation back in) of item

Adepvar.lmer7a = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n2_preview + familiarity|stim), datafile)
summary(Adepvar.lmer7a, corr = FALSE)

# 7b. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.lmer7b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview + familiarity|stim), datafile)
summary(Adepvar.lmer7b, corr = FALSE)

# 7c. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.lmer7c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview + n2_preview|stim), datafile)
summary(Adepvar.lmer7c, corr = FALSE)

# 8a. remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8a = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n2_preview + familiarity|stim), datafile)
summary(Adepvar.lmer8a, corr = FALSE)

# 8b. remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview + familiarity|stim), datafile)
summary(Adepvar.lmer8b, corr = FALSE)

# 8c.  remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview + n2_preview|stim), datafile)
summary(Adepvar.lmer8c, corr = FALSE)

# 9a. remove two of the two slopes

Adepvar.lmer9a = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview|stim), datafile)
summary(Adepvar.lmer9a, corr = FALSE)

# 9b. remove two of the two slopes
Adepvar.lmer9b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + familiarity|stim), datafile)
summary(Adepvar.lmer9b, corr = FALSE)

# 9c.remove two of the two slopes
Adepvar.lmer9c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n2_preview|stim), datafile)
summary(Adepvar.lmer9c, corr = FALSE)

# 10a.remove two of the two slopes,Remove correlations of item

Adepvar.lmer10a = lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1|stim) + (0 + n1_preview|stim), datafile)
summary(Adepvar.lmer10a, corr = FALSE)

# 10b.remove two of the two slopes,Remove correlations of item

Adepvar.lmer10b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) +  (1|stim) + (0 + familiarity|stim), datafile)
summary(Adepvar.lmer10b, corr = FALSE)

# 10c.remove two of the two slopes,Remove correlations of item
Adepvar.lmer10c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) +  (1|stim) + (0 + n2_preview|stim), datafile)
summary(Adepvar.lmer10c, corr = FALSE)

# 11. remove two of the two slopes,Intercept only for item
Adepvar.lmer11 =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer11, corr = FALSE)

# 12.Remove correlations of pp
Adepvar.lmer12 =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview * n2_preview* familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer12, corr = FALSE)

# 13.Remove interactions (with correlation back in) of pp
Adepvar.lmer13 =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview + n2_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer13, corr = FALSE)

############################# 14.Remove correlation and interactions of pp######
Adepvar.lmer14 =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview + n2_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer14, corr = FALSE)
##############################
# 15a. Remove one of the slopes 1
Adepvar.lmer15a =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n2_preview * familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15a, corr = FALSE)

# 15b. Remove one of the slopes 2
Adepvar.lmer15b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15b, corr = FALSE)

# 15c. Remove one of the slopes 3
Adepvar.lmer15c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15c, corr = FALSE)

# 16a. Remove one of the slopes 1- Remove correlations of pp
Adepvar.lmer16a =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n2_preview * familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16a, corr = FALSE)


# 16b. Remove one of the slopes 2- Remove correlations of pp
Adepvar.lmer16b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview * familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16b, corr = FALSE)

# 16c. Remove one of the slopes 3- Remove correlations of pp
Adepvar.lmer16c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview * n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16c, corr = FALSE)

# 17a. Remove one of the slopes 1- Remove interactions (with correlation back in) of pp
Adepvar.lmer17a =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n2_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17a, corr = FALSE)

# 17b. Remove one of the slopes 2- Remove interactions (with correlation back in) of pp
Adepvar.lmer17b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17b, corr = FALSE)

# 17c. Remove one of the slopes 3- Remove interactions (with correlation back in) of pp
Adepvar.lmer17c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview + n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17c, corr = FALSE)

# 18a. Remove one of the slopes 1- Remove correlation and interactions of pp
Adepvar.lmer18a =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n2_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18a, corr = FALSE)

# 18b. Remove one of the slopes 2- Remove correlation and interactions of pp
Adepvar.lmer18b =  lmer(depvar ~n1_preview * n2_preview* familiarity + (0 + n1_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18b, corr = FALSE)

# 18c. Remove one of the slopes 3- Remove correlation and interactions of pp
Adepvar.lmer18c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview + n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18c, corr = FALSE)

# 19a. Remove two of the slopes 1
Adepvar.lmer19a =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 +n1_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19a, corr = FALSE)

# 19b. Remove two of the slopes 2
Adepvar.lmer19b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19b, corr = FALSE)

# 19c. Remove two of the slopes 3
Adepvar.lmer19c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19c, corr = FALSE)

# 20a. Remove two of the slopes 1- Remove correlations of pp 
Adepvar.lmer20a =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1|pp) +(0 + n1_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20a, corr = FALSE)

# 20b. Remove two of the slopes 1- Remove correlations of pp 
Adepvar.lmer20b =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1|pp) +(0 + n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20b, corr = FALSE)

# 20c. Remove two of the slopes 1- Remove correlations of pp 
Adepvar.lmer20c =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1|pp) +(0 + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20c, corr = FALSE)

# 21. Intercept only
Adepvar.lmer21 =  lmer(depvar ~ n1_preview * n2_preview* familiarity + (1|pp) +  (1|stim), datafile)
summary(Adepvar.lmer21, corr = FALSE)

#####CI####
confint(Adepvar.lmer19c, method="Wald") 
tab_model(Adepvar.lmer18a, show.se = TRUE, show.stat = TRUE,auto.label = F)



########################skip#####################################################

#### Libraries needed to run the current R code ####
library(languageR)#version 1.5.0 
library(lme4)     #version 1.1-33 
library(lattice)  #version 0.21-8  
library(lmerTest) # version 3.1-3  #if you want p values for your lmer model 
library(MASS)     #version 7.3-60 
library(plyr)     #version 1.8.8   
library(yarrr) #version 0.1.5  
library(ggplot2)#version 3.4.2 

sessionInfo()

#### Part1- Continuous dependent variables of target word analyse####
rm(list=ls()) # Remove any variables
# 1.Load data
# open the csv.file according to data name.

#datafile = read.csv(file.choose(),header=TRUE,sep = ",",dec=".") 
datafile = read.csv(file.choose(), sep = ",", dec = ".") 

head(datafile) # generally check the file you have imported
# 2.Set up variables 
colnames(datafile)#checked the column names
col.pp =1   # specify which column your participant number is in
col.condition =5 # specify which column contains your condition number 
col.stim =6 # specify which column your item number is in??sentence??
col.n1_preview=2
col.n2_preview= 3
col.familiarity = 4
#col.tp = 9

measure =  "IA_REGRESSION_OUT"  # choose dependent variable
# add to dataframe
datafile$depvar = datafile[,measure]

####Part1-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.pp]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]
#datafile$tp = datafile[,col.tp]

#### Part1-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)

datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$n1_preview = as.factor(datafile$n1preview)
datafile$n2_preview_type = as.factor(datafile$n2preview)
datafile$familiarity = as.factor(datafile$familiarity)
str(datafile)

####Calculate Means, Standard Deviations and Standard Errors####

#Make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix

#Make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

## Calculate the grand mean, grand SD, and grand SE by condition
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(104)  ##The number of the participants is 120. 
grand.se

# 1.Check the levels of VARIABLES
levels(datafile$n1_preview) 
levels(datafile$n2_preview)# 
levels(datafile$familiarity)
# 2. Add contrasts
contrasts(datafile$n1_preview) <- contr.sdif(2)
contrasts(datafile$n2_preview) <- contr.sdif(2)
contrasts(datafile$familiarity) <- contr.sdif(2)
####################################################################################
# 3.Run linear mixed-effects models (LMM)
##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.

# 1.Full model

Adepvar.lmer1 =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview * n2_preview* familiarity|stim), datafile)
summary(Adepvar.lmer1, corr = FALSE)

# 2.Remove correlations of item

Adepvar.lmer2 =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview * n2_preview* familiarity|stim), datafile)
summary(Adepvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item

Adepvar.lmer3 =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview + n2_preview + familiarity|stim), datafile)
summary(Adepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

Adepvar.lmer4 =  glmer(depvar ~ n1_preview * n2_preview* familiarity  + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview + n2_preview + familiarity|stim), datafile)
summary(Adepvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes

Adepvar.lmer5a =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n2_preview* familiarity|stim), datafile)
summary(Adepvar.lmer5a, corr = FALSE)

# 5b. remove one of the slopes
Adepvar.lmer5b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview* familiarity|stim), datafile)
summary(Adepvar.lmer5b, corr = FALSE)

# 5c. remove one of the slopes
Adepvar.lmer5c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview * n2_preview|stim), datafile)
summary(Adepvar.lmer5c, corr = FALSE)


# 6a. remove one of the slopes, without correlation
Adepvar.lmer6a =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n2_preview* familiarity|stim), datafile)
summary(Adepvar.lmer6a, corr = FALSE)

# 6b.remove one of the slopes, without correlation
Adepvar.lmer6b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview * familiarity|stim), datafile)
summary(Adepvar.lmer6b, corr = FALSE)

# 6c remove one of the slopes, without correlation
Adepvar.lmer6c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview * n2_preview|stim), datafile)
summary(Adepvar.lmer6c, corr = FALSE)

# 7a. remove one of the slopes, Remove interactions (with correlation back in) of item

Adepvar.lmer7a =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n2_preview + familiarity|stim), datafile)
summary(Adepvar.lmer7a, corr = FALSE)

# 7b. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.lmer7b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview + familiarity|stim), datafile)
summary(Adepvar.lmer7b, corr = FALSE)

# 7c. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.lmer7c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview + n2_preview|stim), datafile)
summary(Adepvar.lmer7c, corr = FALSE)

# 8a. remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8a =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n2_preview + familiarity|stim), datafile)
summary(Adepvar.lmer8a, corr = FALSE)

# 8b. remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8b =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview + familiarity|stim), datafile)
summary(Adepvar.lmer8b, corr = FALSE)

# 8c.  remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (0 + n1_preview + n2_preview|stim), datafile)
summary(Adepvar.lmer8c, corr = FALSE)

# 9a. remove two of the two slopes

Adepvar.lmer9a =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n1_preview|stim), datafile)
summary(Adepvar.lmer9a, corr = FALSE)

# 9b. remove two of the two slopes
Adepvar.lmer9b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + familiarity|stim), datafile)
summary(Adepvar.lmer9b, corr = FALSE)

# 9c.remove two of the two slopes
Adepvar.lmer9c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1 + n2_preview|stim), datafile)
summary(Adepvar.lmer9c, corr = FALSE)

# 10a.remove two of the two slopes,Remove correlations of item

Adepvar.lmer10a =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) + (1|stim) + (0 + n1_preview|stim), datafile)
summary(Adepvar.lmer10a, corr = FALSE)

# 10b.remove two of the two slopes,Remove correlations of item

Adepvar.lmer10b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) +  (1|stim) + (0 + familiarity|stim), datafile)
summary(Adepvar.lmer10b, corr = FALSE)

# 10c.remove two of the two slopes,Remove correlations of item
Adepvar.lmer10c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) +  (1|stim) + (0 + n2_preview|stim), datafile)
summary(Adepvar.lmer10c, corr = FALSE)

# 11. remove two of the two slopes,Intercept only for item
Adepvar.lmer11 =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview* familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer11, corr = FALSE)

# 12.Remove correlations of pp
Adepvar.lmer12 =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview * n2_preview* familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer12, corr = FALSE)

# 13.Remove interactions (with correlation back in) of pp
Adepvar.lmer13 =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview + n2_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer13, corr = FALSE)

# 14.Remove correlation and interactions of pp######
Adepvar.lmer14 =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview + n2_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer14, corr = FALSE)
##############################
# 15a. Remove one of the slopes 1
Adepvar.lmer15a =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n2_preview * familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15a, corr = FALSE)

# 15b. Remove one of the slopes 2
Adepvar.lmer15b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15b, corr = FALSE)

# 15c. Remove one of the slopes 3
Adepvar.lmer15c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview * n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15c, corr = FALSE)

# 16a. Remove one of the slopes 1- Remove correlations of pp
Adepvar.lmer16a =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n2_preview * familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16a, corr = FALSE)


# 16b. Remove one of the slopes 2- Remove correlations of pp
Adepvar.lmer16b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview * familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16b, corr = FALSE)

# 16c. Remove one of the slopes 3- Remove correlations of pp
Adepvar.lmer16c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview * n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16c, corr = FALSE)

# 17a. Remove one of the slopes 1- Remove interactions (with correlation back in) of pp
Adepvar.lmer17a =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n2_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17a, corr = FALSE)

# 17b. Remove one of the slopes 2- Remove interactions (with correlation back in) of pp
Adepvar.lmer17b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17b, corr = FALSE)

# 17c. Remove one of the slopes 3- Remove interactions (with correlation back in) of pp
Adepvar.lmer17c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n1_preview + n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17c, corr = FALSE)

# 18a. Remove one of the slopes 1- Remove correlation and interactions of pp
Adepvar.lmer18a =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n2_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18a, corr = FALSE)

# 18b. Remove one of the slopes 2- Remove correlation and interactions of pp
Adepvar.lmer18b =   glmer(depvar ~n1_preview * n2_preview* familiarity + (0 + n1_preview + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18b, corr = FALSE)

# 18c. Remove one of the slopes 3- Remove correlation and interactions of pp
Adepvar.lmer18c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (0 + n1_preview + n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18c, corr = FALSE)

# 19a. Remove two of the slopes 1
Adepvar.lmer19a =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 +n1_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19a, corr = FALSE)

# 19b. Remove two of the slopes 2
Adepvar.lmer19b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19b, corr = FALSE)

# 19c. Remove two of the slopes 3
Adepvar.lmer19c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1 + n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19c, corr = FALSE)

# 20a. Remove two of the slopes 1- Remove correlations of pp 
Adepvar.lmer20a =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1|pp) +(0 + n1_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20a, corr = FALSE)

# 20b. Remove two of the slopes 1- Remove correlations of pp 
Adepvar.lmer20b =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1|pp) +(0 + familiarity|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20b, corr = FALSE)

# 20c. Remove two of the slopes 1- Remove correlations of pp 
Adepvar.lmer20c =   glmer(depvar ~ n1_preview * n2_preview* familiarity + (1|pp) +(0 + n2_preview|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20c, corr = FALSE)

# 21. Intercept only
Adepvar.lmer21 =  glmer(depvar ~ n1_preview * n2_preview* familiarity + (1|pp) +  (1|stim), datafile)
summary(Adepvar.lmer21, corr = FALSE)

#####CI####
confint(Adepvar.lmer19c, method="Wald") 
tab_model(Adepvar.lmer18a, show.se = TRUE, show.stat = TRUE,auto.label = F)



######################################################################

