
###### Foveal and Parafoveal Processing of Chinese Three-character 2+1 MN Idioms in Reading ##

#### Brife Introduction ####
# This code for Experiment 1 regarding Foveal and Parafoveal Processing of Chinese Three-character M+1 MN Idioms in Reading.
# This R script was originally run using R version 3.3.3 and R Studio version 1.1.383. 
# There are mainly two parts of analyses.
# Part1 The code for continuous variables (FFD,SFD,GD,TFD,GP) for the pre-target(n), the first constituent (n+1), the second constituent (n+2) and the the whole region.
# Part2 The code for  binomial variable (skipping) for the pre-target(n), the first constituent (n+1), the second constituent (n+2) and the the whole region.

# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.
# Create a folder which contains all .csv files for target analyses.
# Here we will look at two ways of analysing a 2 x 3 design which has:
# 2 levels of phrase type(idiom, phrase)
# 3 levels of preview type (identity, unrelated character or pseudocharacter)

#### Libraries required to run the current R code ####
library(languageR)#version 1.4.1
library(lme4)     #version 1.1-15
library(lattice)  #version 0.20-34
library(lmerTest) # version 2.0-36 #if you want p values for your lmer model 
library(MASS)     #version 7.3-45
library(plyr)     #version 1.8.4

#### Part1- For FFD, SFD, GD, TFD, GP, analyses for n, n+1, n+2 and the whole region ####
rm(list=ls()) # Remove any variables
# 1.Load data
# open the csv.file according to the data file's name.
datafile = read.csv("n_SFD.csv", header=TRUE,sep = ",",dec=".") # replace the name of the file with the one that you're analysing
head(datafile) # generally check the file you have imported

# 6459 observations for FFD,GD,GP for the pre-target
# 5838 observations for SFD for the pre-target
# 7780 observations for TFD for the pre-target 

# 7099 observations for FFD,GD,GP for the n+1 
# 5978 observations for SFD for the n+1 
# 7998 observations for TFD for the n+1 


# 4443 observations for FFD,GD,GP for the n+2
# 4202 observations for SFD for the n+2 
# 5763 observations for TFD for the n+2 


# 8353 observations for FFD,GD,GP for the whole region
# 4579 observations for SFD for the whole region
# 8716 observations for TFD for the whole region 

# 2.Set up variables 
colnames(datafile) #checked the column names
col.subject =1   # specify which column your participant number is in
col.condition =3 # specify which column contains your condition number 
col.stim =6 # specify which column your item number is in
measure =  "IA_FIRST_FIXATION_DURATION" # choose dependent variable, replace the name of the measure with the one that you're analysing
# add to dataframe
datafile$depvar = datafile[,measure]

####Part1-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

#### Part1-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$phrase_type = as.factor(datafile$phrase_type)
datafile$preview_type = as.factor(datafile$preview_type)
str(datafile)

####Part1-Remove outlier####
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
head(datafile) #let's first have a look
# make a new datafile with fixation durations > 0 ms
between1 = datafile[datafile$depvar > 0, ]
head(between1)
#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp), sd, na.rm = T)
sd.matrix
#add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
nrow(datafile)
nrow(datafile)-nrow(result) # calculate how many rows you have removed
# calculate delete rate
rate=(nrow(datafile)-nrow(result))/nrow(datafile)
rate
datafile <-result
nrow(datafile)# checked the observations after removing outliers

# pre-target
## 6365 for FFD, 5753 for SFD, 6336 for GD, 7647 for TFD, 6315 for GP
# word n+1 region:
## 7001 for FFD, 5899 for SFD, 6983 for GD, 7869 for TFD, 6937 for GP
# word n+2 region:
## 4387 for FFD, 4148 for SFD, 4374 for GD, 5674 for TFD, 4337 for GP
# whole region:
## 8245 for FFD, 4529 for SFD, 8226 for GD, 8587 for TFD, 8194 for GP


####Part1-Means,Standard Deviations and Standard Errors####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(130) ##The number of vaild participants is 130. 
grand.se

####Part1-Data visualization####
# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # log data
# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar)
# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)

####Part1-Linear Mixed Models (LMM)####
## 1.Check the levels of phrase type and preview type
levels(datafile$phrase_type) # Phrase,Idiom
levels(datafile$preview_type) # 1identity,2Incorrect,3Pseudo

## 2.Add contrasts
contrasts(datafile$phrase_type) <- contr.sdif(2)
contrasts(datafile$preview_type) <- contr.sdif(3)

## 3.Run linear mixed-effects models (LMM)
## When we ran the models we always began with full models that included the maximum random effects structure.
## But the slopes were removed if the model failed to converge.
#### We saved the results of lme models that run successfully.
##### For the pre-target(n) analyses, FFD: Adepvar.lmer3, SFD:Adepvar.lmer3, GD: Adepvar.lmer3, TFD: Adepvar.lmer3, GP: Adepvar.lmer4.
##### For the n+1 analyses, FFD: Adepvar.lmer6b, SFD: Adepvar.lmer3, GD: Adepvar.lmer5a, TFD:  Adepvar.lmer3, GP:Adepvar.lmer3.
##### For the n+2 analyses, FFD: Adepvar.lmer3, SFD: Adepvar.lmer3, GD: Adepvar.lmer3 TFD:  Adepvar.lmer3, GP:Adepvar.lmer4.
##### For the whole region analyses,FFD: Adepvar.lmer3, SFD: Adepvar.lmer8, GD: Adepvar.lmer5a, TFD: Adepvar.lmer3, GP:Adepvar.lmer3.

# 1. Full model
Adepvar.lmer1 = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + phrase_type * preview_type|stim), datafile)
summary(Adepvar.lmer1, corr = FALSE)

# 2. Remove correlations for items
Adepvar.lmer2 = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (0 + phrase_type * preview_type|stim), datafile)
summary(Adepvar.lmer2, corr = FALSE)

# 3. Remove interactions (with correlation back in) for items
Adepvar.lmer3 = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type *preview_type|pp) + (1 + phrase_type + preview_type|stim), datafile)
summary(Adepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions for items
Adepvar.lmer4 = lmer(depvar ~ phrase_type *preview_type  + (1 + phrase_type * preview_type|pp) + (0 + phrase_type + preview_type|stim), datafile)
summary(Adepvar.lmer4, corr = FALSE)

# 5a. Remove one of the slopes
Adepvar.lmer5a = lmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1 + phrase_type|stim), datafile)
summary(Adepvar.lmer5a, corr = FALSE)

# 5b. Remove one of the slopes
Adepvar.lmer5b = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + preview_type|stim), datafile)
summary(Adepvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation
Adepvar.lmer6a = lmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile)
summary(Adepvar.lmer6a, corr = FALSE)

# 6b. Again, without correlation
Adepvar.lmer6b = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1|stim) + (0 + preview_type|stim), datafile)
summary(Adepvar.lmer6b, corr = FALSE)

# 7. Intercept only for items
Adepvar.lmer7 = lmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp
Adepvar.lmer8 = lmer(depvar ~ phrase_type * preview_type + (0 + phrase_type * preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp
Adepvar.lmer9 = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type + preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp
Adepvar.lmer10 = lmer(depvar ~ phrase_type * preview_type + (0 + phrase_type + preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
Adepvar.lmer11a = lmer(depvar ~ phrase_type * preview_type + (1 + preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer11a, corr = FALSE)

# 11b. Remove one slope for pp
Adepvar.lmer11b = lmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp
Adepvar.lmer12a = lmer(depvar ~ phrase_type * preview_type + (1|pp) + (0 + phrase_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer12a, corr = FALSE)

# 12b. Again without correlation for pp
Adepvar.lmer12b = lmer(depvar ~ phrase_type *preview_type  + (1|pp) + (0 + preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer12b, corr = FALSE)

# 13. Intercepts only 
Adepvar.lmer13 = lmer(depvar ~ phrase_type * preview_type + (1|pp) + (1|stim), datafile)
summary(Adepvar.lmer13, corr = FALSE)

####Part1-Calculate Confidence Interation#####
confint(Adepvar.lmer3, method="Wald") 

####Part1-Simple effect####
## if interaction of phrase type and preview type is significant, then run the code below
# preview effect for different phrase types
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,0,0,# identical vs incorrect preview for idioms
                                                    0,0,0,-0.5,+0.5,0)  # identical vs incorrect preview for phrases
                                                  ,6,2),2)             # ,number of conditions, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
#####For the n+1 analyses, FFD: contrast1.lmer, SFD: contrast1.lmer, GD: contrast3.lmer, TFD: contrast1.lmer, GP:contrast1.lmer.
#####For the whole region analyses, FFD: contrast1.lmer, SFD: contrast1.lmer, GD: contrast1.lmer,TFD: contrast1.lmer, GP:contrast2.lmer.
# Full model
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

# Remove the slope for items
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

# Remove the slope for items and participants
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)
######################################################################################################################################

########Part2-The code for skipping#########

####Part2-load data####
rm(list=ls()) # Remove any variables
# 1.Load data
datafile = read.csv("n_SKIP.csv", header=TRUE,sep = ",",dec=".")
# 10885 observations for the pre-target n
# 8867 observations for the n+1, n+2 and the compoiste region

head(datafile) #generally check the file you have imported
# 2.Set up variables 
colnames(datafile)#checked the column names
col.subject =1   # specify which column your participant number is in
col.condition =3 # specify which column contains your condition number 
col.stim =6 # specify which column your item number is in
measure =   "IA_SKIP"     # choose dependent variable

####Part2-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]
# add to dataframe
datafile$depvar = datafile[,measure]

####Part2-Make sure all the variables are from the correct class####
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$phrase_type = as.factor(datafile$phrase_type)
datafile$preview_type = as.factor(datafile$preview_type)
str(datafile)

#####Part2-Code for calculating means between per pp and per condition#####
##Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
##Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

##Step2:Calculate the grand mean by conditions 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(130) # The number of the valid participants here is 130.
grand.se

####Part2-Linear Mixed Models (GLME)####
# 1.Check the levels of phrase_type and preview_type
levels(datafile$phrase_type) 
levels(datafile$preview_type) 
# 2. Add contrasts 
contrasts(datafile$phrase_type) <- contr.sdif(2)
contrasts(datafile$preview_type) <- contr.sdif(3)

# 3.Run glme model
#####For the pre-target analyses, Adepvar.glmer11b
#####For the n+1 analyses, Adepvar.glmer13 
#####For the n+2 analyses, Adepvar.glmer13
#####For the whole region analyses, Adepvar.glmer13
# 1.Full model
Adepvar.glmer1 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + phrase_type * preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer1, corr = FALSE)

# 2 .Remove correlations for items
Adepvar.glmer2 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (0 + phrase_type * preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer2, corr = FALSE)

# 3. Remove interactions (with correlation back in) for items
Adepvar.glmer3 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type *preview_type|pp) + (1 + phrase_type + preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer3, corr = FALSE)

# 4. Remove correlation and interactions for items
Adepvar.glmer4 = glmer(depvar ~ phrase_type *preview_type  + (1 + phrase_type * preview_type|pp) + (0 + phrase_type + preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer4, corr = FALSE)

# 5a. Remove one of the slopes
Adepvar.glmer5a = glmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1 + phrase_type|stim), datafile,family = binomial)
summary(Adepvar.glmer5a, corr = FALSE)

# 5b. Remove one of the slopes
Adepvar.glmer5b = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer5b, corr = FALSE)

# 6a. Again, without correlation
Adepvar.glmer6a = glmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile,family = binomial)
summary(Adepvar.glmer6a, corr = FALSE)

# 6b. Again, without correlation
Adepvar.glmer6b = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1|stim) + (0 + preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer6b, corr = FALSE)

# 7. Intercept only for items
Adepvar.glmer7 = glmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer7, corr = FALSE)

# 8. Remove correlation for pp
Adepvar.glmer8 = glmer(depvar ~ phrase_type * preview_type + (0 + phrase_type * preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp
Adepvar.glmer9 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type + preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp
Adepvar.glmer10 = glmer(depvar ~ phrase_type * preview_type + (0 + phrase_type + preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer10, corr = FALSE)

# 11a. Remove one slope for pp
Adepvar.glmer11a = glmer(depvar ~ phrase_type * preview_type + (1 + preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11a, corr = FALSE)

# 11b. Remove one slope for pp
Adepvar.glmer11b = glmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11b, corr = FALSE)

# 12a. Again without correlation for pp
Adepvar.glmer12a = glmer(depvar ~ phrase_type * preview_type + (1|pp) + (0 + phrase_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer12a, corr = FALSE)

# 12b. Again without correlation for pp
Adepvar.glmer12b = glmer(depvar ~ phrase_type *preview_type  + (1|pp) + (0 + preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer12b, corr = FALSE)

# 13. Intercepts only 
Adepvar.glmer13 = glmer(depvar ~ phrase_type * preview_type + (1|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer13, corr = FALSE)

####Part2-Calculate Confidence Interation#####
confint(Adepvar.glmer11b, method="Wald") 

#################################End##############################################