
###### Foveal and Parafoveal Processing of Chinese Three-character 2+1 MN Idioms in Reading ##

#### Brife Introduction ####
# This code for Experiment 2 regarding Foveal and Parafoveal Processing of Chinese Three-character 2+1 MN Idioms in Reading.
# This R script was originally run using R version 3.6.0 and R Studio version 1.1.463. 

# There are mainly two parts for analyses.
# Part1 The code for continuous variables (FFD,SFD,GD,TFD,GP) for the pre-target(n), n+1, n+2 and the whole region.
# Part2 The code for  binomial variable (skipping) for the pre-target(n), n+1, n+2 and the whole region.

# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.
# Create a folder which contains all .csv files for target analyses.
# Here we will look at two ways of analysing a 2 x 2 design for idioms and phrases which has:
# 2 levels of n+1 preview type (identity, pseudocharacter)
# 2 levels of n+2 preview type ((identity, pseudocharacter)

#### Libraries required to run the current R code ####
library(languageR)#version 1.5.0
library(lme4)     #version 1.1-21
library(lattice)  #version 0.20-38
library(lmerTest) # version 3.1-0 #if you want p values for your lmer model 
library(MASS)     #version 7.3-51.4
library(plyr)     #version 1.8.4
#### Part1- For FFD, SFD, GD, TFD, GP, analyses of the pre-target, n+1, n+2 and the whole region analyses####

##Note: in this code
# n+1 preview type was labelled as n1_preview_type
# n+2 preview type was labelled as n2_preview_type

rm(list=ls()) # Remove any variables
# 1.Load data
# open the csv.file according to data name.
datafile = read.csv("ID2_n_FFD_ID.csv", header=TRUE,sep = ",",dec=".") 

# In the pre-target analysis
# 2160 observations for FFD,GD,GP for idioms
# 2167 observations for FFD,GD,GP for phrases
# 2102 observations for SFD for idioms
# 2128 observations for SFD for phrases
# 2922 observations for TFD for idioms 
# 3060 observations for TFD for phrases 

# In the n+1 analysis
# 3632 observations for FFD,GD,GP for idioms 
# 3626 observations for FFD,GD,GP for phrases
# 2838 observations for SFD for idioms
# 2816 observations for SFD for phrases 
# 4090 observations for TFD for idioms 
# 4172 observations for TFD for phrases 

# In the n+2 analysis
# 1973 observations for FFD,GD,GP for idioms
# 2210 observations for FFD,GD,GP for phrases 
# 1921 observations for SFD for idioms 
# 2085 observations for SFD for phrases
# 2509 observations for TFD for idioms 
# 2975 observations for TFD for phrases

# In the whole region analysis
# 4194 observations for FFD,GD,GP for idioms
# 4214observations for FFD,GD,GP for phrases
# 2264 observations for SFD for idioms
# 2145 observations for SFD for phrases 
# 4413 observations for TFD for idioms
# 4404 observations for TFD for phrases

head(datafile) # generally check the file you have imported
# 2.Set up variables 
colnames(datafile) #checked the column names
col.subject =1     # specify which column your participant number is in
col.condition =3   # specify which column contains your condition number 
col.stim =7        # specify which column your item number is in

measure =  "IA_FIRST_FIXATION_DURATION"   # choose dependent variable
# add to dataframe
datafile$depvar = datafile[,measure]

####Part1-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

#### Part1-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$n1_preview_type = as.factor(datafile$n1_preview_type)
datafile$n2_preview_type = as.factor(datafile$n2_preview)
datafile$condition = as.factor(datafile$condition)
str(datafile)

#### Part1-Remove outlier ####
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
head(datafile) #let's first have a look
# make a new datafile with fixation durations > 0 ms
between1 = datafile[datafile$depvar > 0, ]
head(between1)
#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp), sd, na.rm = T)
sd.matrix
#add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
nrow(datafile)
nrow(datafile)-nrow(result) # calculate how many row you removed
# calculate delete rate
rate=(nrow(datafile)-nrow(result))/nrow(datafile)
rate
datafile <-result
nrow(datafile)# checked the observations after remove outlier

# the pre-target
## 2142 for FFD_ID, 2151 for FFD_PH, 2086 for SFD_ID, 2112 for SFD_PH, 2136 for GD_ID, 2141 for GD_PH, 2882 for TFD_ID, 3018 for TFD_PH, 2112 for GP_ID, 2110 for GP_PH
#  n+1 region:
## 3609 for FFD_ID, 3600 for FFD_PH, 2821 for SFD_ID, 2797 for SFD_PH, 3597 for GD_ID, 3589 for GD_PH, 4039 for TFD_ID, 4125 for TFD_PH, 3572 for GP_ID, 3558 for GP_PH
#  n+2 region:
## 1963 for FFD_ID, 2193 for FFD_PH, 1910 for SFD_ID, 2072 for SFD_PH, 1957 for GD_ID, 2198 for GD_PH, 2473 for TFD_ID, 2936 for TFD_PH, 1932 for GP_ID, 2181 for GP_PH
# the whole region:
## 4164 for FFD_ID, 4179 for FFD_PH, 2254 for SFD_ID, 2138 for SFD_PH, 4158 for GD_ID, 4168 for GD_PH, 4360 for TFD_ID, 4355 for TFD_PH, 4135 for GP_ID, 4160 for GP_PH


#### Part1-Means,Standard Deviations and Standard Errors for raw data ####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by conditions 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(136) ##The number of the participants is 136. 
grand.se

#### Part1-Data visualization ####
# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # log data
# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar)
# 3.check the distrubition for every participant
qqmath(~depvar|pp, data = datafile)

####Part1-Linear Mixed Models (LMM)####
# 1.Check the levels
levels(datafile$phrase_type) # Idiom or Phrase
levels(datafile$n1_preview_type) # Identical, Pseudo
levels(datafile$n2_preview_type) # ID, PSE

# 2. Add contrasts
contrasts(datafile$n1_preview_type) <- contr.sdif(2)
contrasts(datafile$n2_preview_type) <- contr.sdif(2)

# 3.Run linear mixed-effects models (LMM)
## When we ran the models we always began with full models that included the maximum random effects structure.
## But the slopes were removed if the model failed to converge.
## We saved the results of lme models that run successfully.

## For the pre-target analyses:
### FFD_ID:Adepvar.lmer14, FFD_PH:Adepvar.lmer13, SFD_ID: Adepvar.lmer11b, SFD_PH:Adepvar.lmer11a???GD_ID:Adepvar.lmer13, GD_PH:Adepvar.lmer11a, TFD_ID:Adepvar.lmer13, TFD_PH:Adepvar.lmer11b, GP_ID:Adepvar.lmer13, GP_PH: Adepvar.lmer13
## For the n+1 analyses:
### FFD_ID: Adepvar.lmer11b, FFD_PH: Adepvar.lmer13, SFD_ID:Adepvar.lmer10, SFD_PH:Adepvar.lmer11b, GD_ID:Adepvar.lmer9, GD_PH:Adepvar.lmer9,TFD_ID:Adepvar.lmer9, TFD_PH:Adepvar.lmer11a, GP_ID: Adepvar.lmer11b, GP_PH: Adepvar.lmer5a
## For the n+2 analyses:
### FFD_ID: Adepvar.lmer11a, FFD_PH: Adepvar.lmer11a, SFD_ID:Adepvar.lmer10, SFD_PH:Adepvar.lmer11a???GD_ID:Adepvar.lmer9, GD_PH:Adepvar.lmer10,TFD_ID:Adepvar.lmer11a, TFD_PH:Adepvar.lmer11b, GP_ID: Adepvar.lmer14, GP_PH: Adepvar.lmer13
## For the whole region analyses:
### FFD_ID: Adepvar.lmer11b, FFD_PH: Adepvar.lmer11b, SFD_ID:Adepvar.lmer9, SFD_PH:Adepvar.lmer11b, GD_ID:Adepvar.lmer9,GD_PH:Adepvar.lmer11a, TFD_ID:Adepvar.lmer11b, TFD_PH:Adepvar.lmer11b, GP_ID:Adepvar.lmer11b, GP_PH: Adepvar.lmer11b

# 1.Full model
Adepvar.lmer1 = lmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (1 + n1_preview_type * n2_preview_type|stim), datafile)
summary(Adepvar.lmer1, corr = FALSE)

# 2.Remove correlations for items
Adepvar.lmer2 = lmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (0 + n1_preview_type * n2_preview_type|stim), datafile)
summary(Adepvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) for items
Adepvar.lmer3 = lmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type *n2_preview_type|pp) + (1 + n1_preview_type + n2_preview_type|stim), datafile)
summary(Adepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions for items
Adepvar.lmer4 = lmer(depvar ~ n1_preview_type *n2_preview_type  + (1 + n1_preview_type * n2_preview_type|pp) + (0 + n1_preview_type + n2_preview_type|stim), datafile)
summary(Adepvar.lmer4, corr = FALSE)


# 5a. remove one of the slopes
Adepvar.lmer5a = lmer(depvar ~ n1_preview_type * n2_preview_type  + (1 + n1_preview_type * n2_preview_type|pp) + (1 + n1_preview_type|stim), datafile)
summary(Adepvar.lmer5a, corr = FALSE)

# 5b.remove one of the slopes
Adepvar.lmer5b = lmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (1 + n2_preview_type|stim), datafile)
summary(Adepvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation
Adepvar.lmer6a = lmer(depvar ~ n1_preview_type * n2_preview_type  + (1 + n1_preview_type * n2_preview_type|pp) + (1|stim) + (0 + n1_preview_type|stim), datafile)
summary(Adepvar.lmer6a, corr = FALSE)

# 6b.Again, without correlation
Adepvar.lmer6b = lmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (1|stim) + (0 + n2_preview_type|stim), datafile)
summary(Adepvar.lmer6b, corr = FALSE)

# 7. Intercept only for items
Adepvar.lmer7 = lmer(depvar ~ n1_preview_type * n2_preview_type  + (1 + n1_preview_type * n2_preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp
Adepvar.lmer8 = lmer(depvar ~ n1_preview_type * n2_preview_type + (0 + n1_preview_type * n2_preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp
Adepvar.lmer9 = lmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type + n2_preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp
Adepvar.lmer10 = lmer(depvar ~ n1_preview_type * n2_preview_type + (0 + n1_preview_type + n2_preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
Adepvar.lmer11a = lmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n2_preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer11a, corr = FALSE)

# 11b.Remove another slope for pp
Adepvar.lmer11b = lmer(depvar ~ n1_preview_type * n2_preview_type  + (1 + n1_preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp
Adepvar.lmer12a = lmer(depvar ~ n1_preview_type * n2_preview_type + (1|pp) + (0 + n1_preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer12a, corr = FALSE)

# 12b.Again without correlation for pp
Adepvar.lmer12b = lmer(depvar ~ n1_preview_type *n2_preview_type  + (1|pp) + (0 + n2_preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer12b, corr = FALSE)

# 13. Intercepts only 
Adepvar.lmer13 = lmer(depvar ~ n1_preview_type * n2_preview_type + (1|pp) + (1|stim), datafile)
summary(Adepvar.lmer13, corr = FALSE)

# 14. Intercepts only for pp
Adepvar.lmer14 = lmer(depvar ~ n1_preview_type * n2_preview_type + (1|pp), datafile)
summary(Adepvar.lmer14, corr = FALSE)

####Part1-Calculate Confidence Interation ####
confint(Adepvar.lmer14, method="Wald") 


####Part1-Simple effect####
# if interaction of phrase type and preview type is significant, then run the code below
# n+2 preview effect for the different n+1 preview type

datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,# n+2 preview effect for the identical n+1 preview
                                            0,0,-0.5,+0.5)  #  n+2 preview effect for the pseudo-character n+1 preview
                                          ,4,2),2)             # ,number of conditions, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
#### For the pre-target analyses###

#####For the n+1 analyses###
# FFD_ID:contrast3.lmer, FFD_PH:contrast4.lmer, SFD_ID:contrast3.lmer, SFD_PH:contrast4.lmer, GD_ID:contrast3.lmer, GD_PH:contrast3.lmer, TFD_ID:contrast3.lmer,TFD_PH:contrast3.lmer, GP_ID:contrast3.lmer
#### For the n+2 analyses ###
# TFD_PH: contrast3.lmer, GP_ID: contrast4.lmer
#####For the whole region analyses###
# FFD_ID:contrast3.lmer, FFD_PH:contrast3.lmer, SFD_ID:contrast4.lmer, SFD_PH:contrast3.lmer, GD_ID:contrast3.lmer, GD_PH:contrast3.lmer, TFD_ID:contrast3.lmer,TFD_PH:contrast3.lmer, GP_ID:contrast3.lmer, GP_PH:contrast3.lmer

# Full model
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

# Remove the slope in item
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

# Remove the slope in item and participant
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

# Only interept for pp
contrast4.lmer <- lmer(depvar ~ condition  +(1|pp), data = datafile)
summary(contrast4.lmer, corr = FALSE)



####Part2-code for Skiping (binary data) ####
rm(list=ls()) # Remove any variables
# 1.Load data
datafile = read.csv("ID2_n_SKIP_ID.csv", header=TRUE,sep = ",",dec=".") 

# the pre-target:5428 observations for idioms, 5432 observations for phrases
#  n+1,  n+2, composite: 4480 observations for idioms, 4462 observations for phrases

head(datafile) #generally check the file you have imported

# 2.Set up variables 
colnames(datafile)#checked the column names
col.subject =1    # specify which column your participant number is in
col.condition =3  # specify which column contains your condition number 
col.stim =7       # specify which column your item number is in

measure = "IA_SKIP"   # choose dependent variable

####Part2-Work out which colums the fixed and random factors are in ####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]
# add to dataframe
datafile$depvar = datafile[,measure]

####Part2-Make sure all the variables are from the correct class####
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$n1_preview_type = as.factor(datafile$n1_preview_type)
datafile$n2_preview_type = as.factor(datafile$n2_preview)
str(datafile)

######Part2-Code for calculating means between per pp and per condition######
##Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

##Step2:Calculate the grand mean by conditions 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(136) # The number of the valid participants here is 136.
grand.se

#### Part2-Generalized Linear Mixed Models (GLMM) ####

# 1.Check the levels of n+1 preview type and n+2 preview type
levels(datafile$phrase_type) # Idiom or Phrase
levels(datafile$n1_preview_type) # Identity,Pseudo
levels(datafile$n2_preview_type) # ID, PSE

# 2. Add contrasts
contrasts(datafile$n1_preview_type) <- contr.sdif(2)
contrasts(datafile$n2_preview_type) <- contr.sdif(2)

# 3.Run generalized linear mixed-effects models (GLMM)

##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.

#####For the pre-target analyses: Idiom: Adepvar.glmer11a, Phrase: Adepvar.glmer7
#####For the n+1 analyses: Idiom: Adepvar.glmer11a, Phrase: Adepvar.glmer13
#####For the n+2 analyses: Idiom: Adepvar.glmer3, Phrase: Adepvar.glmer13 
#####For the whole region analyses: Idiom: Adepvar.glmer13, Phrase: Adepvar.glmer13
# 1.Full model
Adepvar.glmer1 = glmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (1 + n1_preview_type * n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer1, corr = FALSE)

# 2 .Remove correlations for items
Adepvar.glmer2 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (0 + phrase_type * preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer2, corr = FALSE)

# 3. Remove interactions (with correlation back in) for items
Adepvar.glmer3 = glmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (1 + n1_preview_type + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer3, corr = FALSE)

# 4. Remove correlation and interactions for items
Adepvar.glmer4 = glmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (0 + n1_preview_type + n2_preview_type|stim),datafile,family = binomial)
summary(Adepvar.glmer4, corr = FALSE)

# 5a. Remove one of the slopes
Adepvar.glmer5a = glmer(depvar ~ n1_preview_type * n2_preview_type  + (1 + n1_preview_type * n2_preview_type|pp) + (1 + n1_preview_type|stim),datafile,family = binomial)
summary(Adepvar.glmer5a, corr = FALSE)

# 5b. Remove one of the slopes
Adepvar.glmer5b = glmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (1 + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer5b, corr = FALSE)

# 6a. Again, without correlation
Adepvar.glmer6a = glmer(depvar ~ n1_preview_type * n2_preview_type  + (1 + n1_preview_type * n2_preview_type|pp) + (1|stim) + (0 + n1_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer6a, corr = FALSE)

# 6b. Again, without correlation
Adepvar.glmer6b = glmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type * n2_preview_type|pp) + (1|stim) + (0 + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer6b, corr = FALSE)

# 7. Intercept only for items
Adepvar.glmer7 = glmer(depvar ~ n1_preview_type * n2_preview_type  + (1 + n1_preview_type * n2_preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer7, corr = FALSE)

# 8. Remove correlation for pp
Adepvar.glmer8 = glmer(depvar ~ n1_preview_type * n2_preview_type + (0 + n1_preview_type * n2_preview_type|pp) + (1|stim),datafile,family = binomial)
summary(Adepvar.glmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp
Adepvar.glmer9 = glmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n1_preview_type + n2_preview_type|pp) + (1|stim),datafile,family = binomial)
summary(Adepvar.glmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp
Adepvar.glmer10 = glmer(depvar ~ n1_preview_type * n2_preview_type + (0 + n1_preview_type + n2_preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer10, corr = FALSE)

# 11a. Remove one slope for pp
Adepvar.glmer11a = glmer(depvar ~ n1_preview_type * n2_preview_type + (1 + n2_preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11a, corr = FALSE)

# 11b. Remove another slope for pp
Adepvar.glmer11b = glmer(depvar ~ n1_preview_type * n2_preview_type  + (1 + n1_preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11b, corr = FALSE)

# 12a. Again without correlation for pp
Adepvar.glmer12a = glmer(depvar ~ n1_preview_type * n2_preview_type + (1|pp) + (0 + n1_preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer12a, corr = FALSE)

# 12b. Again without another correlation for pp
Adepvar.glmer12b = glmer(depvar ~ n1_preview_type * n2_preview_type  + (1|pp) + (0 + n2_preview_type|pp) + (1|stim),  datafile,family = binomial)
summary(Adepvar.glmer12b, corr = FALSE)

# 13. Intercepts only 
Adepvar.glmer13 = glmer(depvar ~ n1_preview_type * n2_preview_type + (1|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer13, corr = FALSE)

# 14. Intercepts only for pp
Adepvar.glmer14 = glmer(depvar ~ n1_preview_type * n2_preview_type + (1|pp) , datafile,family = binomial)
summary(Adepvar.glmer14, corr = FALSE)

####Part2-Calculate Confidence Interation#####
confint(Adepvar.glmer11a, method="Wald") 


##############Part2 Simple effect#########################################################
# if interaction of phrase type and preview type is significant, then run the code below
## n+2 preview effect for the different n+1 prevew type ##
datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0, # ID vs PSE for the identical n+1 preview 
                                            0,0,-0.5,+0.5)  # ID vs PSE for the pseudocharacter n+1 preview 
                                          ,4,2),2)          # ,number of conditions, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)

# Then run the lme
# Analyses of n+2: SKIP_ID:contrast3.glmer, SKIP_PH:contrast3.glmer
# Full model 
contrast1.glmer <- glmer(depvar ~ condition  +(1 + condition|pp) + (1 + condition|stim), data = datafile,family = binomial)
summary(contrast1.glmer, corr = FALSE)

# Remove the slope for items
contrast2.glmer <- glmer(depvar ~ condition  +(1 + condition|pp) + (1|stim), data = datafile,family = binomial)
summary(contrast2.glmer, corr = FALSE)

# Remove the slope for items and participants
contrast3.glmer <- glmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile,family = binomial)
summary(contrast3.glmer, corr = FALSE)

# Only interept for pp
contrast4.glmer <- glmer(depvar ~ condition  +(1|pp), data = datafile,family = binomial)
summary(contrast4.glmer, corr = FALSE)

####################################End###############################################################

