
#### Brife Introduction ####
# This R script was originally run using R version 3.6.0 and R Studio version 1.1.463. 
# There are mainly two parts for the R script.
# Part1 The code for continuous variables (FFD,SFD,GD,TFD,GP) for pre-target, n+1, n+2 and composite region of idioms and phrases.
# Part2 The code for  binomial variable (i.e. skipping data) for pre-target, n+1, n+2 and composite region of idioms and phrases.
# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.
# Create a folder which contains all .csv files for target analyses.

#### Libraries needed to run the current R code ####
library(languageR)#version 1.5.0
library(lme4)     #version 1.1-21
library(lattice)  #version 0.20-38
library(lmerTest) # version 3.1-0 #if you want p values for your lmer model 
library(MASS)     #version 7.3-51.4
library(plyr)     #version 1.8.4
#### Part1- For FFD, SFD, GD, TFD, GP, analyses of pre-target, n+1, n+2 and composite region analyses####
rm(list=ls()) # Remove any variables
# 1.Load data
# open the csv.file according to data name.
datafile = read.csv("n+1_FFD.csv", header=TRUE,sep = ",",dec=".") 

# 4444 observations for FFD,GD,GP of pre-target
# 4067 observations for SFD of pre-target
# 5343 observations for TFD of pre-target 

# 2248 observations for FFD,GD,GP of word n+1 
# 2197 observations for SFD of word n+1 
# 3159 observations for TFD of word n+1 

# 4726 observations for FFD,GD,GP of word n+2
# 3782 observations for SFD of word n+2 
# 5141 observations for TFD of word n+2 

# 5416 observations for FFD,GD,GP of composite region
# 3169 observations for SFD of composite region
# 5608 observations for TFD of composite region

head(datafile) # generally check the file you have imported
# 2.Set up variables 
colnames(datafile) #checked the column names
col.subject =1     # specify which column your participant number is in
col.condition =3   # specify which column contains your condition number 
col.stim =6        # specify which column your item number is in

measure =  "IA_FIRST_FIXATION_DURATION"   # choose dependent variable
# add to dataframe
datafile$depvar = datafile[,measure]

####Part1-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

#### Part1-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$phrase_type = as.factor(datafile$phrase_type)
datafile$preview_type = as.factor(datafile$preview_type)
datafile$condition = as.factor(datafile$condition)
str(datafile)

#### Part1-Remove outlier ####
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
head(datafile) #let's first have a look
# make a new datafile with fixation durations > 0 ms
between1 = datafile[datafile$depvar > 0, ]
head(between1)
#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp), sd, na.rm = T)
sd.matrix
#add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
nrow(datafile)
nrow(datafile)-nrow(result) # calculate how many row you removed
# calculate delete rate
rate=(nrow(datafile)-nrow(result))/nrow(datafile)
rate
datafile <-result
nrow(datafile)# checked the observations after remove outlier

# pre-target
## 4379 for FFD, 4010 for SFD, 4364 for GD, 4343 for GP, 5248 for TFD
# word n+1 region:
## 2219 for FFD, 2169 for SFD, 2216 for GD, 2202 for GP, 3111 for TFD
# word n+2 region:
## 4671 for FFD, 3737 for SFD, 4654 for GD, 4640 for GP, 5069 for TFD
# composite region:
## 5343 for FFD, 3129 for SFD, 5336 for GD, 5323 for GP, 5520 for TFD


#### Part1-Means,Standard Deviations and Standard Errors for raw data ####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(92) ##The number of the participants is 92. 
grand.se

#### Part1-Data visualization ####
# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # log data
# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar)

#### Part1-Means,Standard Deviations and Standard Errors for log data####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(92) ##The number of the participants is 92. 
grand.se
# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)

####Part1-Linear Mixed Models (LMM)####
# 1.Check the levels
levels(datafile$phrase_type) # Idiom, Phrase
levels(datafile$preview_type) # Identity, Pseudo

# 2. Add contrasts
contrasts(datafile$phrase_type) <- contr.sdif(2)
contrasts(datafile$preview_type) <- contr.sdif(2)

# 3.Run linear mixed-effects models (LMM)
## When we ran the models we always began with full models that included the maximum random effects structure.
## But the slopes were removed if the model failed to converge.
## We saved the results of lme models that run successfully.

## For pre-target analyses:
### FFD:Adepvar.lmer11b, SFD: Adepvar.lmer11b, GD:Adepvar.lmer13, GP:Adepvar.lmer11b, TFD: Adepvar.lmer11a 
## For word n+1 analyses:
### FFD:Adepvar.lmer13, SFD:Adepvar.lmer11a, GD:Adepvar.lmer11a, GP:Adepvar.lmer13, TFD:Adepvar.lmer11a
## For word n+2 analyses:
### FFD:Adepvar.lmer11a, SFD:Adepvar.lmer13, GD:Adepvar.lmer9, GP: Adepvar.lmer9, TFD:Adepvar.lmer10
## For composite region analyses:
### FFD:Adepvar.lmer11a, SFD:Adepvar.lmer11a, GD:Adepvar.lmer11a, GP: Adepvar.lmer11a, TFD:Adepvar.lmer3

# 1.Full model
Adepvar.lmer1 = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + phrase_type * preview_type|stim), datafile)
summary(Adepvar.lmer1, corr = FALSE)

# 2.Remove correlations of item
Adepvar.lmer2 = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (0 + phrase_type * preview_type|stim), datafile)
summary(Adepvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item
Adepvar.lmer3 = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type *preview_type|pp) + (1 + phrase_type + preview_type|stim), datafile)
summary(Adepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item
Adepvar.lmer4 = lmer(depvar ~ phrase_type *preview_type  + (1 + phrase_type * preview_type|pp) + (0 + phrase_type + preview_type|stim), datafile)
summary(Adepvar.lmer4, corr = FALSE)


# 5a. remove one of the slopes
Adepvar.lmer5a = lmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1 + phrase_type|stim), datafile)
summary(Adepvar.lmer5a, corr = FALSE)

# 5b.remove one of the slopes
Adepvar.lmer5b = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + preview_type|stim), datafile)
summary(Adepvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation
Adepvar.lmer6a = lmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile)
summary(Adepvar.lmer6a, corr = FALSE)

# 6b.Again, without correlation
Adepvar.lmer6b = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1|stim) + (0 + preview_type|stim), datafile)
summary(Adepvar.lmer6b, corr = FALSE)

# 7. Intercept only for items
Adepvar.lmer7 = lmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp
Adepvar.lmer8 = lmer(depvar ~ phrase_type * preview_type + (0 + phrase_type * preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp
Adepvar.lmer9 = lmer(depvar ~ phrase_type * preview_type + (1 + phrase_type + preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp
Adepvar.lmer10 = lmer(depvar ~ phrase_type * preview_type + (0 + phrase_type + preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
Adepvar.lmer11a = lmer(depvar ~ phrase_type * preview_type + (1 + preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer11a, corr = FALSE)

# 11b.Remove another slope for pp
Adepvar.lmer11b = lmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp
Adepvar.lmer12a = lmer(depvar ~ phrase_type * preview_type + (1|pp) + (0 + phrase_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer12a, corr = FALSE)

# 12b.Again without correlation for pp
Adepvar.lmer12b = lmer(depvar ~ phrase_type *preview_type  + (1|pp) + (0 + preview_type|pp) + (1|stim), datafile)
summary(Adepvar.lmer12b, corr = FALSE)

# 13. Intercepts only 
Adepvar.lmer13 = lmer(depvar ~ phrase_type * preview_type + (1|pp) + (1|stim), datafile)
summary(Adepvar.lmer13, corr = FALSE)

# 14. Intercepts only for pp
Adepvar.lmer14 = lmer(depvar ~ phrase_type * preview_type + (1|pp), datafile)
summary(Adepvar.lmer14, corr = FALSE)

####Part1-Calculate Confidence Interation ####
confint(Adepvar.lmer13, method="Wald") 


####Part1-Simple effect####
# if internation of phrase type and preview type significant, then run below code
# n+2 preview effect for different n+1 preview type

datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0, # Identity vs Pseudo previwe for idiom
                                            0,0,-0.5,+0.5)  # Identity vs Pseudo previwe for phrase
                                          ,4,2),2)  # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme

#####For word n+2 analyses###
# FFD: contrast3.lmer, SFD:contrast3.lmer, GD:contrast3.lmer, GP:contrast3.lmer???TFD:contrast3.lmer
#####For composite region analyses###
# FFD: contrast3.lmer, GD:contrast3.lmer, GP:contrast2.lmer, TFD:contrast3.lmer

# Full model
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

# Remove the slope in item
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

# Remove the slope in item and participant
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

# Only interept for pp
contrast4.lmer <- lmer(depvar ~ condition  +(1|pp), data = datafile)
summary(contrast4.lmer, corr = FALSE)



####Part2-code for Skiping (binary data) ####
rm(list=ls()) # Remove any variables
# 1.Load data
datafile = read.csv("ID2_n+1_SKIP_ID.csv", header=TRUE,sep = ",",dec=".") 

# pre-target:6979 observations for skipping
# word n+1:5680 observations for skipping 
# word n+2:5680 observations for skipping 
# compoiste:5680 observations for skipping 

head(datafile) #generally check the file you have imported

# 2.Set up variables 
colnames(datafile)#checked the column names
col.subject =1    # specify which column your participant number is in
col.condition =3  # specify which column contains your condition number 
col.stim =6       # specify which column your item number is in

measure = "IA_SKIP"   # choose dependent variable

####Part2-Work out which colums the fixed and random factors are in ####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]
# add to dataframe
datafile$depvar = datafile[,measure]

####Part2-Let's make sure all the variables are from the correct class####
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$phrase_type = as.factor(datafile$phrase_type)
datafile$preview_type = as.factor(datafile$preview_type)
str(datafile)

######Part2-Code for calculating means between per pp and per condition######
##Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(92) # The number of the valid participants here is 136.
grand.se

#### Part2-Generalized Linear Mixed Models (GLMM) ####
# 1.Check the levels of preview type and phrase type
levels(datafile$phrase_type) # Idiom, phrase
levels(datafile$preview_type) # Identity, Pseudo

# 2. Add contrasts
contrasts(datafile$phrase_type) <- contr.sdif(2)
contrasts(datafile$preview_type) <- contr.sdif(2)

# 3.Run generalized linear mixed-effects models (GLMM)

##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.

#####For pre-target analyses: Adepvar.glmer11a
#####For word n+1 analyses: Adepvar.glmer13
#####For word n+2 analyses: Adepvar.glmer11a
#####For composite region analyses: Adepvar.glmer11b 
# 1.Full model
Adepvar.glmer1 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + phrase_type * preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer1, corr = FALSE)

# 2 .Remove correlations of item
Adepvar.glmer2 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (0 + phrase_type * preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer2, corr = FALSE)

# 3. Remove interactions (with correlation back in) of item
Adepvar.glmer3 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + phrase_type + preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer3, corr = FALSE)

# 4. Remove correlation and interactions of item
Adepvar.glmer4 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (0 + phrase_type + preview_type|stim),datafile,family = binomial)
summary(Adepvar.glmer4, corr = FALSE)

# 5a. Remove one of the slopes
Adepvar.glmer5a = glmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1 + phrase_type|stim),datafile,family = binomial)
summary(Adepvar.glmer5a, corr = FALSE)

# 5b. Remove one of the slopes
Adepvar.glmer5b = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1 + preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer5b, corr = FALSE)

# 6a. Again, without correlation
Adepvar.glmer6a = glmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile,family = binomial)
summary(Adepvar.glmer6a, corr = FALSE)

# 6b. Again, without correlation
Adepvar.glmer6b = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type * preview_type|pp) + (1|stim) + (0 + preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer6b, corr = FALSE)

# 7. Intercept only for items
Adepvar.glmer7 = glmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type * preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer7, corr = FALSE)

# 8. Remove correlation for pp
Adepvar.glmer8 = glmer(depvar ~ phrase_type * preview_type + (0 + phrase_type * preview_type|pp) + (1|stim),datafile,family = binomial)
summary(Adepvar.glmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp
Adepvar.glmer9 = glmer(depvar ~ phrase_type * preview_type + (1 + phrase_type + preview_type|pp) + (1|stim),datafile,family = binomial)
summary(Adepvar.glmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp
Adepvar.glmer10 = glmer(depvar ~ phrase_type * preview_type + (0 + phrase_type + preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer10, corr = FALSE)

# 11a. Remove one slope for pp
Adepvar.glmer11a = glmer(depvar ~ phrase_type * preview_type + (1 + preview_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11a, corr = FALSE)

# 11b. Remove another slope for pp
Adepvar.glmer11b = glmer(depvar ~ phrase_type * preview_type  + (1 + phrase_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11b, corr = FALSE)

# 12a. Again without correlation for pp
Adepvar.glmer12a = glmer(depvar ~ phrase_type * preview_type + (1|pp) + (0 + phrase_type|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer12a, corr = FALSE)

# 12b. Again without another correlation for pp
Adepvar.glmer12b = glmer(depvar ~ phrase_type * preview_type  + (1|pp) + (0 + preview_type|pp) + (1|stim),  datafile,family = binomial)
summary(Adepvar.glmer12b, corr = FALSE)

# 13. Intercepts only 
Adepvar.glmer13 = glmer(depvar ~ phrase_type * preview_type + (1|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer13, corr = FALSE)

# 14. Intercepts only for pp
Adepvar.glmer14 = glmer(depvar ~ phrase_type * preview_type + (1|pp) , datafile,family = binomial)
summary(Adepvar.glmer14, corr = FALSE)

####Part2-Calculate Confidence Interation#####
confint(Adepvar.glmer13, method="Wald") 
################################################################END##########################################################################









