
#### Brife Introduction ####
# This code for Experiment regarding Foveal and Parafoveal Processing of Chinese Three-character 1+2 MN and VO Idioms in Reading.
# This R script was originally run using R version 3.6.0 and R Studio version 1.1.463. 

# There are mainly two parts for analyses.
# Part1 The code for continuous variables (FFD,SFD,GD,TFD,GP) for the pre-target(n), n+1, n+2 and the whole region.
# Part2 The code for  binomial variable (skipping) for the pre-target(n), n+1, n+2 and the whole region.

# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.
# Create a folder which contains all .csv files for target analyses.
# Here we will look at two ways of analysing a 2 x 2 x 2  design  which has:
# 2 levels of structure type (Modifier Noun,Verb Object)
# 2 levels of phrase type (idiom,phrase)
# 2 levels of n+2 preview type ((identity, pseudocharacter)

# There are mainly two parts for data analyses.
# Part1 The code for continuous variables in target word analyses(FFD,SFD,GD,TFD,GP)
# Part2 The code for skipping.

# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.

#### Libraries needed to run the current R code ####
library(languageR)#version 1.4.1
library(lme4)     #version 1.1-15
library(lattice)  #version 0.20-34
library(lmerTest) # version 2.0-36 #if you want p values for your lmer model 
library(MASS)     #version 7.3-49
library(plyr)     #version 1.8.4




#### Part1- Continuous dependent variables of target word analyse####
rm(list=ls()) # Remove any variables
# 1.Load data
# open the csv.file according to data name.

datafile = read.csv("N_TFD.csv",header=TRUE,sep = ",",dec=".") 

head(datafile) # generally check the file you have imported
# 2.Set up variables 
colnames(datafile)#checked the column names
col.subject =1    # specify which column your participant number is in
col.condition =3  # specify which column contains your condition number 
col.stim =7       # specify which column your item number is in
col.n2_preview=4  # specify which column your n+2 preview number is in
col.phrase= 5     # specify which column your phrase preview number is in
col.structure = 8 # specify which column your structure type is in
col.tp = 9        # specify which column your TP is in

measure =  "IA_DWELL_TIME"  # choose dependent variable

# add to dataframe
datafile$depvar = datafile[,measure]

####Part1-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]
datafile$tp = datafile[,col.tp]

#### Part1-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)
datafile$tp = as.numeric(datafile$tp)
datafile$predictability = as.numeric(datafile$pre)
#datafile$chara_Åfrequency = as.numeric(datafile$chara_frequency)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$phrase_type = as.factor(datafile$phrase)
datafile$n2_preview_type = as.factor(datafile$n2preview)
datafile$structure = as.factor(datafile$structure)
str(datafile)

#### Part1-Remove outlier ####
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
head(datafile) #let's first have a look
# make a new datafile with fixation durations > 0 ms
between1 = datafile[datafile$depvar > 0, ]
head(between1)
#make a matrix with the means per subject for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject  for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp), sd, na.rm = T)
sd.matrix
#add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
nrow(datafile)
nrow(datafile)-nrow(result) # calculate how many row you removed
# calculate delete rate
rate=(nrow(datafile)-nrow(result))/nrow(datafile)
rate
datafile <-result
nrow(datafile)# checked the observations after remove outlier


#### Part1-Means,Standard Deviations and Standard Errors####

###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(96) ##The number of the participants is 96. 
grand.se

#### Part1-Data visualization ####

# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # raw data

# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar)
head(datafile) 

#### Part1-Means,Standard Deviations and Standard Errors####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(96) ##The number of the participants is 96. 
grand.se
# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)




####Part1-Linear Mixed Models (LMM)####
# 1.Check the levels of wordlength and word frequency
levels(datafile$phrase_type) # Phrase,Idioms
levels(datafile$structure)# identity,Pseudo
levels(datafile$n2_preview_type)

####Part1-Centering the covariate####
#centering  TP
datafile$ctp = datafile$tp -mean(datafile$tp)

#centering  predictability
datafile$cpre = datafile$predictability -mean(datafile$predictability)
head(datafile)

# 2. Add contrasts
contrasts(datafile$phrase_type) <- contr.sdif(2)
contrasts(datafile$structure) <- contr.sdif(2)
contrasts(datafile$n2_preview_type) <- contr.sdif(2)


# 3.Run linear mixed-effects models (LMM)

##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.

# 1.Full model
Adepvar.lmer1 = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type * structure* n2_preview_type|stim), datafile)
summary(Adepvar.lmer1, corr = FALSE)

# 2.Remove correlations of item(省了这步)
Adepvar.lmer2 = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type * structure* n2_preview_type|stim), datafile)
summary(Adepvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item
Adepvar.lmer3 = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure + n2_preview_type|stim), datafile)
summary(Adepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item
Adepvar.lmer4 = lmer(depvar ~ phrase_type * structure* n2_preview_type  + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure + n2_preview_type|stim), datafile)
summary(Adepvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes
Adepvar.lmer5a = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure* n2_preview_type|stim), datafile)
summary(Adepvar.lmer5a, corr = FALSE)

# 5b. remove one of the slopes
Adepvar.lmer5b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* n2_preview_type|stim), datafile)
summary(Adepvar.lmer5b, corr = FALSE)

# 5c. remove one of the slopes
Adepvar.lmer5c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* structure|stim), datafile)
summary(Adepvar.lmer5c, corr = FALSE)


# 6a. remove one of the slopes, without correlation
Adepvar.lmer6a = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure* n2_preview_type|stim), datafile)
summary(Adepvar.lmer6a, corr = FALSE)

# 6b.remove one of the slopes, without correlation
Adepvar.lmer6b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* n2_preview_type|stim), datafile)
summary(Adepvar.lmer6b, corr = FALSE)

# 6c remove one of the slopes, without correlation
Adepvar.lmer6c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* structure|stim), datafile)
summary(Adepvar.lmer6c, corr = FALSE)

# 7a. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.lmer7a = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure + n2_preview_type|stim), datafile)
summary(Adepvar.lmer7a, corr = FALSE)

# 7b. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.lmer7b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + n2_preview_type|stim), datafile)
summary(Adepvar.lmer7b, corr = FALSE)

# 7c. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.lmer7c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure|stim), datafile)
summary(Adepvar.lmer7c, corr = FALSE)

# 8a. remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8a = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure + n2_preview_type|stim), datafile)
summary(Adepvar.lmer8a, corr = FALSE)

# 8b. remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + n2_preview_type|stim), datafile)
summary(Adepvar.lmer8b, corr = FALSE)

# 8c.  remove one of the slopes,  Remove correlation and interactions of item
Adepvar.lmer8c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure|stim), datafile)
summary(Adepvar.lmer8c, corr = FALSE)

# 9a. remove two of the two slopes
Adepvar.lmer9a = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type|stim), datafile)
summary(Adepvar.lmer9a, corr = FALSE)

# 9b. remove two of the two slopes
Adepvar.lmer9b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + n2_preview_type|stim), datafile)
summary(Adepvar.lmer9b, corr = FALSE)

# 9c.remove two of the two slopes
Adepvar.lmer9c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure|stim), datafile)
summary(Adepvar.lmer9c, corr = FALSE)

# 10a.remove two of the two slopes,Remove correlations of item
Adepvar.lmer10a = lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile)
summary(Adepvar.lmer10a, corr = FALSE)

# 10b.remove two of the two slopes,Remove correlations of item
Adepvar.lmer10b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + n2_preview_type|stim), datafile)
summary(Adepvar.lmer10b, corr = FALSE)

# 10c.remove two of the two slopes,Remove correlations of item
Adepvar.lmer10c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + structure|stim), datafile)
summary(Adepvar.lmer10c, corr = FALSE)

# 11. remove two of the two slopes,Intercept only for item
Adepvar.lmer11 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer11, corr = FALSE)

# 12.Remove correlations of pp
Adepvar.lmer12 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer12, corr = FALSE)

# 13.Remove interactions (with correlation back in) of pp
Adepvar.lmer13 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer13, corr = FALSE)

# 14.Remove correlation and interactions of pp
Adepvar.lmer14 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer14, corr = FALSE)

# 15a. Remove one of the slopes 1
Adepvar.lmer15a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + structure * n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15a, corr = FALSE)

# 15b. Remove one of the slopes 2
Adepvar.lmer15b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15b, corr = FALSE)

# 15c. Remove one of the slopes 3
Adepvar.lmer15c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure|pp) +  (1|stim), datafile)
summary(Adepvar.lmer15c, corr = FALSE)

# 16a. Remove one of the slopes 1- Remove correlations of pp
Adepvar.lmer16a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + structure * n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16a, corr = FALSE)


# 16b. Remove one of the slopes 2- Remove correlations of pp
Adepvar.lmer16b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16b, corr = FALSE)

# 16c. Remove one of the slopes 3- Remove correlations of pp
Adepvar.lmer16c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type * structure|pp) +  (1|stim), datafile)
summary(Adepvar.lmer16c, corr = FALSE)

# 17a. Remove one of the slopes 1- Remove interactions (with correlation back in) of pp
Adepvar.lmer17a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17a, corr = FALSE)

# 17b. Remove one of the slopes 2- Remove interactions (with correlation back in) of pp
Adepvar.lmer17b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17b, corr = FALSE)

# 17c. Remove one of the slopes 3- Remove interactions (with correlation back in) of pp
Adepvar.lmer17c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type + structure|pp) +  (1|stim), datafile)
summary(Adepvar.lmer17c, corr = FALSE)

# 18a. Remove one of the slopes 1- Remove correlation and interactions of pp
Adepvar.lmer18a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18a, corr = FALSE)

# 18b. Remove one of the slopes 2- Remove correlation and interactions of pp
Adepvar.lmer18b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18b, corr = FALSE)

# 18c. Remove one of the slopes 3- Remove correlation and interactions of pp
Adepvar.lmer18c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type + structure|pp) +  (1|stim), datafile)
summary(Adepvar.lmer18c, corr = FALSE)

# 19a. Remove two of the slopes 1
Adepvar.lmer19a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 +phrase_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19a, corr = FALSE)

# 19b. Remove two of the slopes 2
Adepvar.lmer19b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19b, corr = FALSE)

# 19c. Remove two of the slopes 3
Adepvar.lmer19c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + structure|pp) +  (1|stim), datafile)
summary(Adepvar.lmer19c, corr = FALSE)

# 20a. Remove two of the slopes 1- Remove correlations of pp (可以省)
Adepvar.lmer20a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp) +(0 + phrase_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20a, corr = FALSE)

# 20b. Remove two of the slopes 1- Remove correlations of pp (可以省)
Adepvar.lmer20b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp) +(0 + n2_preview_type|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20b, corr = FALSE)

# 20c. Remove two of the slopes 1- Remove correlations of pp (可以省)
Adepvar.lmer20c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp) +(0 + structure|pp) +  (1|stim), datafile)
summary(Adepvar.lmer20c, corr = FALSE)

# 21. Intercept only
Adepvar.lmer21 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp) +  (1|stim), datafile)
summary(Adepvar.lmer21, corr = FALSE)

confint(Adepvar.lmer19a, method="Wald") 



##############Part1-Simple Effect#########################################################

###n+2 preview effect for different structure

datafile$PS <- C(datafile$condition,matrix(c(-0.5,+0.5,-0.5,+0.5,0,0,0,0, # Consistent vs inconsistent preview for MN target
                                                0,0,0,0,-0.5,+0.5,-0.5,+0.5)  # Consistent vs inconsistent preview for OV target
                                                  ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$PS)

# Then run the lme
contrast1.lmer <- lmer(depvar ~ PS  +(1+PS|pp) + (1+PS|stim),data = datafile)
summary(contrast1.lmer, corr = FALSE)

contrast2.lmer <- lmer(depvar ~ PS  +(1 + PS|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

contrast3.lmer <- lmer(depvar ~ PS  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

confint(contrast3.lmer, method="Wald")



##structure effect for different n+2 preview

datafile$SP<- C(datafile$condition,matrix(c(-0.5,0,-0.5,0,+0.5,0,+0.5,0, # MN vs OV for Consistent preview
                                            0,-0.5,0,-0.5,0,+0.5,0,+0.5)  #  MN vs OV for inconsistent preview
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$SP)

# Then run the lme
contrast1.lmer <- lmer(depvar ~ SP  +(1+SP|pp) + (1+SP|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

contrast2.lmer <- lmer(depvar ~ SP  +(1 + SP|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

contrast3.lmer <- lmer(depvar ~ SP  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)


confint(contrast3.lmer, method="Wald")


## Phrase type effect for different structure

datafile$SP<- C(datafile$condition,matrix(c(-0.5,-0.5,+0.5,+0.5,0,0,0,0, # Idiom vs phrase for MN target
                                            0,0,0,0,-0.5,-0.5,+0.5,+0.5)  #  Idiom vs phrase for OV target
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$SP)

# Then run the lme
contrast1.lmer <- lmer(depvar ~ SP  +(1+SP|pp) + (1+SP|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)


contrast2.lmer <- lmer(depvar ~ SP  +(1 + SP|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)


contrast3.lmer <- lmer(depvar ~ SP  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)



confint(contrast3.lmer, method="Wald")



##structure effect for different phrase type

datafile$SP<- C(datafile$condition,matrix(c(-0.5,-0.5,0,0,+0.5,+0.5,0,0, # MN vs OV for Idiom
                                            0,0,-0.5,-0.5,0,0,+0.5,+0.5)  #  MN vs OV for phrase
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$SP)

# Then run the lme
contrast1.lmer <- lmer(depvar ~ SP  +(1+SP|pp) + (1+SP|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

contrast2.lmer <- lmer(depvar ~ SP  +(1 + SP|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

contrast3.lmer <- lmer(depvar ~ SP  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)


confint(contrast3.lmer, method="Wald")





##n+2 preview type for different phrase type 


datafile$SP<- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,-0.5,+0.5,0,0, # Consistent vs inconsistent for idiom
                                            0,0,-0.5,+0.5,0,0,-0.5,+0.5)  #  Consistent vs inconsistent for phrase
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$SP)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ SP  +(1+SP|pp) + (1+SP|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)


contrast2.lmer <- lmer(depvar ~ SP  +(1 + SP|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

contrast3.lmer <- lmer(depvar ~ SP  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)


confint(contrast3.lmer, method="Wald")

##phrase type for different n+2 preview


datafile$SP<- C(datafile$condition,matrix(c(-0.5,0,+0.5,0,-0.5,0,+0.5,0, # Idiom vs phrase for consistent preview
                                            0,-0.5,0,+0.5,0,-0.5,0,+0.5) # Idiom vs phrase for inconsistent preview
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$SP)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ SP  +(1+SP|pp) + (1+SP|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)

contrast2.lmer <- lmer(depvar ~ SP  +(1 + SP|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)

contrast3.lmer <- lmer(depvar ~ SP  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)


contrast4.lmer <- lmer(depvar ~ SP  +(1|pp), data = datafile)
summary(contrast4.lmer, corr = FALSE)

confint(contrast4.lmer, method="Wald")




########Part1-Run the model when TP as covariate #########

# Run linear mixed-effects models (LMM)
##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.

# 1.Full model
Bdepvar.lmer1 = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type * structure* n2_preview_type|stim), datafile)
summary(Bdepvar.lmer1, corr = FALSE)

# 2.Remove correlations of item(省了这步)
Bdepvar.lmer2 = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type * structure* n2_preview_type|stim), datafile)
summary(Bdepvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item
Bdepvar.lmer3 = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure + n2_preview_type|stim), datafile)
summary(Bdepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item
Bdepvar.lmer4 = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp  + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure + n2_preview_type|stim), datafile)
summary(Bdepvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes
Bdepvar.lmer5a = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp  + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure* n2_preview_type|stim), datafile)
summary(Bdepvar.lmer5a, corr = FALSE)

# 5b. remove one of the slopes
Bdepvar.lmer5b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* n2_preview_type|stim), datafile)
summary(Bdepvar.lmer5b, corr = FALSE)

# 5c. remove one of the slopes
Bdepvar.lmer5c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* structure|stim), datafile)
summary(Bdepvar.lmer5c, corr = FALSE)


# 6a. remove one of the slopes, without correlation
Bdepvar.lmer6a = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure* n2_preview_type|stim), datafile)
summary(Bdepvar.lmer6a, corr = FALSE)

# 6b.remove one of the slopes, without correlation
Bdepvar.lmer6b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* n2_preview_type|stim), datafile)
summary(Bdepvar.lmer6b, corr = FALSE)

# 6c remove one of the slopes, without correlation
Bdepvar.lmer6c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* structure|stim), datafile)
summary(Bdepvar.lmer6c, corr = FALSE)

# 7a. remove one of the slopes, Remove interactions (with correlation back in) of item
Bdepvar.lmer7a = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure + n2_preview_type|stim), datafile)
summary(Bdepvar.lmer7a, corr = FALSE)

# 7b. remove one of the slopes, Remove interactions (with correlation back in) of item
Bdepvar.lmer7b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + n2_preview_type|stim), datafile)
summary(Bdepvar.lmer7b, corr = FALSE)

# 7c. remove one of the slopes, Remove interactions (with correlation back in) of item
Bdepvar.lmer7c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure|stim), datafile)
summary(Bdepvar.lmer7c, corr = FALSE)

# 8a. remove one of the slopes,  Remove correlation and interactions of item
Bdepvar.lmer8a = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure + n2_preview_type|stim), datafile)
summary(Bdepvar.lmer8a, corr = FALSE)

# 8b. remove one of the slopes,  Remove correlation and interactions of item
Bdepvar.lmer8b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + n2_preview_type|stim), datafile)
summary(Bdepvar.lmer8b, corr = FALSE)

# 8c.  remove one of the slopes,  Remove correlation and interactions of item
Bdepvar.lmer8c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure|stim), datafile)
summary(Bdepvar.lmer8c, corr = FALSE)

# 9a. remove two of the two slopes
Bdepvar.lmer9a = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type|stim), datafile)
summary(Bdepvar.lmer9a, corr = FALSE)

# 9b. remove two of the two slopes
Bdepvar.lmer9b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + n2_preview_type|stim), datafile)
summary(Bdepvar.lmer9b, corr = FALSE)

# 9c.remove two of the two slopes
Bdepvar.lmer9c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure|stim), datafile)
summary(Bdepvar.lmer9c, corr = FALSE)

# 10a.remove two of the two slopes,Remove correlations of item（可以省掉）
Bdepvar.lmer10a = lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile)
summary(Bdepvar.lmer10a, corr = FALSE)

# 10b.remove two of the two slopes,Remove correlations of item（可以省掉）
Bdepvar.lmer10b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + n2_preview_type|stim), datafile)
summary(Bdepvar.lmer10b, corr = FALSE)

# 10c.remove two of the two slopes,Remove correlations of item（可以省掉）
Bdepvar.lmer10c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + structure|stim), datafile)
summary(Bdepvar.lmer10c, corr = FALSE)

# 11. remove two of the two slopes,Intercept only for item
Bdepvar.lmer11 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer11, corr = FALSE)

# 12.Remove correlations of pp
Bdepvar.lmer12 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer12, corr = FALSE)

# 13.Remove interactions (with correlation back in) of pp
Bdepvar.lmer13 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer13, corr = FALSE)

# 14.Remove correlation and interactions of pp
Bdepvar.lmer14 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer14, corr = FALSE)

# 15a. Remove one of the slopes 1
Bdepvar.lmer15a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + structure * n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer15a, corr = FALSE)

# 15b. Remove one of the slopes 2
Bdepvar.lmer15b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer15b, corr = FALSE)

# 15c. Remove one of the slopes 3
Bdepvar.lmer15c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer15c, corr = FALSE)

# 16a. Remove one of the slopes 1- Remove correlations of pp
Bdepvar.lmer16a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + structure * n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer16a, corr = FALSE)

# 16b. Remove one of the slopes 2- Remove correlations of pp
Bdepvar.lmer16b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer16b, corr = FALSE)

# 16c. Remove one of the slopes 3- Remove correlations of pp
Bdepvar.lmer16c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type * structure|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer16c, corr = FALSE)

# 17a. Remove one of the slopes 1- Remove interactions (with correlation back in) of pp
Bdepvar.lmer17a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer17a, corr = FALSE)

# 17b. Remove one of the slopes 2- Remove interactions (with correlation back in) of pp
Bdepvar.lmer17b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer17b, corr = FALSE)

# 17c. Remove one of the slopes 3- Remove interactions (with correlation back in) of pp
Bdepvar.lmer17c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type + structure|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer17c, corr = FALSE)

# 18a. Remove one of the slopes 1- Remove correlation and interactions of pp
Bdepvar.lmer18a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer18a, corr = FALSE)


# 18b. Remove one of the slopes 2- Remove correlation and interactions of pp
Bdepvar.lmer18b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer18b, corr = FALSE)

# 18c. Remove one of the slopes 3- Remove correlation and interactions of pp
Bdepvar.lmer18c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type + structure|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer18c, corr = FALSE)

# 19a. Remove two of the slopes 1
Bdepvar.lmer19a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 +phrase_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer19a, corr = FALSE)

# 19b. Remove two of the slopes 2
Bdepvar.lmer19b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer19b, corr = FALSE)

# 19c. Remove two of the slopes 3
Bdepvar.lmer19c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + structure|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer19c, corr = FALSE)

# 20a. Remove two of the slopes 1- Remove correlations of pp (可以省)
Bdepvar.lmer20a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp) +(0 + phrase_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer20a, corr = FALSE)

# 20b. Remove two of the slopes 1- Remove correlations of pp (可以省)
Bdepvar.lmer20b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp) +(0 + n2_preview_type|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer20b, corr = FALSE)

# 20c. Remove two of the slopes 1- Remove correlations of pp (可以省)
Bdepvar.lmer20c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp) +(0 + structure|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer20c, corr = FALSE)

# 21. Intercept only
Bdepvar.lmer21 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp) +  (1|stim), datafile)
summary(Bdepvar.lmer21, corr = FALSE)

confint(Bdepvar.lmer18a, method="Wald") 




########Part1-Run the model when predicibility as covariate ##############################

# 1.Full model
Cdepvar.lmer1 = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type * structure* n2_preview_type|stim), datafile)
summary(Cdepvar.lmer1, corr = FALSE)

# 2.Remove correlations of item
Cdepvar.lmer2 = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type * structure* n2_preview_type|stim), datafile)
summary(Cdepvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item
Cdepvar.lmer3 = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure + n2_preview_type|stim), datafile)
summary(Cdepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item
Cdepvar.lmer4 = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre  + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure + n2_preview_type|stim), datafile)
summary(Cdepvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes
Cdepvar.lmer5a = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre  + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure* n2_preview_type|stim), datafile)
summary(Cdepvar.lmer5a, corr = FALSE)

# 5b. remove one of the slopes
Cdepvar.lmer5b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* n2_preview_type|stim), datafile)
summary(Cdepvar.lmer5b, corr = FALSE)

# 5c. remove one of the slopes
Cdepvar.lmer5c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* structure|stim), datafile)
summary(Cdepvar.lmer5c, corr = FALSE)


# 6a. remove one of the slopes, without correlation
Cdepvar.lmer6a = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure* n2_preview_type|stim), datafile)
summary(Cdepvar.lmer6a, corr = FALSE)

# 6b.remove one of the slopes, without correlation
Cdepvar.lmer6b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* n2_preview_type|stim), datafile)
summary(Cdepvar.lmer6b, corr = FALSE)

# 6c remove one of the slopes, without correlation
Cdepvar.lmer6c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* structure|stim), datafile)
summary(Cdepvar.lmer6c, corr = FALSE)

# 7a. remove one of the slopes, Remove interactions (with correlation back in) of item
Cdepvar.lmer7a = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure + n2_preview_type|stim), datafile)
summary(Cdepvar.lmer7a, corr = FALSE)

# 7b. remove one of the slopes, Remove interactions (with correlation back in) of item
Cdepvar.lmer7b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + n2_preview_type|stim), datafile)
summary(Cdepvar.lmer7b, corr = FALSE)

# 7c. remove one of the slopes, Remove interactions (with correlation back in) of item
Cdepvar.lmer7c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure|stim), datafile)
summary(Cdepvar.lmer7c, corr = FALSE)

# 8a. remove one of the slopes,  Remove correlation and interactions of item
Cdepvar.lmer8a = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure + n2_preview_type|stim), datafile)
summary(Cdepvar.lmer8a, corr = FALSE)

# 8b. remove one of the slopes,  Remove correlation and interactions of item
Cdepvar.lmer8b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + n2_preview_type|stim), datafile)
summary(Cdepvar.lmer8b, corr = FALSE)

# 8c.  remove one of the slopes,  Remove correlation and interactions of item
Cdepvar.lmer8c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure|stim), datafile)
summary(Cdepvar.lmer8c, corr = FALSE)

# 9a. remove two of the two slopes
Cdepvar.lmer9a = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type|stim), datafile)
summary(Cdepvar.lmer9a, corr = FALSE)

# 9b. remove two of the two slopes
Cdepvar.lmer9b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + n2_preview_type|stim), datafile)
summary(Cdepvar.lmer9b, corr = FALSE)

# 9c.remove two of the two slopes
Cdepvar.lmer9c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure|stim), datafile)
summary(Cdepvar.lmer9c, corr = FALSE)

# 10a.remove two of the two slopes,Remove correlations of item（可以省掉）
Cdepvar.lmer10a = lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile)
summary(Cdepvar.lmer10a, corr = FALSE)

# 10b.remove two of the two slopes,Remove correlations of item（可以省掉）
Cdepvar.lmer10b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + n2_preview_type|stim), datafile)
summary(Cdepvar.lmer10b, corr = FALSE)

# 10c.remove two of the two slopes,Remove correlations of item（可以省掉）
Cdepvar.lmer10c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + structure|stim), datafile)
summary(Cdepvar.lmer10c, corr = FALSE)

# 11. remove two of the two slopes,Intercept only for item
Cdepvar.lmer11 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer11, corr = FALSE)

# 12.Remove correlations of pp
Cdepvar.lmer12 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer12, corr = FALSE)

# 13.Remove interactions (with correlation back in) of pp
Cdepvar.lmer13 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer13, corr = FALSE)

# 14.Remove correlation and interactions of pp
Cdepvar.lmer14 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer14, corr = FALSE)

# 15a. Remove one of the slopes 1
Cdepvar.lmer15a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + structure * n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer15a, corr = FALSE)

# 15b. Remove one of the slopes 2
Cdepvar.lmer15b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer15b, corr = FALSE)

# 15c. Remove one of the slopes 3
Cdepvar.lmer15c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer15c, corr = FALSE)

# 16a. Remove one of the slopes 1- Remove correlations of pp
Cdepvar.lmer16a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + structure * n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer16a, corr = FALSE)

# 16b. Remove one of the slopes 2- Remove correlations of pp
Cdepvar.lmer16b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer16b, corr = FALSE)

# 16c. Remove one of the slopes 3- Remove correlations of pp
Cdepvar.lmer16c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type * structure|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer16c, corr = FALSE)

# 17a. Remove one of the slopes 1- Remove interactions (with correlation back in) of pp
Cdepvar.lmer17a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer17a, corr = FALSE)

# 17b. Remove one of the slopes 2- Remove interactions (with correlation back in) of pp
Cdepvar.lmer17b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer17b, corr = FALSE)

# 17c. Remove one of the slopes 3- Remove interactions (with correlation back in) of pp
Cdepvar.lmer17c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type + structure|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer17c, corr = FALSE)

# 18a. Remove one of the slopes 1- Remove correlation and interactions of pp
Cdepvar.lmer18a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + structure + n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer18a, corr = FALSE)

# 18b. Remove one of the slopes 2- Remove correlation and interactions of pp
Cdepvar.lmer18b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer18b, corr = FALSE)

# 18c. Remove one of the slopes 3- Remove correlation and interactions of pp
Cdepvar.lmer18c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type + structure|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer18c, corr = FALSE)

# 19a. Remove two of the slopes 1
Cdepvar.lmer19a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 +phrase_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer19a, corr = FALSE)

# 19b. Remove two of the slopes 2
Cdepvar.lmer19b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer19b, corr = FALSE)

# 19c. Remove two of the slopes 3
Cdepvar.lmer19c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + structure|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer19c, corr = FALSE)

# 20a. Remove two of the slopes 1- Remove correlations of pp (可以省)
Cdepvar.lmer20a =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp) +(0 + phrase_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer20a, corr = FALSE)

# 20b. Remove two of the slopes 1- Remove correlations of pp (可以省)
Cdepvar.lmer20b =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp) +(0 + n2_preview_type|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer20b, corr = FALSE)

# 20c. Remove two of the slopes 1- Remove correlations of pp (可以省)
Cdepvar.lmer20c =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp) +(0 + structure|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer20c, corr = FALSE)

# 21. Intercept only
Cdepvar.lmer21 =  lmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp) +  (1|stim), datafile)
summary(Cdepvar.lmer21, corr = FALSE)

confint(Cdepvar.lmer19a, method="Wald") 




######## Part2-The code for skipping #########
library(languageR)
library(lme4)
library(lattice)
library(MASS)
library(plyr)
library(lmerTest)
library(yarrr)
library(ggplot2)


rm(list=ls()) # Remove any variables
datafile = read.csv("N_SKIP.csv",header=TRUE,sep = ",",dec=".") 
# 1.Load data
head(datafile) # generally check the file you have imported

# 2.Set up variables 
colnames(datafile)#checked the column names
col.subject =1    # specify which column your participant number is in
col.condition =3  # specify which column contains your condition number 
col.stim =7       # specify which column your item number is in
col.n2_preview=4  # specify which column your n+2 preview number is in
col.phrase= 5     # specify which column your phrase preview number is in
col.structure = 8 # specify which column your structure type is in
col.tp = 9        # specify which column your TP is in

measure = "IA_SKIP"  # choose dependent variable
# add to dataframe
datafile$depvar = datafile[,measure]

####Part2-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]
datafile$tp = datafile[,col.tp]

#### Part2-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)
datafile$tp = as.numeric(datafile$tp)
datafile$predictability = as.numeric(datafile$pre)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$phrase_type = as.factor(datafile$phrase)
datafile$n2_preview_type = as.factor(datafile$n2preview)
datafile$structure = as.factor(datafile$structure)
str(datafile)

#######Part2-Code for calculating means between per pp and per condition######

##Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(96) # The number of the valid participants here is 96.
grand.se




####Part2-GLMM####
# 1.Check the levels of wordlength and word frequency
levels(datafile$phrase_type) # Phrase,Idioms
levels(datafile$structure)# identity,Pseudo
levels(datafile$n2_preview_type)

####Part2-Centering the covariate####
#centering  TP
datafile$ctp = datafile$tp -mean(datafile$tp)

#centering  predictability
datafile$cpre = datafile$predictability -mean(datafile$predictability)
head(datafile)

# 2. Add contrasts
contrasts(datafile$phrase_type) <- contr.sdif(2)
contrasts(datafile$structure) <- contr.sdif(2)
contrasts(datafile$n2_preview_type) <- contr.sdif(2)


# 3.Run linear mixed-effects models (LMM)
##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.

# 1.Full model
Adepvar.glmer1 = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type * structure* n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer1, corr = FALSE)

# 2.Remove correlations of item(省了这步)
Adepvar.glmer2 = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type * structure* n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item
Adepvar.glmer3 = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer3, corr = FALSE)

# 4. Remove correlation and interactions of item
Adepvar.glmer4 = glmer(depvar ~ phrase_type * structure* n2_preview_type  + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer4, corr = FALSE)

# 5a. remove one of the slopes
Adepvar.glmer5a = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure* n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer5a, corr = FALSE)

# 5b. remove one of the slopes
Adepvar.glmer5b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer5b, corr = FALSE)

# 5c. remove one of the slopes
Adepvar.glmer5c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* structure|stim), datafile,family = binomial)
summary(Adepvar.glmer5c, corr = FALSE)


# 6a. remove one of the slopes, without correlation
Adepvar.glmer6a = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure* n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer6a, corr = FALSE)

# 6b.remove one of the slopes, without correlation
Adepvar.glmer6b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer6b, corr = FALSE)

# 6c remove one of the slopes, without correlation
Adepvar.glmer6c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* structure|stim), datafile,family = binomial)
summary(Adepvar.glmer6c, corr = FALSE)

# 7a. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.glmer7a = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer7a, corr = FALSE)

# 7b. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.glmer7b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer7b, corr = FALSE)

# 7c. remove one of the slopes, Remove interactions (with correlation back in) of item
Adepvar.glmer7c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure|stim), datafile,family = binomial)
summary(Adepvar.glmer7c, corr = FALSE)

# 8a. remove one of the slopes,  Remove correlation and interactions of item
Adepvar.glmer8a = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer8a, corr = FALSE)

# 8b. remove one of the slopes,  Remove correlation and interactions of item
Adepvar.glmer8b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer8b, corr = FALSE)

# 8c.  remove one of the slopes,  Remove correlation and interactions of item
Adepvar.glmer8c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure|stim), datafile,family = binomial)
summary(Adepvar.glmer8c, corr = FALSE)

# 9a. remove two of the two slopes
Adepvar.glmer9a = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type|stim), datafile,family = binomial)
summary(Adepvar.glmer9a, corr = FALSE)

# 9b. remove two of the two slopes
Adepvar.glmer9b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer9b, corr = FALSE)

# 9c.remove two of the two slopes
Adepvar.glmer9c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure|stim), datafile,family = binomial)
summary(Adepvar.glmer9c, corr = FALSE)

# 10a.remove two of the two slopes,Remove correlations of item（可以省掉）
Adepvar.glmer10a = glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile,family = binomial)
summary(Adepvar.glmer10a, corr = FALSE)

# 10b.remove two of the two slopes,Remove correlations of item（可以省掉）
Adepvar.glmer10b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + n2_preview_type|stim), datafile,family = binomial)
summary(Adepvar.glmer10b, corr = FALSE)

# 10c.remove two of the two slopes,Remove correlations of item（可以省掉）
Adepvar.glmer10c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + structure|stim), datafile,family = binomial)
summary(Adepvar.glmer10c, corr = FALSE)

# 11. remove two of the two slopes,Intercept only for item
Adepvar.glmer11 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11, corr = FALSE)

# 12.Remove correlations of pp
Adepvar.glmer12 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer12, corr = FALSE)

# 13.Remove interactions (with correlation back in) of pp
Adepvar.glmer13 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer13, corr = FALSE)

# 14.Remove correlation and interactions of pp
Adepvar.glmer14 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer14, corr = FALSE)

# 15a. Remove one of the slopes 1
Adepvar.glmer15a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + structure * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer15a, corr = FALSE)

# 15b. Remove one of the slopes 2
Adepvar.glmer15b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer15b, corr = FALSE)

# 15c. Remove one of the slopes 3
Adepvar.glmer15c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type * structure|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer15c, corr = FALSE)

# 16a. Remove one of the slopes 1- Remove correlations of pp
Adepvar.glmer16a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + structure * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer16a, corr = FALSE)

# 16b. Remove one of the slopes 2- Remove correlations of pp
Adepvar.glmer16b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer16b, corr = FALSE)

# 16c. Remove one of the slopes 3- Remove correlations of pp
Adepvar.glmer16c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type * structure|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer16c, corr = FALSE)

# 17a. Remove one of the slopes 1- Remove interactions (with correlation back in) of pp
Adepvar.glmer17a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer17a, corr = FALSE)

# 17b. Remove one of the slopes 2- Remove interactions (with correlation back in) of pp
Adepvar.glmer17b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer17b, corr = FALSE)

# 17c. Remove one of the slopes 3- Remove interactions (with correlation back in) of pp
Adepvar.glmer17c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + phrase_type + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer17c, corr = FALSE)

# 18a. Remove one of the slopes 1- Remove correlation and interactions of pp
Adepvar.glmer18a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer18a, corr = FALSE)

# 18b. Remove one of the slopes 2- Remove correlation and interactions of pp
Adepvar.glmer18b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer18b, corr = FALSE)

# 18c. Remove one of the slopes 3- Remove correlation and interactions of pp
Adepvar.glmer18c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer18c, corr = FALSE)

# 19a. Remove two of the slopes 1
Adepvar.glmer19a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 +phrase_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer19a, corr = FALSE)

# 19b. Remove two of the slopes 2
Adepvar.glmer19b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer19b, corr = FALSE)

# 19c. Remove two of the slopes 3
Adepvar.glmer19c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1 + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer19c, corr = FALSE)

# 20a. Remove two of the slopes 1
Adepvar.glmer20a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp) +(0 + phrase_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer20a, corr = FALSE)

# 20b. Remove two of the slopes 1
Adepvar.glmer20b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp) +(0 + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer20b, corr = FALSE)

# 20c. Remove two of the slopes 1
Adepvar.glmer20c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp) +(0 + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer20c, corr = FALSE)

# 21. Intercept only
Adepvar.glmer21 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp)+  (1|stim), datafile,family = binomial)
summary(Adepvar.glmer21, corr = FALSE)

# 22.Intercept only for pp
Adepvar.glmer22 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (1|pp), datafile,family = binomial)
summary(Adepvar.glmer22, corr = FALSE)

# 22.Intercept only for item
Adepvar.glmer23 =  glmer(depvar ~ phrase_type * structure* n2_preview_type +(1|stim), datafile,family = binomial)
summary(Adepvar.glmer23, corr = FALSE)


confint(Adepvar.glmer22, method="Wald") 





##############Part2-Simple effect#########################################################

###n+2 preview effect for different structure

datafile$PS <- C(datafile$condition,matrix(c(-0.5,+0.5,-0.5,+0.5,0,0,0,0, # Consistent vs inconsistent preview for MN target
                                             0,0,0,0,-0.5,+0.5,-0.5,+0.5)  # Consistent vs inconsistent preview for OV target
                                           ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$PS)

# Then run the lme
# Then run the lme
contrast1.glmer <- glmer(depvar ~ PS  +(1+PS|pp) + (1+PS|stim),data =datafile,family = binomial)
summary(contrast1.glmer, corr = FALSE)

contrast2.glmer <- glmer(depvar ~ PS  +(1 + PS|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast2.glmer, corr = FALSE)

contrast3.glmer <- glmer(depvar ~ PS  +(1|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast3.glmer, corr = FALSE)

confint(contrast3.glmer, method="Wald")





##structure effect for different n+2 preview

datafile$SP<- C(datafile$condition,matrix(c(-0.5,0,-0.5,0,+0.5,0,+0.5,0, # MN vs OV for Consistent preview
                                            0,-0.5,0,-0.5,0,+0.5,0,+0.5)  #  MN vs OV for inconsistent preview
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$SP)

# Then run the lme
contrast1.glmer <- glmer(depvar ~ PS  +(1+PS|pp) + (1+PS|stim),data =datafile,family = binomial)
summary(contrast1.glmer, corr = FALSE)

contrast2.glmer <- glmer(depvar ~ PS  +(1 + PS|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast2.glmer, corr = FALSE)

contrast3.glmer <- glmer(depvar ~ PS  +(1|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast3.glmer, corr = FALSE)

confint(contrast3.glmer, method="Wald")




## Phrase type effect for different structure

datafile$SP<- C(datafile$condition,matrix(c(-0.5,-0.5,+0.5,+0.5,0,0,0,0, # Idiom vs phrase for MN target
                                            0,0,0,0,-0.5,-0.5,+0.5,+0.5)  #  Idiom vs phrase for OV target
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$SP)

# Then run the lme
# Then run the lme
contrast1.glmer <- glmer(depvar ~ PS  +(1+PS|pp) + (1+PS|stim),data =datafile,family = binomial)
summary(contrast1.glmer, corr = FALSE)

contrast2.glmer <- glmer(depvar ~ PS  +(1 + PS|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast2.glmer, corr = FALSE)

contrast3.glmer <- glmer(depvar ~ PS  +(1|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast3.glmer, corr = FALSE)

confint(contrast3.glmer, method="Wald")



##structure effect for different phrase type

datafile$SP<- C(datafile$condition,matrix(c(-0.5,-0.5,0,0,+0.5,+0.5,0,0, # MN vs OV for Idiom
                                            0,0,-0.5,-0.5,0,0,+0.5,+0.5)  #  MN vs OV for phrase
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$SP)

# Then run the lme
contrast1.glmer <- glmer(depvar ~ PS  +(1+PS|pp) + (1+PS|stim),data =datafile,family = binomial)
summary(contrast1.glmer, corr = FALSE)

contrast2.glmer <- glmer(depvar ~ PS  +(1 + PS|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast2.glmer, corr = FALSE)

contrast3.glmer <- glmer(depvar ~ PS  +(1|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast3.glmer, corr = FALSE)

confint(contrast3.glmer, method="Wald")





##n+2 preview type for different phrase type 


datafile$SP<- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,-0.5,+0.5,0,0, # Consistent vs inconsistent for idiom
                                            0,0,-0.5,+0.5,0,0,-0.5,+0.5)  #  Consistent vs inconsistent for phrase
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$SP)

# Then run the lme
contrast1.glmer <- glmer(depvar ~ PS  +(1+PS|pp) + (1+PS|stim),data =datafile,family = binomial)
summary(contrast1.glmer, corr = FALSE)

contrast2.glmer <- glmer(depvar ~ PS  +(1 + PS|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast2.glmer, corr = FALSE)

contrast3.glmer <- glmer(depvar ~ PS  +(1|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast3.glmer, corr = FALSE)

confint(contrast3.glmer, method="Wald")


##phrase type for different n+2 preview


datafile$SP<- C(datafile$condition,matrix(c(-0.5,0,+0.5,0,-0.5,0,+0.5,0, # Idiom vs phrase for consistent preview
                                            0,-0.5,0,+0.5,0,-0.5,0,+0.5) # Idiom vs phrase for inconsistent preview
                                          ,8,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

contrasts(datafile$SP)
# Then run the lme
contrast1.glmer <- glmer(depvar ~ PS  +(1+PS|pp) + (1+PS|stim),data =datafile,family = binomial)
summary(contrast1.glmer, corr = FALSE)

contrast2.glmer <- glmer(depvar ~ PS  +(1 + PS|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast2.glmer, corr = FALSE)

contrast3.glmer <- glmer(depvar ~ PS  +(1|pp) + (1|stim), data =datafile,family = binomial)
summary(contrast3.glmer, corr = FALSE)

contrast4.glmer <- glmer(depvar ~ SP  +(1|pp), data = datafile)
summary(contrast4.lmer, corr = FALSE)

confint(contrast4.glmer, method="Wald")




########Part2 Run the model when TP as covariate#########
##Run linear mixed-effects models (LMM)
##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.

# 1.Full model
Bdepvar.glmer1 = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type * structure* n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer1, corr = FALSE)

# 2.Remove correlations of item
Bdepvar.glmer2 = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type * structure* n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item
Bdepvar.glmer3 = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer3, corr = FALSE)

# 4. Remove correlation and interactions of item
Bdepvar.glmer4 = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp  + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer4, corr = FALSE)

# 5a. remove one of the slopes
Bdepvar.glmer5a = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp  + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure* n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer5a, corr = FALSE)

# 5b. remove one of the slopes
Bdepvar.glmer5b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer5b, corr = FALSE)

# 5c. remove one of the slopes
Bdepvar.glmer5c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* structure|stim), datafile,family = binomial)
summary(Bdepvar.glmer5c, corr = FALSE)


# 6a. remove one of the slopes, without correlation
Bdepvar.glmer6a = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure* n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer6a, corr = FALSE)

# 6b.remove one of the slopes, without correlation
Bdepvar.glmer6b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer6b, corr = FALSE)

# 6c remove one of the slopes, without correlation
Bdepvar.glmer6c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* structure|stim), datafile,family = binomial)
summary(Bdepvar.glmer6c, corr = FALSE)

# 7a. remove one of the slopes, Remove interactions (with correlation back in) of item
Bdepvar.glmer7a = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer7a, corr = FALSE)

# 7b. remove one of the slopes, Remove interactions (with correlation back in) of item
Bdepvar.glmer7b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer7b, corr = FALSE)

# 7c. remove one of the slopes, Remove interactions (with correlation back in) of item
Bdepvar.glmer7c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure|stim), datafile,family = binomial)
summary(Bdepvar.glmer7c, corr = FALSE)

# 8a. remove one of the slopes,  Remove correlation and interactions of item
Bdepvar.glmer8a = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer8a, corr = FALSE)

# 8b. remove one of the slopes,  Remove correlation and interactions of item
Bdepvar.glmer8b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer8b, corr = FALSE)

# 8c.  remove one of the slopes,  Remove correlation and interactions of item
Bdepvar.glmer8c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure|stim), datafile,family = binomial)
summary(Bdepvar.glmer8c, corr = FALSE)

# 9a. remove two of the two slopes
Bdepvar.glmer9a = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer9a, corr = FALSE)

# 9b. remove two of the two slopes
Bdepvar.glmer9b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer9b, corr = FALSE)

# 9c.remove two of the two slopes
Bdepvar.glmer9c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure|stim), datafile,family = binomial)
summary(Bdepvar.glmer9c, corr = FALSE)

# 10a.remove two of the two slopes,Remove correlations of item（可以省掉）
Bdepvar.glmer10a = glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer10a, corr = FALSE)

# 10b.remove two of the two slopes,Remove correlations of item（可以省掉）
Bdepvar.glmer10b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + n2_preview_type|stim), datafile,family = binomial)
summary(Bdepvar.glmer10b, corr = FALSE)

# 10c.remove two of the two slopes,Remove correlations of item（可以省掉）
Bdepvar.glmer10c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + structure|stim), datafile,family = binomial)
summary(Bdepvar.glmer10c, corr = FALSE)

# 11. remove two of the two slopes,Intercept only for item
Bdepvar.glmer11 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer11, corr = FALSE)

# 12.Remove correlations of pp
Bdepvar.glmer12 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer12, corr = FALSE)

# 13.Remove interactions (with correlation back in) of pp
Bdepvar.glmer13 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer13, corr = FALSE)

# 14.Remove correlation and interactions of pp
Bdepvar.glmer14 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer14, corr = FALSE)

# 15a. Remove one of the slopes 1
Bdepvar.glmer15a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + structure * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer15a, corr = FALSE)

# 15b. Remove one of the slopes 2
Bdepvar.glmer15b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer15b, corr = FALSE)

# 15c. Remove one of the slopes 3
Bdepvar.glmer15c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type * structure|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer15c, corr = FALSE)

# 16a. Remove one of the slopes 1- Remove correlations of pp
Bdepvar.glmer16a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + structure * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer16a, corr = FALSE)

# 16b. Remove one of the slopes 2- Remove correlations of pp
Bdepvar.glmer16b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer16b, corr = FALSE)

# 16c. Remove one of the slopes 3- Remove correlations of pp
Bdepvar.glmer16c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp+ (0 + phrase_type * structure|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer16c, corr = FALSE)

# 17a. Remove one of the slopes 1- Remove interactions (with correlation back in) of pp
Bdepvar.glmer17a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer17a, corr = FALSE)

# 17b. Remove one of the slopes 2- Remove interactions (with correlation back in) of pp
Bdepvar.glmer17b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer17b, corr = FALSE)

# 17c. Remove one of the slopes 3- Remove interactions (with correlation back in) of pp
Bdepvar.glmer17c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + phrase_type + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer17c, corr = FALSE)

# 18a. Remove one of the slopes 1- Remove correlation and interactions of pp
Bdepvar.glmer18a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer18a, corr = FALSE)

# 18b. Remove one of the slopes 2- Remove correlation and interactions of pp
Bdepvar.glmer18b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer18b, corr = FALSE)

# 18c. Remove one of the slopes 3- Remove correlation and interactions of pp
Bdepvar.glmer18c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (0 + phrase_type + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer18c, corr = FALSE)

# 19a. Remove two of the slopes 1
Bdepvar.glmer19a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 +phrase_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer19a, corr = FALSE)

# 19b. Remove two of the slopes 2
Bdepvar.glmer19b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer19b, corr = FALSE)

# 19c. Remove two of the slopes 3
Bdepvar.glmer19c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1 + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer19c, corr = FALSE)

# 20a. Remove two of the slopes 1- Remove correlations of pp (可以省)
Bdepvar.glmer20a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp) +(0 + phrase_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer20a, corr = FALSE)

# 20b. Remove two of the slopes 1- Remove correlations of pp (可以省)
Bdepvar.glmer20b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp) +(0 + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer20b, corr = FALSE)

# 20c. Remove two of the slopes 1- Remove correlations of pp (可以省)
Bdepvar.glmer20c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp) +(0 + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer20c, corr = FALSE)

# 21. Intercept only
Bdepvar.glmer21 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp) +  (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer21, corr = FALSE)

# 22. Intercept only for pp
Bdepvar.glmer22 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|pp), datafile,family = binomial)
summary(Bdepvar.glmer22, corr = FALSE)

# 23. Intercept only for item
Bdepvar.glmer23 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + ctp + (1|stim), datafile,family = binomial)
summary(Bdepvar.glmer23, corr = FALSE)

confint(Bdepvar.glmer21, method="Wald") 



############Part2-Run the model when predictability as covariate################################

# 1.Full model
Cdepvar.glmer1 = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type * structure* n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer1, corr = FALSE)

# 2.Remove correlations of item
Cdepvar.glmer2 = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type * structure* n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item
Cdepvar.glmer3 = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer3, corr = FALSE)

# 4. Remove correlation and interactions of item
Cdepvar.glmer4 = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre  + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer4, corr = FALSE)

# 5a. remove one of the slopes
Cdepvar.glmer5a = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre  + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure* n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer5a, corr = FALSE)

# 5b. remove one of the slopes
Cdepvar.glmer5b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer5b, corr = FALSE)

# 5c. remove one of the slopes
Cdepvar.glmer5c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type* structure|stim), datafile,family = binomial)
summary(Cdepvar.glmer5c, corr = FALSE)


# 6a. remove one of the slopes, without correlation
Cdepvar.glmer6a = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure* n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer6a, corr = FALSE)

# 6b.remove one of the slopes, without correlation
Cdepvar.glmer6b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer6b, corr = FALSE)

# 6c remove one of the slopes, without correlation
Cdepvar.glmer6c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type* structure|stim), datafile,family = binomial)
summary(Cdepvar.glmer6c, corr = FALSE)

# 7a. remove one of the slopes, Remove interactions (with correlation back in) of item
Cdepvar.glmer7a = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer7a, corr = FALSE)

# 7b. remove one of the slopes, Remove interactions (with correlation back in) of item
Cdepvar.glmer7b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer7b, corr = FALSE)

# 7c. remove one of the slopes, Remove interactions (with correlation back in) of item
Cdepvar.glmer7c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type + structure|stim), datafile,family = binomial)
summary(Cdepvar.glmer7c, corr = FALSE)

# 8a. remove one of the slopes,  Remove correlation and interactions of item
Cdepvar.glmer8a = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + structure + n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer8a, corr = FALSE)

# 8b. remove one of the slopes,  Remove correlation and interactions of item
Cdepvar.glmer8b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer8b, corr = FALSE)

# 8c.  remove one of the slopes,  Remove correlation and interactions of item
Cdepvar.glmer8c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (0 + phrase_type + structure|stim), datafile,family = binomial)
summary(Cdepvar.glmer8c, corr = FALSE)

# 9a. remove two of the two slopes
Cdepvar.glmer9a = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + phrase_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer9a, corr = FALSE)

# 9b. remove two of the two slopes
Cdepvar.glmer9b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer9b, corr = FALSE)

# 9c.remove two of the two slopes
Cdepvar.glmer9c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1 + structure|stim), datafile,family = binomial)
summary(Cdepvar.glmer9c, corr = FALSE)

# 10a.remove two of the two slopes,Remove correlations of item（可以省掉）
Cdepvar.glmer10a = glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) + (1|stim) + (0 + phrase_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer10a, corr = FALSE)

# 10b.remove two of the two slopes,Remove correlations of item（可以省掉）
Cdepvar.glmer10b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + n2_preview_type|stim), datafile,family = binomial)
summary(Cdepvar.glmer10b, corr = FALSE)

# 10c.remove two of the two slopes,Remove correlations of item（可以省掉）
Cdepvar.glmer10c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim) + (0 + structure|stim), datafile,family = binomial)
summary(Cdepvar.glmer10c, corr = FALSE)

# 11. remove two of the two slopes,Intercept only for item
Cdepvar.glmer11 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer11, corr = FALSE)

# 12.Remove correlations of pp
Cdepvar.glmer12 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type * structure* n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer12, corr = FALSE)

# 13.Remove interactions (with correlation back in) of pp
Cdepvar.glmer13 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer13, corr = FALSE)

# 14.Remove correlation and interactions of pp
Cdepvar.glmer14 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer14, corr = FALSE)

# 15a. Remove one of the slopes 1
Cdepvar.glmer15a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + structure * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer15a, corr = FALSE)

# 15b. Remove one of the slopes 2
Cdepvar.glmer15b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer15b, corr = FALSE)

# 15c. Remove one of the slopes 3
Cdepvar.glmer15c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type * structure|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer15c, corr = FALSE)

# 16a. Remove one of the slopes 1- Remove correlations of pp
Cdepvar.glmer16a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + structure * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer16a, corr = FALSE)

# 16b. Remove one of the slopes 2- Remove correlations of pp
Cdepvar.glmer16b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type * n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer16b, corr = FALSE)

# 16c. Remove one of the slopes 3- Remove correlations of pp
Cdepvar.glmer16c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + (0 + phrase_type * structure|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer16c, corr = FALSE)

# 17a. Remove one of the slopes 1- Remove interactions (with correlation back in) of pp
Cdepvar.glmer17a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer17a, corr = FALSE)

# 17b. Remove one of the slopes 2- Remove interactions (with correlation back in) of pp
Cdepvar.glmer17b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer17b, corr = FALSE)

# 17c. Remove one of the slopes 3- Remove interactions (with correlation back in) of pp
Cdepvar.glmer17c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + phrase_type + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer17c, corr = FALSE)

# 18a. Remove one of the slopes 1- Remove correlation and interactions of pp
Cdepvar.glmer18a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + structure + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer18a, corr = FALSE)

# 18b. Remove one of the slopes 2- Remove correlation and interactions of pp
Cdepvar.glmer18b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer18b, corr = FALSE)

# 18c. Remove one of the slopes 3- Remove correlation and interactions of pp
Cdepvar.glmer18c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (0 + phrase_type + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer18c, corr = FALSE)

# 19a. Remove two of the slopes 1
Cdepvar.glmer19a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 +phrase_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer19a, corr = FALSE)

# 19b. Remove two of the slopes 2
Cdepvar.glmer19b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer19b, corr = FALSE)

# 19c. Remove two of the slopes 3
Cdepvar.glmer19c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1 + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer19c, corr = FALSE)

# 20a. Remove two of the slopes 1- Remove correlations of pp 
Cdepvar.glmer20a =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp) +(0 + phrase_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer20a, corr = FALSE)

# 20b. Remove two of the slopes 1- Remove correlations of pp 
Cdepvar.glmer20b =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp) +(0 + n2_preview_type|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer20b, corr = FALSE)

# 20c. Remove two of the slopes 1- Remove correlations of pp 
Cdepvar.glmer20c =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp) +(0 + structure|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer20c, corr = FALSE)

# 21. Intercept only
Cdepvar.glmer21 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp) +  (1|stim), datafile,family = binomial)
summary(Cdepvar.glmer21, corr = FALSE)


# 22 Intercept only for pp
Cdepvar.glmer22 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|pp), datafile,family = binomial)
summary(Cdepvar.glmer22, corr = FALSE)

# 23 Intercept only for item
Cdepvar.glmer23 =  glmer(depvar ~ phrase_type * structure* n2_preview_type + cpre + (1|stim) , datafile,family = binomial)
summary(Cdepvar.glmer23, corr = FALSE)


confint(Cdepvar.glmer22, method="Wald") 

########################################### The End##########################################















