###### Parafoveal Processing of Chinese four-character idioms in Reading ##

#### Brife Introduction ####
# This code for Experiment 1 regarding Parafoveal Processing of Chinese four-character idioms.
# This R script was originally run using R version 4.0.5 and Rstudio version 1.4.1717-3 for the first constituent (n+1), the second constituent (n+2), the the whole region ,and R version 4.1.0, Rstudio version 2021.09.2+382 for the pretarget??and  
# There are mainly two parts of analyses.
# Part1 The code for continuous variables (FFD,SFD,GD,TFD,Go-past) for the pretarget, the first constituent (n+1), the second constituent (n+2) and the the whole region.
# Part2 The code for  binomial variable (skipping) for the pretarget, the first constituent (n+1), the second constituent (n+2) and the the whole region.

# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.

# Here we will look at two ways of analysing a 2 x 2 design which has:
# 2 levels of n+1preview(Identity, Pseudocharacter)
# 2 levels of n+2preview(Identity, Pseudocharacter)

##Note: in this code
# n+1 preview type was labelled as n_1
# n+2 preview type was labelled as n_2
#Identity was labelled as ID
#Pseudocharacter was labelled as IN

#### Libraries needed to run the current R code ####
library(languageR)#version 1.5.0
library(lme4)     #version 1.1-27; version 1.1.28 for the pretarget region 
library(lattice)  #version 0.20-44
library(lmerTest) #if you want p values for your lmer model #version 3.1-3
library(MASS)     #version 7.3-54
library(plyr)     #version 1.8.6
library(sjPlot) #version 2.8.9 ;version 2.8.10 for the pretarget region
sessionInfo()
#### Clean up####
rm(list=ls())

#### Part1- For FFD, SFD, GD, TFD, Go-past, analyses for the two pretarget characters, n+1, n+2 and the whole region ####
#### Part1-TARGET WORDS ANALYSES-Load data and set up variables####
# 1.Load data
# open the csv.file according to data name.
datafile = read.csv(file.choose(), sep = ",", dec = ".")
head(datafile) #generally check the file you have imported
# choose dependent variable
measure = "SFD"

# 5720 observations for FFD,GD,Go-past for the pretarget
# 6635 observations for TFD for the pretarget
# 5079 observations for SFD for the pretarget

# 5374 observations for FFD,GD,Go-past for n+1
# 6032 observations for TFD for n+1
# 4390 observations for SFD for n+1

# 5052 observations for FFD,GD,Go-past for n+2
# 5629 observations for TFD for n+2
# 4459 observations for SFD for n+2

# 6756 observations for FFD,GD,Go-past for the whole region
# 6876 observations for TFD for the whole region
# 2832 observations for SFD for the whole region

# add to dataframe
datafile$depvar = datafile[,measure]
# 2.Set up variables 
colnames(datafile) #checked the column names
col.pp = 1    #specify which column your participant number is in,participant
col.stim =2    #specify which column your stim number is in,trial
col.n1 =3 #specify which column n_1preview number is
col.n2 =4    #specify which column  column n_2preview number is
col.condition =5 #specify which column conditon number is
col.prediction = 7 #specify which column n2prediction number is
head(datafile)

#### Part1-Work out which colums the fixed and random factors are in####

datafile$stim = datafile[,col.stim]
datafile$pp = datafile[,col.pp]
#### Part1-TARGET WORDS ANALYSES-Making sure all variables are correct class ####
str(datafile)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$ n2 = as.factor(datafile$ n_2)
datafile$n1 = as.factor(datafile$n_1)
datafile$condition = as.factor(datafile$condition)
datafile$prediction = as.numeric(datafile$n_1_prediction)
datafile$depvar = as.numeric(datafile$depvar)

#### Part1-Remove outlier ####
# Remove data outside 3 standard deviations
head(datafile) #let's first have a look
nrcolumns = ncol(datafile)   
# make a new datafile with eye movement measures > 0
between1 = datafile[datafile$depvar > 0, ]
head(between1)
between1 = datafile
#make a matrix with the means per subject 
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between1$depvar, list(between1$pp ), sd, na.rm = T)
sd.matrix
# add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0
# make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between1[abs(between1$zscore) < 3,]
# you might want to clean up this data file by removing the added columns
result = result[,1:nrcolumns]
tussen1 = result# insert the name from the datafile coming from the clean up on the right
nrow(datafile)-nrow(tussen1) # calculate how many row you removed
# calculate how many row rate
rate=(nrow(datafile)-nrow(tussen1))/nrow(datafile) 
rate 
datafile = tussen1 
nrow(datafile)# checked the observations after remove outlier

# two pretarget characters region:
## 5641 for FFD, 5013 for SFD, 5606 for GD, 6527 for TFD, 5589 for Go-past
# word n+1 region:
## 5326 for FFD, 4353 for SFD, 5301 for GD, 5945 for TFD, 5257 for Go-past
# word n+2 region:
## 4983 for FFD, 4395 for SFD, 4959 for GD, 5546 for TFD, 4925 for Go-past
# whole region:
## 6690 for FFD, 2815 for SFD, 6659 for GD, 6781 for TFD, 6633 for Go-past


#### Part1-TARGET WORD ANALYSES-Means,Standard Deviations and Standard Errors####
##Code for calculating means between per pp and per condition
mean.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.tt
sd.tt = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.tt
## then calculate the grand mean by condition
grand.mean=apply(mean.tt, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.tt, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(100)  ## this number is the total number of participants from your data, so it is changable.
grand.se


#### Part1-TARGET WORD ANALYSES-Datavisualization ####
# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # log transform data
# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar) 
#### Part1-Means,Standard Deviations and Standard Errors####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(100) ##The number of the participants is 100. 
grand.se

# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)


####Part1-Linear Mixed Models (LMM)####
# 1.Check the levels of  n+1preview and n+2preview
levels(datafile$ n1)
levels(datafile$ n2)
# 2.Do the contrast.
#contrasts(datafile$phrase_type)#
contrasts(datafile$ n1) <- contr.sdif(2)
contrasts(datafile$ n2) <- contr.sdif(2)


# 3.Run linear mixed-effects models (LMM)
## When we ran the models we always began with full models that included the maximum random effects structure.
## But the slopes were removed if the model failed to converge.
#### We saved the results of lme models that run successfully.
##### For the the pretarget analyses, FFD: depvar.lmer11a, SFD: depvar.lmer11a, GD: depvar.lmer11a, TFD:  depvar.lmer11a, Go-past:depvar.lmer11b.
##### For the n+1 analyses, FFD: depvar.lmer7, SFD: depvar.lmer11b, GD: depvar.lmer9, TFD:  depvar.lmer11b, Go-past:depvar.lmer11b.
##### For the n+2 analyses, FFD: depvar.lmer11b, SFD: depvar.lmer11b, GD: depvar.lmer11b TFD:  depvar.lmer11a, Go-past:depvar.lmer11b.
##### For the whole region analyses,FFD: depvar.lmer11b, SFD: depvar.lmer11b, GD: depvar.lmer11a, TFD: depvar.lmer9, Go-past:depvar.lmer11b.


# 1.Full model

depvar.lmer1 = lmer(depvar ~ n_1 *  n_2 + (1 + n_1 *  n_2|pp) + (1 + n_1 *  n_2|stim), datafile)
summary(depvar.lmer1, corr = FALSE)

# 2.Remove correlations of item

depvar.lmer2 = lmer(depvar ~ n_1 *  n_2  + (1 + n_1 *  n_2|pp) + (0 + n_1 *  n_2|stim), datafile)
summary(depvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item

depvar.lmer3 = lmer(depvar ~ n_1 *  n_2   + (1 + n_1 *  n_2|pp) + (1 + n_1 +  n_2|stim), datafile)
summary(depvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

depvar.lmer4 = lmer(depvar ~ n_1 *  n_2  + (1 + n_1 *  n_2|pp) + (0 + n_1 +  n_2|stim), datafile)
summary(depvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes

depvar.lmer5a = lmer(depvar ~ n_1 *  n_2  + (1 + n_1 *  n_2|pp) + (1 + n_1|stim), datafile)
summary(depvar.lmer5a, corr = FALSE)

### 5b.
depvar.lmer5b = lmer(depvar ~ n_1 *  n_2+ (1 + n_1 *  n_2|pp) + (1 +  n_2|stim), datafile)
summary(depvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

depvar.lmer6a = lmer(depvar ~ n_1 *  n_2+ (1 + n_1 *  n_2|pp) + (1|stim) + (0 + n_1|stim), datafile)
summary(depvar.lmer6a, corr = FALSE)

### 6b.
depvar.lmer6b = lmer(depvar ~ n_1 *  n_2  + (1 + n_1 *  n_2|pp) + (1|stim) + (0 +  n_2|stim), datafile)
summary(depvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

depvar.lmer7 = lmer(depvar ~ n_1 *  n_2  + (1 + n_1 *  n_2|pp) + (1|stim), datafile)
summary(depvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

depvar.lmer8 = lmer(depvar ~ n_1 *  n_2  + (0 + n_1 *  n_2|pp) + (1|stim), datafile)
summary(depvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

depvar.lmer9 = lmer(depvar ~ n_1 * n_2  + (1 + n_1 +  n_2|pp) + (1|stim), datafile)
summary(depvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

depvar.lmer10 = lmer(depvar ~ n_1 *  n_2  + (0 + n_1 +  n_2|pp) + (1|stim), datafile)
summary(depvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
depvar.lmer11a = lmer(depvar ~ n_1 *  n_2  + (1 +  n_2|pp) + (1|stim), datafile)
summary(depvar.lmer11a, corr = FALSE)

#### 11b.
depvar.lmer11b = lmer(depvar ~ n_1 *  n_2  + (1 + n_1|pp) + (1|stim), datafile)
summary(depvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

depvar.lmer12a = lmer(depvar ~ n_1 *  n_2  + (1|pp) + (0 + n_1|pp) + (1|stim), datafile)
summary(depvar.lmer12a, corr = FALSE)

#### 12b.

depvar.lmer12b = lmer(depvar ~ n_1 *  n_2  + (1|pp) + (0 +  n_2|pp) + (1|stim), datafile)
summary(depvar.lmer12b, corr = FALSE)

# 13. Intercepts only 

depvar.lmer13 = lmer(depvar ~ n_1 *  n_2  + (1|pp) + (1|stim), datafile)
summary(depvar.lmer13, corr = FALSE)

#### Part1-TARGET WORD ANALYSES-Confidence interval ####
confint(depvar.lmer11b, method="Wald") # calculate CI of the model you run.


tab_model(depvar.lmer11b, show.se = TRUE, show.stat = TRUE,auto.label = F)


####Part1-Simple effect####
## if interaction of n+1preview and n+2preview is significant, then run the code below
#1. n+2preview effect for different n+1preview
levels(datafile$condition)

datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,# n+2identity vs n+2pseudocharacter for n+1identity
                                                    0,0,-0.5,+0.5)  # n+2identity vs n+2pseudocharacter for n+1pseudocharacter
                                                  ,4,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
## Then run the lme
#####For the the pretarget analyses,FFD:contrast3.lmer,TFD: contrast2.lmer.
#####For the n+1 analyses, FFD: contrast3.lmer, SFD: contrast2.lmer, GD: contrast3.lmer, TFD: contrast3.lmer, Go-past:contrast3.lmer.
#####For the n+2 analyses,GD:contrast3.lmer,TFD: contrast3.lmer,Go-past:contrast3.lmer
#####For the whole region analyses, FFD: contrast3.lmer, SFD: contrast3.lmer, GD: contrast3.lmer,TFD: contrast3.lmer, Go-past:contrast3.lmer.

contrasts(datafile$condition)
# Full model
contrast1.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
# Remove the slope for items
contrast2.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
# Remove the slope for items and participants
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

#2. n+1preview effect for different n+2preview
datafile$condition <- C(datafile$condition,matrix(c(-0.5,0,+0.5,0,# n+1identity vs n+1pseudocharacter for n+2identity
                                                    0,-0.5,0,+0.5)  # n+1identity vs n+1pseudocharacter for n+2pseudocharacter
                                                  ,4,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

## Then run the lme
#####For the pretarget analyses,FFD:contrast3.lmer,TFD: contrast3.lmer.
#####For the n+1 analyses, FFD: contrast2.lmer, SFD: contrast3.lmer, GD: contrast3.lmer, TFD: contrast2.lmer, Go-past:contrast3.lmer.
#####For the n+2 analyses,GD:contrast2.lmer,TFD: contrast3.lmer,Go-past:contrast3.lmer
#####For the whole region analyses, FFD: contrast3.lmer, SFD: contrast3.lmer, GD: contrast2.lmer,TFD: contrast2.lmer, Go-past:contrast3.lmer.

contrasts(datafile$condition)
# Full model
contrast1.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
# Remove the slope for items
contrast2.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
# Remove the slope for items and participants
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

#### Part1-Confidence interval ####
confint(contrast2.lmer, method="Wald") # calculate CI of the model you run.
tab_model(contrast2.lmer, show.se = TRUE, show.stat = TRUE,auto.label = F)

##############################################################################

###############################################################################


########Part2-The code for skipping#########

rm(list=ls()) # Remove any variables

# Open a csv.file of skipping 

datafile = read.csv(file.choose(), sep = ",", dec = ".")
#7925 observations for the pretarget region
# 6859 observations for the n+1, n+2
#6942 observations for the compoiste region

head(datafile) # generally check the file you have imported

nrow(datafile) # check the number of observations

colnames(datafile)   #Display the column names 
col.subject = 1      # specify which column your participant number is in
col.condition = 5    # specify which column contains your condition number
col.stim = 2       # specify which column your item number is in
col.prediction = 7
# choose dependent variable
measure = "IA_SKIP"

# add to dataframe
datafile$depvar = datafile[,measure]

# Work out which colums the fixed and random factors are in

datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# Let's make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$prediction = as.numeric(datafile$n_1_prediction)

################################################################
#####Part2-Code for calculating means between per pp and per condition#####
###Step1a:Make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix

###Step1b:Make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

####Step1c: Calculate the grand mean, grand SD, and grand SE by condition
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix, 2, sd, na.rm = T)
grand.sd 
grand.se=grand.sd/sqrt(100)  ##The number of the participants is 100. 
grand.se

###############################################################################
####Part2-Linear Mixed Models (GLME)####
# 1.Check the levels of phrase_type and preview_type
levels(datafile$n_1) 
levels(datafile$n_2) 
# Add contrasts
contrasts(datafile$n_1) <- contr.sdif(2)  
contrasts(datafile$n_2) <- contr.sdif(2)


#####For the pretarget analyses, depvar.lmer11a 
#####For the n+1 analyses, depvar.lmer12a 
#####For the n+2 analyses, depvar.lmer11a
#####For the whole region analyses, depvar.lmer11b
# GLME
# 1.Full model
depvar.lmer1 = glmer(depvar ~ n_1 *n_2   + (1 + n_1 *n_2|pp) + (1 + n_1 *n_2|stim), datafile, family = binomial)
summary(depvar.lmer1, corr = FALSE)

# 2.remove correlations of item

depvar.lmer2 = glmer(depvar ~ n_1 *n_2 + (1 + n_1 *n_2|pp) + (0 + n_1 *n_2|stim), datafile, family = binomial)
summary(depvar.lmer2, corr = FALSE)

# 3. remove interactions (with correlation back in) of item

depvar.lmer3 = glmer(depvar ~ n_1 *n_2  + (1 + n_1 *n_2|pp) + (1 + n_1 +n_2|stim), datafile, family = binomial)
summary(depvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item


depvar.lmer4 = glmer(depvar ~ n_1 *n_2 + (1 + n_1 *n_2|pp) + (0 + n_1 +n_2|stim), datafile, family = binomial)
summary(depvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes 

depvar.lmer5a = glmer(depvar ~ n_1 *n_2  + (1 + n_1 *n_2|pp) + (1 + n_1|stim), datafile, family = binomial)
summary(depvar.lmer5a, corr = FALSE)

### 5b. 

depvar.lmer5b = glmer(depvar ~ n_1 *n_2  + (1 + n_1 *n_2|pp) + (1 +n_2|stim), datafile, family = binomial)
summary(depvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

depvar.lmer6a = glmer(depvar ~ n_1 * n_2+ (1 + n_1 *n_2|pp) + (1|stim) + (0 + n_1|stim), datafile, family = binomial)
summary(depvar.lmer6a, corr = FALSE)

### 6b.

depvar.lmer6b = glmer(depvar ~ n_1 *n_2  + (1 + n_1 *n_2|pp) + (1|stim) + (0 +n_2|stim), datafile, family = binomial)
summary(depvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

depvar.lmer7 = glmer(depvar ~ n_1 *n_2  + (1 + n_1 *n_2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

depvar.lmer8 = glmer(depvar ~ n_1 *n_2   + (0 + n_1 *n_2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

depvar.lmer9 = glmer(depvar ~ n_1 *n_2 + (1 + n_1 +n_2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

depvar.lmer10 = glmer(depvar ~ n_1 *n_2 + (0 + n_1 +n_2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
depvar.lmer11a = glmer(depvar ~ n_1 *n_2  + (1 +n_2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11a, corr = FALSE)

##### 11b.Remove one slope for pp
depvar.lmer11b = glmer(depvar ~ n_1 *n_2 + (1 + n_1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

depvar.lmer12a = glmer(depvar ~ n_1 *n_2  + (1|pp) + (0 + n_1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12a, corr = FALSE)

#### 12b.Again without correlation for pp

depvar.lmer12b = glmer(depvar ~ n_1 *n_2  + (1|pp) + (0 +n_2|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer12b, corr = FALSE)

# 13. Intercepts only

depvar.lmer13 = glmer(depvar ~ n_1 *n_2 + (1|pp) + (1|stim), datafile, family = binomial)
summary(depvar.lmer13, corr = FALSE)

######################################################################

####Part2-Calculate Confidence Interation#####
confint(depvar.lmer12a, method="Wald")


####Part2-Simple effect####
## if interaction of n+1preview and n+2preview is significant, then run the code below
#1. n+2preview effect for different n+1preview
levels(datafile$condition)

datafile$condition <- C(datafile$condition,matrix(c(-0.5,+0.5,0,0,# n+2identity vs n+2pseudocharacter for n+1identity
                                                    0,0,-0.5,+0.5)  # n+2identity vs n+2pseudocharacter for n+1pseudocharacter
                                                  ,4,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
## Then run the lme
#####For the n+1 analyses, SP: contrast3.lmer.
#####For the n+2 analyses,SP:contrast3.lmer.

contrasts(datafile$condition)
# Full model
contrast1.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
# Remove the slope for items
contrast2.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
# Remove the slope for items and participants
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

#2. n+1preview effect for different n+2preview
datafile$condition <- C(datafile$condition,matrix(c(-0.5,0,+0.5,0,# n+1identity vs n+1pseudocharacter for n+2identity
                                                    0,-0.5,0,+0.5)  # n+1identity vs n+1pseudocharacter for n+2pseudocharacter
                                                  ,4,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:

## Then run the lme
#####For the n+1 analyses, SP: contrast2.lmer.
#####For the n+2 analyses,SP:contrast3.lmer.

contrasts(datafile$condition)
# Full model
contrast1.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
# Remove the slope for items
contrast2.lmer <- lmer(depvar ~ condition  + (1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
# Remove the slope for items and participants
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

#### Part2-Confidence interval ####
confint(contrast2.lmer, method="Wald") # calculate CI of the model you run.

###############################################################################



 