
####Parafoveal Processing of Chinese four-character strings in Reading ##

#### Brife Introduction ####

# This R script was originally run using R version 4.0.5 and Rstudio version 1.4.1717-3 for the first constituent (n+1), the second constituent (n+2), the the whole region and R version 4.1.0 and Rstudio version 2021.09.2+382 for the two pretarget character region.
#n2prediction and naturalness were treated as covariate using R version 4.1.0 and Rstudio version 2021.09.2+382.
# This code for the experiment 3 regarding Parafoveal Processing of Chinese four-character phrases in Reading.

# There are mainly two parts for Color and Word effects analyses.
# Part1 The code for continuous variables (FFD,SFD,GD,TFD) for for the two pretarget character region, the first constituent (n+1), the second constituent (n+2) and the the whole region.
# Part2 The code for skipping  probability for for the two pretarget character region, the first constituent (n+1), the second constituent (n+2) and the the whole region..

# Each eyemovement measure is in a separate file.
# Make sure that you have your datafile saved as .csv file.
# Create a folder which contains all .csv files.
# Here we will look at two ways of analysing a 2 x 3 design which has:
# 2 levels of n2preview (identity,Pseudocharacter)
# 3 levels of phrase (1-word string, ambiguous string, 2-word string)


##Note: in this code
#Identity was labelled as id.
#Pseudocharacter was labelled as in.


#### Libraries needed to run the current R code ####

library(languageR)#version 1.5.0
library(lme4)     #version 1.1-27
library(lattice)  #version 0.20-44
library(lmerTest) # version 3.1-3 #if you want p values for your lmer model 
library(MASS)     #version 7.3-54
library(plyr)     #version 1.8.6
library(yarrr) #version 0.1.5

library(ggplot2)# version 3.3.3
library(sjPlot) #version 2.8.9

sessionInfo()

#### Part1- Continuous dependent variables of target word analyse####
rm(list=ls()) # Remove any variables
# 1.Load data
# open the csv.file according to data name.
datafile = read.csv(file.choose(), sep = ",", dec = ".")
# 3451 observations for FFD,GD,Go-past for the pretarget
# 4181 observations for TFD for the pretarget
# 3024 observations for SFD for the pretarget

# 3110 observations for FFD,GD,Go-past for n+1
# 3644 observations for TFD for n+1
# 2601 observations for SFD for n+1

# 3141 observations for FFD,GD,Go-past for n+2
# 3597 observations for TFD for n+2
# 2643 observations for SFD for n+2

# 3847 observations for FFD,GD,Go-past for the whole region
# 3994 observations for TFD for the whole region
# 1456 observations for SFD for the whole region

head(datafile) # generally check the file you have imported
# 2.Set up variables 
colnames(datafile)#checked the column names
col.subject =1  # specify which column your participant number is in
col.condition =5 # specify which column contains your condition number 
col.stim =2 # specify which column your item number is in
col.n2prediction =5
col.naturalness =5
crit = 3    # setting the criterium value you want, usually 3 or 2.5 standard deviations

measure =  "GD" # choose dependent variable
# add to dataframe
datafile$depvar = datafile[,measure]

####Part1-Work out which colums the fixed and random factors are in####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

#### Part1-Make sure all variables are correct class ####
datafile$depvar = as.numeric(datafile$depvar)

#datafile$phrase = as.factor(datafile$phrase)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$n2preview = as.factor(datafile$n2preview)
datafile$phrase = as.factor(datafile$phrase)
datafile$n2prediction = as.numeric(datafile$n2prediction)
datafile$naturalness = as.numeric(datafile$naturalness)
str(datafile)

#### Part1-Remove outlier ####
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
head(datafile) #let's first have a look
# make a new datafile with fixation durations > 0 ms
between2preview = datafile[datafile$depvar > 0, ]
head(between2preview)
#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(between2preview$depvar, list(between2preview$pp), mean, na.rm = T)
mean.matrix
#make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(between2preview$depvar, list(between2preview$pp), sd, na.rm = T)
sd.matrix
#add this data to the actual dataframe
for(i in 1:nrow(between2preview)){between2preview$mean.sc[i] = mean.matrix[between2preview$pp[i]]}
for(i in 1:nrow(between2preview)){between2preview$sd.sc[i] = sd.matrix[between2preview$pp[i]]}
#calculate z-scores
for(i in 1:nrow(between2preview)) {between2preview$zscore[i] = (between2preview$depvar[i] - between2preview$mean.sc[i])/between2preview$sd.sc[i]}
# assign a zero value to cells with only 1 observation
between2preview$zscore[is.na(between2preview$zscore)] = 0
#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)
result = between2preview[abs(between2preview$zscore) < 3,]#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
nrow(datafile)
nrow(datafile)-nrow(result) # calculate how many row you removed
# calculate delete rate
rate=(nrow(datafile)-nrow(result))/nrow(datafile)
rate
datafile <-result
nrow(datafile)# checked the observations after remove outlier

# two pretarget characters region:
## 3407 for FFD, 2984 for SFD, 3393 for GD, 4127 for TFD, 3387 for Go-past
# word n+1 region:
## 3067 for FFD, 2575 for SFD, 3068 for GD, 3589 for TFD, 3040 for Go-past
# word n+2 region:
## 3109 for FFD, 2615 for SFD, 3092 for GD, 3553 for TFD, 3073 for Go-past
# whole region:
## 3792 for FFD, 1450 for SFD, 3798 for GD, 3957 for TFD, 3780 for Go-past



#### Part1-Means,Standard Deviations and Standard Errors####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(102) ##The number of the participants is 72. 
grand.se
#### Part1-Data visualization ####

# Do we need to transform?
# 1.plot the data
qqnorm(datafile$depvar) # raw data
qqnorm(log(datafile$depvar)) # raw data

# 2.We log transform (log transform data is more linear)
datafile$depvar=log(datafile$depvar)
#### Part1-Means,Standard Deviations and Standard Errors####
###Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix
##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(102) ##The number of the participants is 102. 
grand.se
# 3.checked the distrubition for every participant
qqmath(~depvar|pp, data = datafile)
##### visualization the results in gaze duration######

####Part1-Linear Mixed Models (LMM)####
# 1.Check the levels of n2preview and phrase
levels(datafile$n2preview) #id,in
levels(datafile$phrase) # "1_word"    "2_word"    "ambiguous"
####Part1-TARGET ANALYSES
contrasts(datafile$n2preview) <- contr.sdif(2)
######contrasts 1####################################
contrasts(datafile$phrase) <- contr.sdif(3)

######contrasts2:"b.a", "c.a"####################################
#NOTE: After run the first contrast,then run lmer models. Then run the second contrast plus the lmer models.####
contrast.matrix2 <- matrix(c(   
  -1, +1, 0,# 2_word vs 1-word
  +1, 0, -1), 3, 2,    # 1_word vs ambiguous
  dimnames=list(c("a", "b", "c"), # names of the conditions
                c("b.a", "a.c"))) # names of the contrasts

# Assign this contrast matrix to phrase
inv.contrast.matrix2 <- matrix(t(ginv(contrast.matrix2)),3, 2,
                               dimnames=list(c("a", "b", "c"), 
                                             c("b.a", "a.c")))
(contrasts(datafile$phrase) <- fractions(inv.contrast.matrix2))
###############################################################################################
# 3.Run linear mixed-effects models (LMM)
##When we ran the models we always began with full models that included the maximum random effects structure.
##But the slopes were removed if the model failed to converge.
#### We saved the results of lme models that run successfully.
##### For the the pretarget analyses, FFD: Adepvar.lmer13, SFD: Adepvar.lmer13, GD: Adepvar.lmer13, TFD:  Adepvar.lmer13, Go-past:Adepvar.lmer13.
##### For the n+1 analyses, FFD: Adepvar.lmer11b, SFD: Adepvar.lmer11b, GD: Adepvar.lmer11b, TFD:  Adepvar.lmer13, Go-past:Adepvar.lmer13.
##### For the n+2 analyses, FFD: Adepvar.lmer13, SFD: Adepvar.lmer11a, GD: Adepvar.lmer13 TFD:  Adepvar.lmer13, Go-past:Adepvar.lmer13.
##### For the whole region analyses,FFD: Adepvar.lmer11b, SFD: Adepvar.lmer11b, GD: Adepvar.lmer13, TFD: Adepvar.lmer11b, Go-past:Adepvar.lmer11b.

# 1.Full model

Adepvar.lmer1 = lmer(depvar ~n2preview * phrase + (1 +n2preview * phrase|pp) + (1 +n2preview * phrase|stim), datafile)
summary(Adepvar.lmer1, corr = FALSE)

# 2.Remove correlations of item

Adepvar.lmer2 = lmer(depvar ~n2preview * phrase + (1 +n2preview * phrase|pp) + (0 +n2preview * phrase|stim), datafile)
summary(Adepvar.lmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item

Adepvar.lmer3 = lmer(depvar ~n2preview * phrase + (1 +n2preview *phrase|pp) + (1 +n2preview + phrase|stim), datafile)
summary(Adepvar.lmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

Adepvar.lmer4 = lmer(depvar ~n2preview *phrase  + (1 +n2preview * phrase|pp) + (0 +n2preview + phrase|stim), datafile)
summary(Adepvar.lmer4, corr = FALSE)

# 5a. remove one of the slopes

Adepvar.lmer5a = lmer(depvar ~n2preview * phrase  + (1 +n2preview * phrase|pp) + (1 +n2preview|stim), datafile)
summary(Adepvar.lmer5a, corr = FALSE)

### 5b.
Adepvar.lmer5b = lmer(depvar ~n2preview * phrase + (1 +n2preview * phrase|pp) + (1 + phrase|stim), datafile)
summary(Adepvar.lmer5b, corr = FALSE)

# 6a. Again, without correlation

Adepvar.lmer6a = lmer(depvar ~n2preview * phrase  + (1 +n2preview * phrase|pp) + (1|stim) + (0 +n2preview|stim), datafile)
summary(Adepvar.lmer6a, corr = FALSE)

### 6b.
Adepvar.lmer6b = lmer(depvar ~n2preview * phrase + (1 +n2preview * phrase|pp) + (1|stim) + (0 + phrase|stim), datafile)
summary(Adepvar.lmer6b, corr = FALSE)

# 7. Intercept only for items

Adepvar.lmer7 = lmer(depvar ~n2preview * phrase  + (1 +n2preview * phrase|pp) + (1|stim), datafile)
summary(Adepvar.lmer7, corr = FALSE)

# 8. Remove correlation for pp

Adepvar.lmer8 = lmer(depvar ~n2preview * phrase + (0 +n2preview * phrase|pp) + (1|stim), datafile)
summary(Adepvar.lmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

Adepvar.lmer9 = lmer(depvar ~n2preview * phrase + (1 +n2preview + phrase|pp) + (1|stim), datafile)
summary(Adepvar.lmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

Adepvar.lmer10 = lmer(depvar ~n2preview * phrase + (0 +n2preview + phrase|pp) + (1|stim), datafile)
summary(Adepvar.lmer10, corr = FALSE)

# 11a. Remove one slope for pp
Adepvar.lmer11a = lmer(depvar ~n2preview * phrase + (1 + phrase|pp) + (1|stim), datafile)
summary(Adepvar.lmer11a, corr = FALSE)

#### 11b.
Adepvar.lmer11b = lmer(depvar ~n2preview * phrase  + (1 +n2preview|pp) + (1|stim), datafile)
summary(Adepvar.lmer11b, corr = FALSE)

# 12a. Again without correlation for pp

Adepvar.lmer12a = lmer(depvar ~n2preview * phrase + (1|pp) + (0 +n2preview|pp) + (1|stim), datafile)
summary(Adepvar.lmer12a, corr = FALSE)

#### 12b.

Adepvar.lmer12b = lmer(depvar ~n2preview *phrase  + (1|pp) + (0 + phrase|pp) + (1|stim), datafile)
summary(Adepvar.lmer12b, corr = FALSE)

# 13. Intercepts only 

Adepvar.lmer13 = lmer(depvar ~n2preview * phrase + (1|pp) + (1|stim), datafile)
summary(Adepvar.lmer13, corr = FALSE)

# 14.Intercepts only for pp
Adepvar.lmer14 = lmer(depvar ~n2preview * phrase + (1|pp) , datafile)
summary(Adepvar.lmer14, corr = FALSE)
#15.Intercepts only for stim
Adepvar.lmer15 = lmer(depvar ~n2preview * phrase + (1|stim) , datafile)
summary(Adepvar.lmer15, corr = FALSE)

###############################
#### Part1-Confidence interval ####
confint(Adepvar.lmer13, method="Wald") 
tab_model(Adepvar.lmer11b, show.se = TRUE, show.stat = TRUE,auto.label = F)


###############
###4.simple effects analysis
############################################################################################################################
#contrast:a and b
datafile$condition <- C(datafile$condition,matrix(c(+0.5,0,-0.5,0,0,0,# a vs b for id
                                                    0,0.5,0,-0.5,0,0)  # a vs b for in
                                                  ,6,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
# Full model
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
### Remove the slope for items
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
### Remove the slope for items and participants
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

########
#contrast:b and c
datafile$condition <- C(datafile$condition,matrix(c(0,0,+0.5,0,-0.5,0,# b vs c for id
                                                    0,0,0,0.5,0,-0.5)  #b vs c for in
                                                  ,6,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
################################################################################
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
#######################################################################################
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)
#######################################

#contrast a and c
datafile$condition <- C(datafile$condition,matrix(c(0.5,0,0,0,-0.5,0,# a vs c for id
                                                    0,0.5,0,0,0,-.5)  # a vs c for in
                                                  ,6,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
################################################################################
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
#######################################################################################
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)
#######################################
#contrast:id and in
#####For the n+1 analyses, GD: contrast3.lmer, SFD: contrast3.lmer, TFD: contrast3.lmer, Go-past:contrast3.lmer.
#####For the n+2 analyses,TFD: contrast3.lmer.
#####For the whole region analyses, SFD: contrast3.lmer, Go-past:contrast3.lmer.

datafile$condition <- C(datafile$condition,matrix(c(0.5,-0.5,0,0,0,0,# id vs in for 1_word
                                                    0,0,0.5,-0.5,0,0,#id vs in for 2_word
                                                    0,0,0,0,0.5,-0.5)  #id vs in for ambiguous
                                                  ,6,3),3)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ condition  + (1 + condition|pp) + (1 + condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
################################################################################
contrast2.lmer <- lmer(depvar ~ condition  + (1 + condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
#######################################################################################
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)
###############################################################################
#### Part1-Confidence interval ####
confint(contrast3.lmer, method="Wald")

tab_model(contrast3.lmer,show.se=TRUE,show.stat=TRUE,auto.label=F)


###############################################################################################


######## Part2-The code for skipping#########
####Part2-Skiping (binary data) ####
rm(list=ls()) # Remove any variables
# 1.Load data#
datafile = read.csv(file.choose(), sep = ",", dec = ".")

#4851 observations for the pretarget region
#4002 observations for the n+1, n+2 and the composite region

colnames(datafile)
head(datafile) #generally check the file you have imported

# 2.Set up variables 
colnames(datafile)#checked the column names
col.subject =1   # specify which column your participant number is in
col.condition =5# specify which column contains your condition number 
col.stim =2 # specify which column your item number is in
col.n2prediction =11
measure =   "IA_SKIP"     # choose dependent variable

####Part2-Work out which colums the fixed and random factors are in ####
datafile$pp = datafile[,col.subject]
datafile$condition = datafile[,col.condition]
datafile$stim = datafile[,col.stim]

# add to dataframe
datafile$depvar = datafile[,measure]

####Part2-Let's make sure all the variables are from the correct class####
datafile$depvar = as.numeric(datafile$depvar)

#datafile$phrase = as.numeric(datafile$phrase)
datafile$pp = as.factor(datafile$pp)
datafile$stim = as.factor(datafile$stim)
datafile$condition = as.factor(datafile$condition)
datafile$n2preview = as.factor(datafile$n2preview)
datafile$phrase = as.factor(datafile$phrase)
datafile$n2prediction = as.numeric(datafile$n2prediction)
str(datafile)

######Part2-Code for calculating means between per pp and per condition######

##Step1a: make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), mean, na.rm = T)
mean.matrix
####Step1b: make a matrix with the standard deviations per subject and per condition for the dependent variable
sd.matrix = tapply(datafile$depvar, list(datafile$pp, datafile$condition), sd, na.rm = T)
sd.matrix

##Step2:Calculate the grand mean by condition 
grand.mean=apply(mean.matrix, 2, mean, na.rm = T)
grand.mean
grand.sd=apply(mean.matrix,2,sd, na.rm = T)
grand.sd
grand.se=grand.sd/sqrt(102) # The number of the valid participants here is 102.
grand.se

####Part2--Linear Mixed Models (LMM)####

# 1.Check the levels of n2preview and phrase
levels(datafile$n2preview) ##id,in
levels(datafile$phrase) # # 1_word,ambiguous,2_word
# 2. Add contrasts 
contrasts(datafile$n2preview) <- contr.sdif(2)

contrasts(datafile$phrase) <- contr.sdif(3)


######contrasts2:"b.a", "a.c"####################################
#NOTE: After run the first contrast,then run lmer models. Then run the second contrast plus the lmer models.####
contrast.matrix2 <- matrix(c(   
  -1, +1, 0,# 2_word vs 1_word
  +1, 0, -1), 3, 2,    # (1_word vs ambiguous)
  dimnames=list(c("a", "b", "c"), # names of the conditions
                c("b.a", "a.c"))) # names of the contrasts

# Assign this contrast matrix to phrase
inv.contrast.matrix2 <- matrix(t(ginv(contrast.matrix2)),3, 2,
                               dimnames=list(c("a", "b", "c"), 
                                             c("b.a", "a.c")))

(contrasts(datafile$phrase) <- fractions(inv.contrast.matrix2))
# 3.Run linear mixed-effects models (GLME)

#####For the pretarget analyses, Adepvar.glmer13 
#####For the n+1 analyses, Adepvar.glmer13 
#####For the n+2 analyses, Adepvar.glmer13
#####For the whole region analyses, Adepvar.glmer13

##1.Full model

Adepvar.glmer1 = glmer(depvar ~n2preview * phrase + (1 +n2preview * phrase|pp) + (1 +n2preview * phrase|stim), datafile,family = binomial)
summary(Adepvar.glmer1, corr = FALSE)

# 2.Remove correlations of item

Adepvar.glmer2 = glmer(depvar ~n2preview * phrase + (1 +n2preview * phrase|pp) + (0 +n2preview * phrase|stim), datafile,family = binomial)
summary(Adepvar.glmer2, corr = FALSE)

# 3.remove interactions (with correlation back in) of item

Adepvar.glmer3 = glmer(depvar ~n2preview * phrase + (1 +n2preview *phrase|pp) + (1 +n2preview + phrase|stim), datafile,family = binomial)
summary(Adepvar.glmer3, corr = FALSE)

# 4. Remove correlation and interactions of item

Adepvar.glmer4 = glmer(depvar ~n2preview *phrase  + (1 +n2preview * phrase|pp) + (0 +n2preview + phrase|stim), datafile,family = binomial)
summary(Adepvar.glmer4, corr = FALSE)

# 5a. remove one of the slopes

Adepvar.glmer5a = glmer(depvar ~n2preview * phrase  + (1 +n2preview * phrase|pp) + (1 +n2preview|stim), datafile,family = binomial)
summary(Adepvar.glmer5a, corr = FALSE)

### 5b.
Adepvar.glmer5b = glmer(depvar ~n2preview * phrase + (1 +n2preview * phrase|pp) + (1 + phrase|stim), datafile,family = binomial)
summary(Adepvar.glmer5b, corr = FALSE)

# 6a. Again, without correlation

Adepvar.glmer6a = glmer(depvar ~n2preview * phrase  + (1 +n2preview * phrase|pp) + (1|stim) + (0 +n2preview|stim), datafile,family = binomial)
summary(Adepvar.glmer6a, corr = FALSE)

### 6b.
Adepvar.glmer6b = glmer(depvar ~n2preview * phrase + (1 +n2preview * phrase|pp) + (1|stim) + (0 + phrase|stim), datafile,family = binomial)
summary(Adepvar.glmer6b, corr = FALSE)

# 7. Intercept only for items

Adepvar.glmer7 = glmer(depvar ~n2preview * phrase  + (1 +n2preview * phrase|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer7, corr = FALSE)

# 8. Remove correlation for pp

Adepvar.glmer8 = glmer(depvar ~n2preview * phrase + (0 +n2preview * phrase|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer8, corr = FALSE)

# 9. Remove interaction (but with correlation back in) for pp

Adepvar.glmer9 = glmer(depvar ~n2preview * phrase + (1 +n2preview + phrase|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer9, corr = FALSE)

# 10. Remove interaction and correlation for pp

Adepvar.glmer10 = glmer(depvar ~n2preview * phrase + (0 +n2preview + phrase|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer10, corr = FALSE)

# 11a. Remove one slope for pp
Adepvar.glmer11a = glmer(depvar ~n2preview * phrase + (1 + phrase|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11a, corr = FALSE)

#### 11b.
Adepvar.glmer11b = glmer(depvar ~n2preview * phrase  + (1 +n2preview|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer11b, corr = FALSE)

# 12a. Again without correlation for pp

Adepvar.glmer12a = glmer(depvar ~n2preview * phrase + (1|pp) + (0 +n2preview|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer12a, corr = FALSE)

#### 12b.

Adepvar.glmer12b = glmer(depvar ~n2preview *phrase  + (1|pp) + (0 + phrase|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer12b, corr = FALSE)

# 13. Intercepts only 

Adepvar.glmer13 = glmer(depvar ~n2preview * phrase + (1|pp) + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer13, corr = FALSE)

#14.Intercepts only for pp

Adepvar.glmer14 = glmer(depvar ~n2preview * phrase + (1|pp), datafile,family = binomial)
summary(Adepvar.glmer14, corr = FALSE)

#15.Intercepts only for stim

Adepvar.glmer15 = glmer(depvar ~n2preview * phrase + (1|stim), datafile,family = binomial)
summary(Adepvar.glmer15, corr = FALSE)

###########Part2-Calculate Confidence Interation#####
confint(Adepvar.glmer12a, method="Wald") 


#########Part2-Simple effect####
## if interaction of n2preview and phrase is significant, then run the code below

#contrast:a and b
datafile$condition <- C(datafile$condition,matrix(c(+0.5,0,-0.5,0,0,0,# a vs b for id
                                                    0,0.5,0,-0.5,0,0)  # a vs b for in
                                                  ,6,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
# Full model
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
### Remove the slope for items
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
### Remove the slope for items and participants
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)

########
#contrast:b and c
datafile$condition <- C(datafile$condition,matrix(c(0,0,+0.5,0,-0.5,0,# b vs c for id
                                                    0,0,0,0.5,0,-0.5)  #b vs c for in
                                                  ,6,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
################################################################################
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
#######################################################################################
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)
#######################################

#contrast a and c
datafile$condition <- C(datafile$condition,matrix(c(0.5,0,0,0,-0.5,0,# a vs c for id
                                                    0,0.5,0,0,0,-.5)  # a vs c for in
                                                  ,6,2),2)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1+condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
################################################################################
contrast2.lmer <- lmer(depvar ~ condition  +(1+condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
#######################################################################################
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)
#######################################
#contrast:id and in

#####For the n+2 analyses,SP: contrast3.lmer.

datafile$condition <- C(datafile$condition,matrix(c(0.5,-0.5,0,0,0,0,# id vs in for 1_word
                                                    0,0,0.5,-0.5,0,0,#id vs in for 2_word
                                                    0,0,0,0,0.5,-0.5)  #id vs in for ambiguous
                                                  ,6,3),3)             # ,number of condition, number of contrasts), number of contrasts)
# Let's see how this contrast matrix looks:
contrasts(datafile$condition)
# Then run the lme
contrast1.lmer <- lmer(depvar ~ condition  + (1 + condition|pp) + (1 + condition|stim), data = datafile)
summary(contrast1.lmer, corr = FALSE)
################################################################################
contrast2.lmer <- lmer(depvar ~ condition  + (1 + condition|pp) + (1|stim), data = datafile)
summary(contrast2.lmer, corr = FALSE)
#######################################################################################
contrast3.lmer <- lmer(depvar ~ condition  +(1|pp) + (1|stim), data = datafile)
summary(contrast3.lmer, corr = FALSE)
###############################################################################
#### Part1-Confidence interval ####
confint(contrast3.lmer, method="Wald")

tab_model(contrast3.lmer,show.se=TRUE,show.stat=TRUE,auto.label=F)

######################################################################

##########################################End#######################################












